<?php
/*
 * This file is part of the easy-CMS project.
 * easy-CMS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * easy-CMS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with easy-CMS; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

/**
 * @package    Core
 * @subpackage ACL
 */
 
/**
 */
include_once('classes/core/CoreObject.class.php');
include_once('classes/core/DBManipulator.class.php');
include_once('classes/core/ACL/ACLEntry.class.php');

/**
 * An ACL (access control list) holds infos about permissions over objects (content, container, containersList, pages and menus).
 *
 * @access     public
 * @author	   Cedric Francoys <cedric.francoys@easy-cms.org>
 * @version	   ACL.class, Sat Feb 12 15:31:45 CET 2005
 * @package	   Core
 * @subpackage ACL
 */
class ACL extends CoreObject {
	/**#@+
	 * @access private
	 */
	/**
	 * @var integer
	 */
	var $id;
    
  /**
   * @var integer
   */
	var $parentId;
    
  /**
   * @var integer
   */
	var $inherit;
    
	/**
   * @var array instances of ACLEntry
   */
	var $groupsAclEntryTable;
    
  /**
   * @var array instances of ACLEntry
   */
	var $usersAclEntryTable;
  /**#@-*/

	/**#@+
	 * @access public
	 */
	/**
	 * Class Constructor
	 *
	 * @param integer $id
	 * @param integer $parentId
	 * @param integer $inherit
	 */
	function ACL($id=0, $parentId=0, $inherit=0) {
		$this->setAclId($id);
		$this->setAclParentId($parentId);
		$this->setAclInherit($inherit);
		$this->usersAclEntryTable = array();
		$this->groupsAclEntryTable = array();
	}
	
	/**
   * Gets ACL Id
   *
	 * @return integer
	 */
	function getAclId() {
		return $this->id;
	}
  
  /**
   * Sets ACL Id
   *
	 * @param integer $id
	 */
	function setAclId($id) {
		$this->id = $id;
	}
	
	/**
   * Gets ACL Parent Id
   *
	 * @return integer
	 */
	function getAclParentId() {
		return $this->parentId;
	}
  
  /**
   * Sets ACL Parent Id
   *
	 * @param integer $parentId
	 */
	function setAclParentId($parentId) {
		$this->parentId = $parentId;
	}
	
	/**
   * Gets ACL Inherit
   *
	 * @return integer
	 */
	function getAclInherit() {
		return $this->inherit;
	}
  
  /**
   * Sets ACL Inherit
   *
	 * @param integer $inherit
	 */
	function setAclInherit($inherit) {
		$this->inherit = $inherit;
	}
	
	/**
	 * Gets Groups ACL Entries
	 *
	 * @return array
	 */
	function &getGroupsAclEntryTable() {
		return $this->groupsAclEntryTable;
	}
	
	/**
	 * Sets Groups ACL Entries
	 *
	 * @param array $groupsAclEntryTable
	 */
	function setGroupsAclEntryTable(&$groupsAclEntryTable) {
		$this->groupsAclEntryTable = &$groupsAclEntryTable;
	}
	
	/**
	 * Gets Users ACL Entries
	 *
	 * @return array
	 */
	function &getUsersAclEntryTable() {
		return $this->usersAclEntryTable;
	}
	
	/**
	 * Sets Users ACL Entries
	 *
	 * @param array $usersAclEntriesTable
	 */
	function setUsersAclEntryTable(&$usersAclEntryTable) {
		$this->usersAclEntryTable = &$usersAclEntryTable;
	}
	
	/**
	 * Gets Number Of Groups ACL Entries
	 *
	 * @return integer
	 */
	function getNumGroupsAclEntry() {
		return count($this->groupsAclEntryTable);
	}
	
	/**
	 * Gets Number Of Users ACL Entries
	 *
	 * @return integer
	 */
	function getNumUsersAclEntry() {
		return count($this->usersAclEntryTable);
	}
	
	/**
	 * Gets Groups Id List
	 *
	 * @return array
	 */
	function getGroupsIdList() {
		return array_keys($this->groupsAclEntryTable);
	}
	
	/**
	 * Gets Users Id List
	 *
	 * @return array
	 */
	function getUsersIdList() {
		return array_keys($this->usersAclEntryTable);
	}
	
	/**
	 * Checks Group Acl Entry
	 *
	 * Checks if given Group has an entry defined into ACL
	 *
	 * @param  integer $groupId Group Id
	 * @return boolean
	 */
	function groupAclEntryExists($groupId) {
		return isset($this->groupsAclEntryTable[$groupId]);
	}	

	/**
	 * Checks User Acl Entry
	 *
	 * Checks if given User has an entry defined into ACL
	 *
	 * @param  integer $userId User Id
	 * @return boolean
	 */
	function userAclEntryExists($userId) {
		return isset($this->usersAclEntryTable[$userId]);
	}
	
  /**
   * Adds Group Entry Into ACL
   *
   * @param array $record Record as in ACL_GROUPS_TABLE
   */
	function addGroupEntry($record) {
		$aclEntry = &new ACLEntry();
		$aclEntry->setValues($record);
		$id = $aclEntry->getId();
		$this->groupsAclEntryTable[$id] = &$aclEntry;
	}
	
  /**
   * Adds User Entry Into ACL
   *
   * @param array $record Record as in ACL_USERS_TABLE
   */
	function addUserEntry($record) {
		$aclEntry = &new ACLEntry();
		$aclEntry->setValues($record);
		$id = $aclEntry->getId();
		$this->usersAclEntryTable[$id] = &$aclEntry;
	}
    
  /**
	 * Gets ACL entry for given group
	 *
	 * @author  vinadelmar <vinadelmar@users.sourceforge.net>
	 * @since   2006-02-23
	 * @version 0.1.0
	 * @param   integer $gid group id
	 * @return  mixed `ACLEntry` object or false
	 */
	function &getGroupAclEntry($gid) {
		if (!$this->groupAclEntryExists($gid)) {
			return false;
		}
		return $this->groupsAclEntryTable[$gid];
	}
	
	/**
	 * Gets User's ACL Entry
	 *
	 * @author  vinadelmar <vinadelmar@users.sourceforge.net>
	 * @since   2006-02-23
	 * @version 0.1.0
	 * @param   integer $userId
	 * @return  mixed `ACLEntry` object or false
	 */
	function &getUserAclEntry($uid) {
		if (!$this->userAclEntryExists($uid)) {
			return false;
		}
		return $this->usersAclEntryTable[$uid];
	}
	
	/**
	 * Sets Group's ACL Entry
	 *
	 * @author  vinadelmar <vinadelmar@users.sourceforge.net>
	 * @since   2006-02-23
	 * @version 0.1.0
	 * @param   integer $gid group id
	 * @param   array arrayof rights
	 * @return  boolean
	 */
	
	function setGroupAclEntry($gid, $fieldsArray) {
		if (!$this->groupAclEntryExists($gid)) {
			$aclEntry = &new ACLEntry($gid);
			$this->groupsAclEntryTable[$gid] = &$aclEntry;
		}
		$this->groupsAclEntryTable[$gid]->setValues($fieldsArray);
		return true;
	}
	
	/**
	 * Sets User's ACL Entry
	 *
	 * @author  vinadelmar <vinadelmar@users.sourceforge.net>
	 * @since   2006-02-23
	 * @version 0.1.0
	 * @return  boolean
	 */
	
	function setUserAclEntry($uid, $fieldsArray) {
		if (!$this->userAclEntryExists($uid)) {
			$aclEntry = &new ACLEntry($uid);
			$this->usersAclEntryTable[$uid] = &$aclEntry;
		}
		$this->usersAclEntryTable[$uid]->setValues($fieldsArray);
		return true;
	}
	
	function removeGroupAclEntry($gid) {
		if (!$this->groupAclEntryExists($gid)) {
			$this->debug('ACL::groupAclEntryExists(), warning : group #'.$gid.' not defined in ACL #'.$this->getAclId().' (no action taken).');
			return false;
		}
		
		unset($this->groupsAclEntryTable[$gid]);
		$this->debug('ACL::groupAclEntryTable(), success : group #'.$gid.' removed from ACL #'.$this->getAclId().'.', 9);
		return true;
	}
	
	function removeUserAclEntry($uid) {
		if (!$this->userAclEntryExists($uid)) {
			$this->debug('ACL::removeUserAclEntry(), warning : user #'.$uid.' not defined in ACL (no action taken).');
			return false;
		}
		unset($this->usersAclEntryTable[$uid]);
		$this->debug('ACL::removeUserAclEntry(), success : user #'.$uid.' removed from ACL.', 9);
		return true;
	}
    
  /**
	 * Group's View Right
 	 * 
 	 * Checks if group has the view right
 	 *
 	 * @param  integer $gid group id in groups list
	 * @return boolean
	 */
	function groupIdHasViewRight($gid) {
		if (!$this->groupAclEntryExists($gid)) {
			return false;
		}
		return $this->groupsAclEntryTable[$gid]->getViewRight();
	}
    
	/**
	 * User's View Right
	 * 
	 * Checks if user or one its groups has view right
	 *
 	 * @param  object $user instanceof `User`
	 * @return boolean
	 */
	function userHasViewRight(&$user) {
		if(!is_object($user)) {
			$this->debug('ACL::userHasViewRight(), error : user not defined.', 2);
			return false;
		}
    
    $userId = $user->getUserId();
    
    if ($this->userAclEntryExists($userId)) {
      if($this->usersAclEntryTable[$userId]->getViewRight()) {
				return true;
			}
    }

    foreach ($this->getGroupsIdList() as $groupId) {
    	if($user->checkGroupMembership($groupId)) {
        if ($this->groupIdHasViewRight($groupId)) {
        	return true;
				}
			}
		}

    return false;
	}

	/**
	 * Group's Edit Right
 	 * 
 	 * Checks if group has the edit right
 	 *
 	 * @param  integer $gid group id in groups list
	 * @return boolean
	 */  
	function groupIdHasEditRight($gid) {
    	if (!$this->groupAclEntryExists($gid)) {
    		return 0;
    	}
    	return $this->groupsAclEntryTable[$gid]->getEditRight();    	
	}
    
	/**
	 * User's Edit Right
	 * 
	 * Checks if user or one of its groups has edit right
	 *
 	 * @param  object $user instance of User
	 * @return boolean
	 */   
	function userHasEditRight(&$user) {
    	$right = 0;
    	
    	if (!is_object($user)) {
    		$this->debug('ACL::userHasEditRight(), error : user not defined (right 0 returned).');
    		return $right;
    	}
    	
    	$uid = $user->getUserId();
    	
    	if ($this->userAclEntryExists($uid)) {
    		$right = $this->usersAclEntryTable[$uid]->getEditRight();
    	}
    	
    	if (!$right) {
    		foreach ($user->getGroupsMembershipList() as $gid)
    			if ($right = $this->groupIdHasEditRight($gid))
    				break;
    	}
    	
    	return $right;
	}

	/**
	 * Group's Publish Right
 	 * 
 	 * Checks if group has the publish right
 	 *
 	 * @param  integer $gid group id in groups list
	 * @return boolean
	 */    
	function groupHasPublishRight($gid) {
    	if ($this->groupAclEntryExists($gid)) {
    		return $this->groupsAclEntryTable[$gid]->getPublishRight();
    	}
    	return 0;    	
	}
    
    /**
	 * User's Publish Right
 	 * 
 	 * Checks if user or one of its groups has publish right
 	 *
 	 * @param  object $user instance of User
	 * @return boolean
	 */
	function userHasPublishRight(&$user) {
		$right = 0;
		
		if (!is_object($user)) {
			$this->debug('ACL::userHasPublishRight(), error : user not defined (right 0 returned).');
			return $right;
		}
		
		$uid = $user->getUserId();
		
		if($this->userAclEntryExists($uid)){
			$right = $this->usersAclEntryTable[$uid]->getPublishRight();
		}
		
		if (!$right) {
			foreach ($user->getGroupsMembershipList() as $gid)
				if ($right = $this->groupIdHasPublishRight($gid))
					break;
		}
		
		return $right;
	}

	/**
	 * Group's Remove Right
 	 * 
 	 * Checks if group has the remove right
 	 *
 	 * @param  integer $gid group id in groups list
	 * @return boolean
	 */
	function groupIdHasRemoveRight($gid) {
		if ($this->groupAclEntryExists($gid)) {
			return $this->groupsAclEntryTable[$gid]->getRemoveRight();
		}
		return 0;    	
	}
    
    /**
	 * User's Remove Right
 	 * 
 	 * Checks if user or one of its groups has remove right
 	 *
 	 * @param  object $user instance of User
	 * @return boolean
	 */
	function userHasRemoveRight(&$user) {
		$right = 0;
		
		if (!is_object($user)) {
			$this->debug('ACL::userHasRemoveRight(), error : user not defined (right 0 returned).');
			return $right;
		}
		
		$uid = $user->getUserId();
		
		if ($this->userAclEntryExists($uid)) {
			$right = $this->usersAclEntryTable[$uid]->getRemoveRight();
		}
		
		if (!$right) {
			foreach ($user->getGroupsMembershipList() as $gid)
				if ($right = $this->groupIdHasRemoveRight($gid))
					break;
		}
		
		return $right;
	}

	/**
	 * Group's Admin Right
 	 * 
 	 * Checks if group has the admin right
 	 *
 	 * @param  integer $gid group id in groups list
	 * @return boolean
	 */
	function groupIdHasAdminRight($gid) {
    	if ($this->groupAclEntryExists($gid)) {
    		return $this->groupsAclEntryTable[$gid]->getAdminRight();
    	}
    	return 0;    	
	}
    
	/**
	 * User's Admin Right
 	 * 
 	 * Checks if user or one of its groups has admin right
 	 *
 	 * @param  object $user instance of User
	 * @return boolean
	 */
	function userHasAdminRight(&$user) {
		$right = 0;
		
		if (!is_object($user)) {
			$this->debug('ACL::userHasAdminRight(), error : user not defined (right 0 returned).');
			return $right;
		}
		
		$uid = $user->getUserId();
		
		if ($this->userAclEntryExists($uid)) {
			$right = $this->usersAclEntryTable[$uid]->getAdminRight();
		}
		
		if (!$right) {
			foreach ($user->getGroupsMembershipList() as $gid) 
				if ($right = $this->groupIdHasAdminRight($gid)) 
					break;
		}
		
		return $right;
	}
	
	/**
	 * @author  vinadelmar <vinadelmar@users.sourceforge.net>
	 * @since   2006-02-23
	 * @version 1.1.0
	 * @param   object $acl instance of ACL, another ACL to be compared with 
	 * @return  array diff
	 */
  /*
	function compareTo(&$acl) {
		$cmpv = array (
			 'id'                  => ($this->getId() == $acl->getId())
			,'parentId'            => ($this->getParentId() == $acl->getParentId())
			,'inherit'             => ($this->getInherit() == $acl->getInherit())
			,'groupsAclEntryTable' => true
			,'usersAclEntryTable'  => true
		);
		
		foreach ($acl->getGroupsAclEntryTable() as $gid => $aclEntry) {
			// the entry in clone does not exist
			if (!$this->groupsAclEntryTable[$gid]) {
				$cmpv['groupsAclEntryTable'] = false;
				break;
			}
			if (!$this->groupsAclEntryTable[$gid]->compareTo($aclEntry)) {
				$cmpv['groupsAclEntryTable'] = false;
				break;
			}
		}
		
		foreach ($acl->getUsersAclEntryTable() as $uid => $aclEntry) {
			if (!$this->usersAclEntryTable[$uid]) {
				$cmpv['usersAclEntryTable'] = false;
				break;
			}
			
			if (!$this->usersAclEntryTable[$uid]->compareTo($aclEntry)) {
				$cmpv['usersAclEntryTable'] = false;
				break;
			}
		}
		
		return $cmpv;
	}
  */

	//returns < 0 if the current acl has less rights defined than acl;
	//				> 0 if current acl has more rights defined than acl;
	//					0 if acl's have equals rights
	function compareTo(&$acl) {
		foreach ($acl->getGroupsAclEntryTable() as $gid => $aclEntry) {
			if(!isset($this->groupsAclEntryTable[$gid])) {
				return -1;
			}
			if(($comp = $aclEntry->compareTo($this->groupsAclEntryTable[$gid])) != 0) {
				return (-$comp);
			}
		}

		foreach ($acl->getUsersAclEntryTable() as $uid => $aclEntry) {
			if(!isset($this->usersAclEntryTable[$uid])) {
				return -1;
			}
			if(($comp = $aclEntry->compareTo($this->usersAclEntryTable[$uid])) != 0) {
				return (-$comp);
			}
		}
		foreach ($this->getGroupsAclEntryTable() as $gid => $aclEntry) {
			if(!isset($acl->groupsAclEntryTable[$gid])) {
				return 1;
			}
			if(($comp = $aclEntry->compareTo($acl->groupsAclEntryTable[$gid])) != 0) {
				return $comp;
			}
		}
		foreach ($this->getUsersAclEntryTable() as $uid => $aclEntry) {
			if(!isset($acl->usersAclEntryTable[$uid])) {
				return 1;
			}
			if(($comp = $aclEntry->compareTo($acl->usersAclEntryTable[$uid])) != 0) {
				return $comp;
			}
		}
		return 0;
	}


	  /**
     * Export ACL Into XML String
     *
     * @return string XML
     * @todo   finish xml string
     */
	function toXML() {
		$xml  = '';
		$xml .= '<acl id="" parent="" inherit="">';
		$xml .= '  <users>';
		$xml .= '  </users>';
		$xml .= '  <groups>';
		$xml .= '  </groups>';
		$xml .= '</acl>';
		return $xml;
	}
	









	/*--- DEPRECATED CODE BELOW ---*/
	
	
	
	
	/**
	 * Adds ACL entry in {@link groupsAclEntryTable}
	 *
	 * @author vinadelmar <vinadelmar@users.sourceforge.net>
	 * @since  2006-03-07
	 * @param  integer $gid group id
	 * @param  integer $view view right
	 * @param  integer $edit edit right
	 * @param  integer $publish publish right
	 * @param  integer $remove remove right
	 * @param  integer $admin admin right
	 * @return boolean
	 */
	/*
	function addGroupAclEntry($gid, $view=0, $edit=0, $publish=0, $remove=0, $admin=0) {
    if ($this->groupAclEntryExists($gid)) {
      $this->debug('ACL::addGroupAclEntry(), warning : group #'.$gid.' already defined in ACL #'.$this->getAclId().'.', 6);
      return false;
    }
    $this->groupsAclEntryTable[$gid] = &new ACLEntry($gid, $view, $edit, $publish, $remove, $admin);
    $this->debug('ACL::addGroupAclEntry(), success : group #'.$gid.' added to ACL #'.$this->getAclId().'.', 9);
    return true;
	}
	*/
	
	/*
	function addUserAclEntry($uid, $view=0, $edit=0, $publish=0, $remove=0, $admin=0) {
		if ($this->userAclEntryExists($uid)) {
			$this->debug('ACL::addUserACLEntry(), warning : user #'.$uid.' already defined in ACL #'.$this->getAclId().' (add skipped).', 6);
			return false;
		}
		$this->usersAclEntryTable[$uid] = &new ACLEntry($uid, $view, $edit, $publish, $remove, $admin);
		return true;
	}
	*/
	
	
  /*
	function setId(&$id) 
    {
		$this->id = &$id;
	}
	
    function &getId() 
    {
		return $this->id;
	}
	
	function setParentId(&$parentId) 
    {
		$this->parentId = &$parentId;
	}
	
	function &getParentId() 
	{
		return $this->parentId;
	}
	
	function setInherit(&$inherit) 
	{
		$this->inherit = &$inherit;
	}
	
    function &getInherit() 
    {
		return $this->inherit;
	}

	function &getUsersList()
	{
		return $this->usersAclEntryTable;
	}
	
	function &getGroupsList()
	{
		return $this->groupsAclEntryTable;
	}
	*/
	
	/**
	 * Set ACL Properties From Array
	 *
	 * @param array $array associative array property=>value
	 * @todo check for relevance
	 */
    function setValues(&$array) 
    {
		if(isset($array['id']))
			$this->id = &$array['id'];
		if(isset($array['parent_id']))
			$this->parentId = &$array['parent_id'];
		if(isset($array['inherit']))
			$this->inherit = &$array['inherit'];
		return 1;
    }
	
	/**
	 * @todo check for relevance
	 */
	function &getValue($fieldName) 
	{
		if($fieldName == 'id')
			return $this->id;
		return -1;
	}
	
	/**
	 * Checks If Group Exists
	 *
	 * @param  integer $id group id
	 * @return boolean
	 * @deprecated {@link use groupAclEntryExists}
	 */
	/*
	function checkGroup(&$id)
	{
		return isset($this->groupsAclEntryTable[$id]);
	}
	*/
	
	/**
	 * @deprecated {@link use groupAclEntryExists}
	 */
	/*
	function groupExists($gid) {
		return isset($this->groupsAclEntryTable[$gid]);
	}
	*/
	
	/**
	 * @deprecated {@link userAclEntryExists}
	 */
	/*
	function userExists($uid) {
		return isset($this->usersAclEntryTable[$uid]);
	}
	*/
	
	/**
	 * @deprecated use {@link userAclEntryExists}
	 */
	/*
	function checkUser(&$id) {
		return isset($this->usersAclEntryTable[$id]);
	}
	*/
	
	/**
	 * Add Group To List
	 *
	 * @param  integer $groupId
	 * @param  integer $viewRight
	 * @param  integer $editRight
	 * @param  integer $publishRight
	 * @param  integer $removeRight
	 * @param  integer $adminRight
	 * @return integer <0 if error
	 * @deprecated use {@link addGroupAclEntry}
	 */
	/*
	function addGroup(&$groupId, &$viewRight, &$editRight, &$publishRight, &$removeRight, &$adminRight) {
		if ($this->groupAclEntryExists($groupId)) {
			$this->debug("ACL.addGroup, error : group already defined in ACL ".$this->getId()." (add skipped).", 2);
			return -1;
		}
   		$this->groupsAclEntryTable[$groupId] = &new ACLEntry($groupId, $viewRight, $editRight, $publishRight, $removeRight, $adminRight);
		return 1;    	
  }
	*/
	
	/**
	 * Add User To List
	 *
	 * @param  integer $userId
	 * @param  integer $viewRight
	 * @param  integer $editRight
	 * @param  integer $publishRight
	 * @param  integer $removeRight
	 * @param  integer $adminRight
	 * @return integer <0 if error
	 * @deprecated use {@link addUserAclEntry}
	 */
	/*
	function addUser(&$userId, &$viewRight, &$editRight, &$publishRight, &$removeRight, &$adminRight) {
		if ($this->userAclEntryExists($userId)) {
			$this->debug("ACL.addUser, error : user already defined in ACL ".$this->getId()." (add skipped).", 2);			
			return -1;
		}
		else {
			$this->usersAclEntryTable[$userId] = &new ACLEntry($userId, $viewRight, $editRight, $publishRight, $removeRight, $adminRight);
		}
		return 1;
	}
	*/
	
	/**
	 * Remove User From ACL
	 *
	 * @param  integer $userId
	 * @return boolean
	 * @deprecated use {@link removeUserAclEntry}
	 */
	/* 
  function removeUser(&$userId) {
		if (!$this->checkUser($userId)) {
			$this->debug("ACL::removeUser(), warning : user #{$userId} not defined in ACL (no action taken).");
			return false;
		}
		unset($this->usersList[$userId]);
		$this->debug("ACL::removeUser(), success : user #{$userId} removed from ACL.");
		return true;
	}
	*/
    
	/**
	 * Remove Group From ACL
	 *
	 * @param  integer $groupId
	 * @return boolean
	 * @deprecated use {@link removeGroupAclEntry}
	 */
	/*
	function removeGroup(&$groupId) {
		if (!$this->checkGroup($groupId)) {
			$this->debug("ACL::removeGroup(), warning : group #{$groupId} not defined in ACL (no action taken).");
			return false;
		}
		unset($this->groupsList[$groupId]);
		$this->debug("ACL::removeGroup(), success : group #{$groupId} removed from ACL.");
		return true;
	}
	*/
	
	/**
	 * Set User Rights
	 *
	 * @param  integer $userId
	 * @param  integer $viewRight
	 * @param  integer $editRight
	 * @param  integer $publishRight
	 * @param  integer $removeRight
	 * @param  integer $adminRight
	 * @return integer <0 if error
	 * @todo check for relevance
	 */
	function setUserRights(&$userId, &$viewRight, &$editRight, &$publishRight, &$removeRight, &$adminRight) {
    	if (!$this->checkUser($userId)) {
			$this->debug("ACL.setUserRights, error : user ".$userId." not defined in ACL ".$this->getId()." (no action taken).", 2);
			return -1;    		
    	}
    	$this->usersList[$userId]->setViewRight($viewRight);
    	$this->usersList[$userId]->setEditRight($editRight);
    	$this->usersList[$userId]->setPublishRight($publishRight);
    	$this->usersList[$userId]->setRemoveRight($removeRight);    	    	    	
    	$this->usersList[$userId]->setAdminRight($adminRight);
    	return 1;
	}

	/**
	 * Set Group Rights
	 *
	 * @param  integer $groupId
	 * @param  integer $viewRight
	 * @param  integer $editRight
	 * @param  integer $publishRight
	 * @param  integer $removeRight
	 * @param  integer $adminRight
	 * @return integer <0 if error
	 * @todo check for relevance
	 */
	function setGroupRights(&$groupId, &$viewRight, &$editRight, &$publishRight, &$removeRight, &$adminRight) {
    	if (!$this->checkUser($groupId)) {
			$this->debug("ACL.setGroupRights, error : group ".$groupId." not defined in ACL ".$this->getId()." (no action taken).", 2);
			return -1;    		
    	}
    	$this->groupsList[$groupId]->setViewRight($viewRight);
    	$this->groupsList[$groupId]->setEditRight($editRight);
    	$this->groupsList[$groupId]->setPublishRight($publishRight);
    	$this->groupsList[$groupId]->setRemoveRight($removeRight);    	    	    	
    	$this->groupsList[$groupId]->setAdminRight($adminRight);
    	return 1;
	}
	
	/**
	 * @deprecated
	 */
	function getHTMLForm($mode) {
    	$site = &Site::getInstance();
    	$user = &$site->getCurrentUser();
    	
    	if (!$this->userHasAdminRight($user)) {
    		return '';
    	}
    	
    	$groupsManager = &$site->getGroupsManager();
    	$usersManager = &$site->getUsersManager();
    	
    	$form .= "<p>Groups/Users can : <strong>V</strong>iew, <strong>E</strong>dit, <strong>P</strong>ublish, <strong>R</strong>emove, <strong>A</strong>dmin</p>";
    	$form .= "<div style=\"overflow:auto;height:150px\">\n";
    	$form .= "<table>\n";
    	$form .= "\t<thead><tr><th>NAME</th><th>V</th><th>E</th><th>P</th><th>R</th><th>A</th></tr></thead>\n";
    	$form .= "\t<tfoot><tr><th>NAME</th><th>V</th><th>E</th><th>P</th><th>R</th><th>A</th></tr></tfoot>\n";
    	$form .= "\t<tbody>\n";
    	
    	/*
    	foreach ($this->getUsersList() as $userId => $aclEntry) {
    		$form .= "\t\t<tr>\n";
    		$form .= "\t\t<td>{$userId}</td>\n";
    		foreach ($aclEntry->getFieldsArray() as $right => $isSet) {
    			$isChecked = $isSet? ' checked="checked"' : '';
    			$form .= "\t\t<td><input type=\"checkbox\" value=\"{$userId}\"{$isChecked}/></td>\n";
    		}
    		$form .= "\t\t</tr>\n";
    	}
    	*/
    	
    	$groupsIdList = array_keys($this->getGroupsList());
    	
    	foreach ($groupsManager->getGroupsName($groupsIdList) as $gid => $gname) {
    		$form .= "\t\t<tr>\n";
    		$form .= "\t\t<td><span style=\"color:green;font-size:smaller\">Group</span> {$gname}</td>\n";
    		$aclEntry = $this->groupsList[$gid];
    		foreach ($aclEntry->getFieldsArray() as $right => $isSet) {
    			// name of inputs checkbox
    			$ctrlName = "grv[{$gid}]['{$right}']";
    			$isChecked = $isSet? ' checked="checked"' : '';
    			//$form .= "\t\t<td><input name=\"{$ctrlName}\" type=\"checkbox\" value=\"1\"{$isChecked}/></td>\n";
    			$form .= "\t\t<td><select name=\"{$ctrlName}\"><option value=\"yes\">yes</option><option value=\"no\">no</option></select></td>";
    		}
    		$form .= "\t\t</tr>\n";
    	}
    	
    	$usersIdList = array_keys($this->getUsersList());
    	
    	foreach ($usersManager->getUsersName($usersIdList) as $uid => $uname) {
    		$form .= "\t\t<tr>\n";
    		$form .= "\t\t<td><span style=\"color:green;font-size:smaller\">User</span> {$uname}</td>\n";
    		$aclEntry = $this->usersList[$uid];
    		foreach ($aclEntry->getFieldsArray() as $right => $isSet) {
    			$ctrlName = "usrv[{$uid}]['{$right}']";
    			$isChecked = $isSet? ' checked="checked"' : '';
    			$form .= "\t\t<td><input name=\"{$ctrlName}\" type=\"checkbox\" value=\"1\"{$isChecked}/></td>\n";
    		}
    		$form .= "\t\t</tr>\n";
    	}
    	
    	/*
    	foreach ($this->getGroupsList() as $groupId => $aclEntry) {
    		$group = &$groupsManager->getGroup($groupId);
    		$id = $group->getGroupId();
    		$form .= "\t\t<tr>\n";
    		$form .= "\t\t<td><span style="">Group</span>{$id}</td>\n";
    		foreach ($aclEntry->getFieldsArray() as $right => $isSet) {
    			$isChecked = $isSet? ' checked="checked"' : '';
    			$form .= "\t\t<td><input type=\"checkbox\" value=\"{$id}\"{$isChecked}/></td>\n";
    		}
    		$form .= "\t\t</tr>\n";
    	}
    	*/
    	
    	$form .= "\t</tbody>\n";
    	$form .= "</table>\n";
    	//$form .= "<p> groups count : ".count($this->getGroupsList())."</p>";
    	/*
    	$form .= "<pre>";
  		foreach ($this->getGroupsList() as $groupId => $aclEntry) {
  			$form .= $groupsManager->loadGroup($groupId);
  		}
  		$form .= "</pre>";
  		*/
  		
    	$form .= "</div>\n";
    	
		return $form;
	}	
	
	/**
     * @todo finish or remove method
     */
	function setGroupsEntry($groupsEntry) {
		foreach ($groupsEntry as $gid => $group) {
		}
	}
    
    /**
     * @todo finish or remove method
     */
	function setUsersEntry($usersEntry) {
	}

	/**
	 * @todo finish or remove
	 */
	function getHTMLContentList($mode) {
	}
	/**#@-*/
} 

?>
