<?php
/*
 * This file is part of the Easy-CMS project.
 * Easy-CMS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * Easy-CMS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Easy-CMS; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

/**
 * @package Core
 */
 
/**
 */
include_once('config.inc.php');
include_once('classes/core/CoreObject.class.php');
include_once('classes/db/DBMSData.class.php');

/**
 * Abstract class for DB Manipulators (different for each DBMS).
 *
 * @access  private
 * @author	Cedric Francoys <cedric.francoys@easy-cms.org>
 * @version	DBManipulator.class, Sun Nov 14 16:50:15 CET 2004
 * @package	Core
 */
class DBManipulator extends CoreObject {
	/**#@+
	 * @access	private
	 */
	/**
	 * @var string DBMS type (e.g. MySQL, Postgresql, ...)
	 */
	var $dbmsType;
	
	/**
	 * @var object contains db data for SQL transactions.
	 */
    var $dbData;
	
    //var $dbConnection; deprecated

	/** 
	 * @var integer the last auto increment value generated
	 */
    var $lastId;
	
	/** 
	 * Variable containing the latest error.
	 *
	 * The possible values of this var are depending on the DBMS used (here MySQL)
	 * The string can generally be retrieved using the $lastId var value.
	 * 
	 * @var	string
	 */	
    var $lastError;
	
	/**
	 * @var integer
	 */
	var $errNo;
	
	/**
	 * @var string
	 */
	var $errMsg;

	/** 
	 * Variable containing the number of affected rows.
	 *
	 * The possible values of this var are depending on the DBMS used (here MySQL)
	 * The integer can generally be retrieved using the $affectedRows var value.
	 * 
	 * @var integer
	 */		
	var $affectedRows;
	
	/**
	 * Number of rows returned by last query
	 *
	 * @var integer;
	 */
	var $numRows;
	/**#@-*/
	
	/**
	 * Class constructor.
	 * Initialize the DBConnection object for SQL transactions.
	 * 
	 * @access public
 	 * @param  string    The hostname of the DB server.
	 * @param  string    The name of the DB.
	 * @param  string    The username to use for the connection to the DB.
	 * @param  string    The password to use for the connection to the DB.
 	 * @return void  
	 */	    
    function DBManipulator($host, $db, $user, $pass) 
	{  	
		$this->dbData = new DBMSData($host, $db, $user, $pass);
    }
	
	/**
	 * Gets Last Id
	 *
	 * Last auto incremented Id
	 *
	 * @return integer
	 * @final
	 */
	function getLastId(){
		return $this->lastId;
	} 
	
	/**
	 * Sets Last Id
	 *
	 * Last auto incremented Id
	 *
	 * @param integer $id
	 * @final
	 */
	function setLastId($id){
		$this->lastId = $id;
	}
	
	/**
	 * Gets Affected Rows
	 *
	 * Number of affected rows by last query
	 *
	 * @return integer
	 * @final
	 */
	function getAffectedRows(){
		return $this->affectedRows;
	}
	
	/**
	 * Sets Affected Rows
	 *
	 * Number of affected rows by last query
	 *
	 * @param integer $affectedRows
	 * @final
	 */
	function setAffectedRows($affectedRows){
		$this->affectedRows = $affectedRows;	
	}
	
	/**
	 * Gets Last Error
	 *
	 * Error generated by last query
	 *
	 * @return string
	 * @final
	 * @todo check for uselessness
	 */
	function getLastError(){
		return $this->lastError;
	} 
	
	/**
	 * Sets Last Error
	 *
	 * Error generated by last query
	 *
	 * @param string $error
	 * @final
	 * @todo check for uselessness
	 */
	function setLastError($error) 
	{
        $this->lastError = $error;
    }
	
	/**
	 * Gets Error Number
	 *
	 * Error code generated by last query
	 *
	 * @return integer
	 * @final
	 */
	function getErrNo()
	{
		return $this->errNo;
	}
	
	/**
	 * Sets Error Number
	 *
	 * Error code generated by last query
	 *
	 * @param integer $errNo
	 * @final
	 */
	function setErrNo($errNo)
	{
		$this->errNo = $errNo;
	}
	
	/**
	 * Gets Error Message
	 *
	 * Error message generated by last query
	 *
	 * @return string
	 * @final
	 */
	function getErrMsg()
	{
		return $this->errMsg;
	}
	
	/**
	 * Sets Error Message
	 *
	 * Error message generated by last query
	 *
	 * @param string $errMsg
	 * @final
	 */
	function setErrMsg($errMsg)
	{
		$this->errMsg = $errMsg;
	}
	
	/**
	 * Gets Number of Rows
	 *
	 * Number of rows returned by last query
	 *
	 * @return integer
	 * @final
	 */
	function getNumRows()
	{
		return $this->numRows;
	}
	
	/**
	 * Sets Number of Rows
	 *
	 * Number of rows returned by last query
	 *
	 * @param integer $numRows
	 * @final
	 */
	function setNumRows($numRows)
	{
		$this->numRows = $numRows;
	}

	/**#@+
	 *@access	public
	 */
	/**
	 * Open the DBMS connection.
	 *
	 * @return boolean status of the connect function call.
	 */
    function connect() 
	{
    	//return $this->dbConnection->connect(); overridden in childs
	}
	
	/**
	 * Close the DBMS connection.
	 *
	 * @return boolean status of the close function call.
	 */
    function disconnect() 
	{
    	//return $this->dbConnection->disconnect(); overridden in childs    	
	}
	
	/**
	 * Sends Query
	 *
	 * Executes SQL statement
	 *
	 * @param	 string	$sql
	 * @return resource
	 * @abstract
	 */
	function sendQuery($sql){
	}

	/**
	 *
	 * @param	string	$table
	 * @return 	array	
	 */
	function &getColumns($table) 
	{
    } 
	
	/**
	 * @deprecated
	 */
    function &getDBConnection() 
	{
    	//return $this->dbConnection; to be removed
	}

	/**
	 * @return	integer
	 */
  function getCMSType($dbFieldType) 
	{
    } 

	/**
	 * @return	string
	 */
	function getDBMSType($cmsFieldType) 
	{
    } 

	/**
	 * @param	string $table name of table in database.
	 * @return 	array reference to associative array of fields and types.
	 */
	function &getFieldsArray($table)
	{
	}
	
	/**
	 * Get record from table.
	 *
	 * @param	string $tableName name of table.
	 * @param	string $id record id.
	 * @param	string $cond SQL WHERE clause.
	 * @param	string $idField record id field.
	 * @param	string $order order field.
	 * @return	resource reference to query resource
	 */
	function getRecord($tableName, $id = "", $cond = "", $idField = "id", $order="")
	{
	}

	/**
	 * Update record in table.
	 *
	 * @param	string $tableName name of table.
	 * @param	string $id record id.
	 * @param	array $fieldsArray associative array of fields and values.
	 * @param	string $cond SQL WHERE clause.
	 * @param	string $idField record id field.
	 * @return	resource reference to query resource.
	 */
	function setRecord($tableName, $id, $fieldsArray, $cond = "", $idField = "id") 
	{
	}
	
	/**
	 * Add record to table.
	 *
	 * @param	string $tableName name of table to add record into.
	 * @param	array $fieldsArray associative array of fields and values.
	 * @return	resource reference to query resource.
	 */
	function addRecord($tableName, $fieldsArray)
	{
	}

	/**
	 * Delete record from table.
	 *
	 * @param	string $tableName name of table.
	 * @param	string $id record id.
	 * @param	string $cond SQL WHERE clause.
	 * @param	string $idField record id field.
	 * @return	resource reference to query resource.
	 */
	function delRecord($tableName, $id, $cond = "", $idField = "id")
	{
	}

	/**
	 * Returns row from query results.
	 *
	 * @param	resource $query reference to query resource.
	 * @return	array
	 * @abstract
	 */
	function fetchRow($resource) // &$array
	{
	}

	/**
	 * Returns row from query results.
	 *
	 * @param	resource $query reference to query resource.
	 * @return	array 
	 * @abstract
	 */
	function fetchArray($resource) // &$array
	{
	}
	
	/**
	 * Returns `Field` value from SQL SHOW FULL COLUMNS statement.
	 *
	 * @param	array $fieldArray associative array of fields and values.
	 * @return	string value of `Field` in SQL SHOW statement.
	 */
    function getDBFieldName($fieldArray) 
	{
    } 

	/**
	 * Returns `Type` value from SQL SHOW FULL COLUMNS statement.
	 *
	 * @param	array $fieldArray associative array of fields and values.
	 * @return 	string value of `Type` in SQL SHOW statement.
	 */
	function getDBFieldType($fieldArray) 
	{
	} 

	/**
	 * Returns `Key` value from SQL SHOW FULL COLUMNS statement.
	 *
	 * @param	array $fieldArray associative array of fields and values.
	 * @return	string valueof `Key` in SQL SHOW statement.
	 */
    function getDBFieldKey($fieldArray) 
	{
    } 

	/**
	 * Returns resource to "SHOW TABLES LIKE '$prefix'" query.
	 *
	 * @param	string $prefix prefix in all tables name in database.
	 * @return	resource reference to query resource.
	 */
	function &getTables($prefix){	
	}

	/**
	 * Returns resource to "SHOW TABLES LIKE '$tableName'" query.
	 * 
	 * @param	string $tableName name of table.
	 * @return	resource reference to query resource.
	 */
    function &getTable($tableName) 
	{	
	}
	
	/**
	 * Returns number of "content_type" tables in database.
	 *
	 * @return	integer number
	 */
    function countTypeTables() 
	{	
	}	
	
	/**
	 * Check if table exists in database.
	 *
	 * @param	string $tableName name of table in database.
	 * @return	bool true if table exists or false.
	 */
	function tableExists($tableName) 
	{
    } 

	/**
	 * Check if record exists in table.
	 *
	 * @param	string $tableName name of table.
	 * @param	string $id record id.
	 * @param	string $cond SQL WHERE clause.
	 * @param	string $idField record id field.
	 * @return	bool true if record exists or false.
	 */
    function recordExists($tableName, $id, $cond = "", $idField = "id") 
	{
	}
	
	/**
	 * Check if content_type_* table exists in database.
	 *
	 * @param	string $typeName content_type_* table name.
	 * @return	bool true if content_type_* table exists or false.
	 */
    function typeExists($typeName) 
	{
	}

	/**
	 * Check if page exists in PAGES_TABLE.
	 *
	 * @param	integer $pageId page id.
	 * @return	bool true if page exists or false.
	 */
    function pageExists($pageId) 
	{
	}

	/**
	 * Check if container exists in CONTAINERS_TABLE.
	 *
	 * @param	integer $containerId container id.
	 * @return	bool true if container exists or false.
	 */
    function containerExists($containerId) 
	{
	}
	
	/**
	 * Check if menu exists in MENUS_TABLE.
	 *
	 * @param	integer	$menuId menu id.
	 * @return	bool true if menu exists or false.
	 */
    function menuExists($menuId) 
	{
	}

	/**
	 * Check if containers list in CONTAINERS_LISTS_TABLE.
	 *
	 * @param	integer	$containersListId containers list id.
	 * @return	bool true if containers list exists or false.
	 */
    function containersListExists($containersListId) 
	{
	}

	/**
	 * Check if template exists in TEMPLATES_TABLE.
	 *
	 * @param	string $typeName type name.
	 * @return	bool true if template exists or false.
	 */
    function templateExists($typeNname, $id) 
	{
	}
	
	/**
	 * Gets Page Menus
	 * 
	 * @param  integer $pageId Page Id
	 * @param  boolean $deleted 
	 * 	 	 	 	 
	 */	 	
	function getPageMenus($frameId){
		$sql  = 'select b.* ';
		$sql .= 'from `'.FRAME_MENUS_TABLE.'` a ';
		$sql .= 'join `'.MENUS_TABLE.'` b on a.menu_id=b.id ';
		$sql .= 'where a.frame_id='.$this->quoteSmart($frameId);
		return $this->sendQuery($sql);
	}
	
	/**
	 * Gets Page ContainersLists
	 * 
	 * @param  integer $pageId
	 * @param  integer $frameId
	 * @param  boolean $deleted
	 * @return resource	 	 	 	 	 
	 */	 	
	function getPageContainersLists($pageId, $frameId, $deleted=false){
		$sql  = 'select b.* ';
		$sql .= 'from `'.FRAME_CONTAINERS_LISTS_TABLE.'` a ';
		$sql .= 'join `'.CONTAINERS_LISTS_TABLE.'` b on a.containers_list_id=b.id ';
		$sql .= 'where a.page_id='.$this->quoteSmart($pageId);
		$sql .= ' and a.frame_id='.$this->quoteSmart($frameId);
		if(!$deleted){
			$sql .= ' and b.deleted=0';
		}
		return $this->sendQuery($sql);
	}
	
	/**
	 * Gets Page Containers
	 * 
	 * @param  integer $pageId
	 * @param  integer $frameId
	 * @param  boolean $deleted
	 * @return resource	 	 	 	 	 
	 */	 	
	function getPageContainers($pageId, $frameId, $deleted=false){
		$sql  = 'select b.* ';
		$sql .= 'from `'.FRAME_CONTAINERS_TABLE.'` a ';
		$sql .= 'join `'.CONTAINERS_TABLE.'` b on a.container_id=b.id ';
		$sql .= 'where a.page_id='.$this->quoteSmart($pageId);
		$sql .= ' and a.frame_id='.$this->quoteSmart($frameId);
		if(!$deleted){
			$sql .= ' and b.deleted=0';
		}
		return $this->sendQuery($sql);
	}
	
	/**
	 * Gets ContainersList Containers
	 * 
	 * @param  integer $containersListId ContainersList Id
	 * @param  boolean $deleted	 
	 * @return resource	 	 	 
	 */	 	
	function getContainersListContainers($containersListId, $deleted=false){
		$sql  = 'select b.* ';
		$sql .= 'from `'.CONTAINERS_LISTS_CONTAINERS_TABLE.'` a ';
		$sql .= 'join `'.CONTAINERS_TABLE.'` b on a.container_id=b.id ';
		$sql .= 'where a.containers_list_id='.$this->quoteSmart($containersListId);
		if(!$deleted){
			$sql .= ' and b.deleted=0';
		}
		return $this->sendQuery($sql);
	}

	/**
	 * Gets Container Contents
	 *
	 * @param  integer $containerId Container Id
	 * @param  string  $typeName Content Type
	 * @param  boolean $deleted
	 * @return resource
	 */
	function getContainerContents($containerId, $typeName, $deleted=false){
		$sql  = 'select b.* ';
		$sql .= 'from `'.CONTAINER_CONTENTS_TABLE.'` a ';
		$sql .= 'join `'.TYPE_TABLES_PREFIX.$typeName.'` b on a.content_id=b.id ';
		$sql .= 'where a.container_id='.$this->quoteSmart($containerId);
		if(!$deleted){
			$sql .= ' and b.deleted=0';
		}
		return $this->sendQuery($sql);
	}
	
	/**
	 * Gets Container Contents Id
	 *
	 * @param  mixed $containerId
	 * @return resource
	 */
	function getContainerContentsId($containerId){
		$sql  = 'select content_id ';
		$sql .= 'from `'.CONTAINER_CONTENTS_TABLE.'` ';
		$sql .= 'where container_id='.$this->quoteSmart($containerId);
		return $this->sendQuery($sql);
	}

	function &getTemplate($name, $id){
	}
	
	function &getTemplateId($templateName){
	}

	/**
	 * Get static container id from FRAME_CONTAINERS_TABLE.
	 *
	 * @param	integer $frameId frame id.
	 * @param	string $containerName container name.
	 * @return	integer
	 */
	function getStaticContainerId($frameId, $containerName)
	{	
	}	 

	/**
	 * Get static containers list id from FRAME_CONTAINERS_LISTS_TABLE.
	 *
	 * @param	integer $frameId frame id.
	 * @param	string $containersListName containers list name.
	 * @return	integer
	 */
	function getStaticContainersListId($frameId, $containersListName)
	{	
	}	 

	/**
	 * Add record to FRAME_CONTAINERS_TABLE.
	 *
	 * @param	integer $frameId frame id.
	 * @param	integer $pageId page id.
	 * @param	integer $containerId container id.
	 * @param	string $containerName container name.
	 * @return	bool true if record added successfully or false.
	 */
	function addFrameContainer($frameId, $pageId, $containerId, $containerName)
	{	
	}	 

	/**
	 * Add record to FRAME_CONTAINERS_LISTS_TABLE.
	 *
	 * @param	integer $frameId frame id.
	 * @param	integer $pageId page id.
	 * @param 	integer $containersListId containers list id.
	 * @param	string $containersListName containers list name.
	 * @return	bool true if record added successfully or false.
	 */
	function addFrameContainersList($frameId, $pageId, $containersListId, $containersListName)
	{	
	}	
	
	// a verifier
	
	/**
	 * Return SQL SELECT statement
	 *
	 * @param	string	$table
	 * @param	integer	$id
	 * @param	string	$cond WHERE clause
	 * @param	string	$field_id
	 * @param	string	$field_order
	 * @return	string
	 * @final
	 */
	function toSQLSelect($table, $id=-1, $cond='', $field_id='id', $field_order='') {
		if (($id>=0 && $id!='') && $cond) {
			$where = " where `{$field_id}`='{$id}' and {$cond}";
		} elseif ($id>=0 && $id != '') {
			$where = " where `{$field_id}`='{$id}'";
		} elseif ($cond) {
			$where = " where {$cond}";
		} else {
			$where = '';
		}
		$sql = "select * from `{$table}`".$where;	
		$sql .= $field_order? " order by `{$field_order}`;" : ';';
		return $sql;
	}
	
	/**
	 * Return SQL INSERT statement
	 *
	 * @param	string	$table
	 * @param	array	$fieldsv associative array field => value
	 * @return	string
	 * @final
	 * @deprecated
	 */
	function toSQLInsert($table, $fieldv)
	{
		$into = '';
		$values = '';
		foreach ($fieldv as $key => $val) {
			//$val = get_magic_quotes_gpc()? $val : addslashes($val);
			$val = $this->quoteSmart($val);
			$into .= "`{$key}`,";
			$values .= "{$val},";
		}
		// remove last ',' char.
		$into = substr($into, 0, -1);
		$values = substr($values, 0, -1);
		$sql = sprintf("insert into `%s` (%s) values (%s);", $table, $into, $values);
		return $sql;
	}
	
	/**
	 * @deprecated
	 */
	function queryInsert($tableName, $fieldsArray) {
		if (!$fieldsArray) {
			$sql = 'insert into `'.$tableName.'` () values ();';
		} else {
			$cols = '';
			$vals = '';
		
			foreach ($fieldsArray as $field => $val) {
				$cols .= '`'.$field.'`,';
				$vals .= $this->quoteSmart($val).',';
			}
			
			$sql = 'insert into `'.$tableName.'` ('.substr($cols, 0, -1).') values ('.substr($vals, 0, -1).');';
		}
		
		return $this->sendQuery($sql);
	}
	
	/**
	 * Return SQL UPDATE statement
	 *
	 * @param	string	$table
	 * @param	integer	$id
	 * @param	array	$fieldsv associative array field => value
	 * @param	string	$cond
	 * @param	string	$field_id
	 * @return	string
	 * @final
	 */
	function toSQLUpdate($table, $id, $fieldv, $cond='', $idField='id')
	{	
		$sql = "update `{$table}` set ";
		foreach ($fieldv as $key => $val) {
			//$val = get_magic_quotes_gpc()? $val : addslashes($val);
			$val = $this->quoteSmart($val);
			$sql .= "`{$key}`={$val},";
		}	
		// remove last ','
		$sql = substr($sql, 0, -1);
		$sql .= " where `{$idField}`='{$id}'"; //<-- vinadelmar got noobified just here
		$sql .= $cond? " and {$cond};" : ';';
        return $sql;
	}
	
	function SQLMUpdate($tableName, $fieldsArray, $idsArray, $idField='id', $cond='')
	{
		$sql  = 'UPDATE `'.$tableName.'` ';
		$sql .= 'SET ';
		
		$fields = '';
		foreach ($fieldsArray as $field => $value) {
			$value = $this->quoteSmart($value);
			$fields .= '`'.$field.'`='.$value.',';
		}
		
		$sql .= substr($fields, 0, -1).' ';
		$sql .= 'WHERE `'.$idField.'` IN ('.implode(',', $idsArray).')';
		
		if ($cond) {
			$sql .= ' '.$cond;
		}
		
		$sql .= ';';
		
		return $sql;
	}
	
	/**
	 * @deprecated
	 */
	function querySelect($tableName, $id=-1, $cond='', $idField='id', $order='')
	{
		$sql = 'select * from `'.$tableName.'`';
		
		if (($id>=0 && $id!='') && $cond) {
			$sql .= ' where `'.$idField.'`=\''.$id.'\' and '.$cond;
		} elseif ($id>=0 && $id != '') {
			$sql .= ' where `'.$idField.'`=\''.$id.'\'';
		} elseif ($cond) {
			$sql .= ' where '.$cond;
		}
		
		if ($order) {
			$sql .= ' order by '.$order;
		}
		
		$sql .= ';';
		
		return $this->sendQuery($sql);
	}
	
	/**
	 * @param  string $tableName
	 * @param  array $fieldsArray
	 * @param  integer $id
	 * @param  string $idField
	 * @param  string $cond
	 * @return mixed boolean or resource
	 * @deprecated
	 */
	function queryUpdate($tableName, $fieldsArray, $id, $idField='id', $cond='')
	{
		$sql = 'update `'.$tableName.'` ';
		
		$fields = '';
		
		foreach ($fieldsArray as $field => $value) {
			$fields .= '`'.$field.'`='.$this->quoteSmart($value).',';
		}
		
		$sql .= 'set '.substr($fields, 0, -1).' ';
		$sql .= 'where `'.$idField.'`='.$id;
		
		if ($cond) {
			$sql .= ' and '.$cond;
		}
		
		$sql .= ';';
		
		return $this->sendQuery($sql);
	}
	
	/**
	 * @param  string $tableName
	 * @param  array $fieldsArray
	 * @param  array $idsArray
	 * @param  string $idField
	 * @param  string $cond
	 * @return mixed boolean or resource
	 * @deprecated
	 */
	function queryMultipleUpdate($tableName, $fieldsArray, $idsArray, $idField='id', $cond='')
	{
		$sql = 'update `'.$tableName.'` ';
		
		$fields = '';
		
		foreach ($fieldsArray as $field => $value) {
			$fields .= '`'.$field.'`='.$this->quoteSmart($value).',';
		}
		
		$sql .= 'set '.substr($fields, 0, -1).' ';
		$sql .= 'where `'.$idField.'` in ('.implode(',', $idsArray).')';
		
		if ($cond) {
			$sql .= ' and '.$cond;
		}
		
		$sql .= ';';

		return $this->sendQuery($sql);
	}
	
	/**
	 * @deprecated use {@link SQLMUpdate}
	 */
	function toSQLUpdateMultipleIds($tableName, $fieldsArray, $idsArray, $idField='id', $cond='')
	{
		$sql  = 'UPDATE `'.$tableName.'` ';
		$sql .= 'SET ';
		
		$fields = '';
		foreach ($fieldsArray as $field => $value) {
			$value = $this->quoteSmart($value);
			$fields .= '`'.$field.'`='.$value.',';
		}
		
		$sql .= substr($fields, 0, -1).' ';
		$sql .= 'WHERE `'.$idField.'` IN ('.implode(',', $idsArray).')';
		
		if ($cond) {
			$sql .= ' '.$cond;
		}
		
		$sql .= ';';
	}
	
	/**
	 * Return SQL DELETE statement
	 *
	 * @param	string	$table
	 * @param	integer	$id
	 * @param	string	$cond WHERE clause
	 * @param	string	$field_id
	 * @return	string
	 * @final
	 */
	function toSQLDelete($table, $id, $cond='', $field_id='id')
	{
		$sql = "delete from `{$table}` where `{$field_id}`='{$id}'";
		$sql .= $cond? " and {$cond};" : ';';
		return $sql;
	}
	
	/**
	 * Execute DELETE Statement
	 * 
	 * @final
	 * @param  string  $tableName
	 * @param  integer $id
	 * @param  string  $cond
	 * @param  string  $idField
	 * @return boolean
	 */
	function queryDelete($tableName, $id, $cond='', $idField='id')
	{
		$sql  = 'delete from `'.$tableName.'` where `'.$idField.'`='.$this->quoteSmart($id);
		$sql .= $cond? ' and '.$cond.';' : ';';
		return $this->sendQuery($sql);
	}
	
	/**
	 * Execute Multiple DELETE Statements
	 *
	 * @param  string $tableName
	 * @param  array  $idsArray
	 * @param  string $cond
	 * @param  string $idField
	 * @return boolean
	 */
	function queryMultipleDelete($tableName, $idsArray, $cond='', $idField='id') 
	{
		$sql  = 'delete from `'.$tableName.'` where `'.$idField.'` in ('.implode(',', $idsArray).')';
		
		if ($cond) {
			$sql .= ' and '.$cond;
		}
		
		$sql .= ';';
		
		return $this->sendQuery($sql);
	}
	
	/**
	 * Execute DROP statement
	 *
	 * @param  string $table
	 * @return boolean
	 * @final
	 */
	function dropTable($table) 
	{
		$sql = "drop table `$table`;";
        return $this->sendQuery($sql);
    }
	
	/**
	 * Execute ALTER statement on given table
	 *
	 * @param  string $table
	 * @param  array  $newColumnsArray
	 * @param  array  $oldColumnsArray
	 * @return boolean
	 * @final
	 */
	function updateTable($table, $newColumnsArray, $oldColumnsArray) 
	{
		$query = "";
        foreach ($newColumnsArray as $key => $value) {
			if (strlen($query))
        	    $query .= ", ";
			$query .= "add `$key` $value not null";
        }
        foreach ($oldColumnsArray as $key => $value) {
			if (strlen($query))
        	    $query .= ", ";
			$query .= "drop `$key`";
        }	
		$query = "alter table `$table` ".$query.";";
        return $this->sendQuery($query);		
	}		
	
	/**
	 * Create new table
	 *
	 * @param  string $table
	 * @param  array  $columnsArray
	 * @return boolean
	 * @final
	 */
	function createTable($table, $columnsArray) 
	{
		$query  = "create table `{$table}` (";
    	$query .= "`id` int not null auto_increment ";
        foreach ($columnsArray as $key => $value) {
	    	$query .= ", `$key` $value not null ";
        } 		
    	$query .= ", primary key (`id`));";
    	//echo $query;
        return $this->sendQuery($query);		
	}
	
	function dbGetPageMenusId($frameId)
	{
		$sql  = 'SELECT menu_id ';
		$sql .= 'FROM '.FRAME_MENUS_TABLE.' ';
		$sql .= 'WHERE frame_id='.$frameId.';';
		return $this->sendQuery($sql);
	}
	
	function dbGetPageContainersIdAndType($pageId, $frameId)
	{
		$sql  = 'SELECT ct.id AS container_id, ct.type_name AS type_name ';
		$sql .= 'FROM '.FRAME_CONTAINERS_TABLE.' fct ';
		$sql .= 'JOIN '.CONTAINERS_TABLE.' ct ON fct.container_id=ct.id ';
		$sql .= 'WHERE page_id='.$pageId.' AND frame_id='.$frameId.' AND ct.deleted=0;';
		return $this->sendQuery($sql);
	}
	
	function dbGetPageContainersListsId($pageId, $frameId)
	{
		$sql  = 'SELECT fcl.containers_list_id AS containers_list_id ';
		$sql .= 'FROM '.FRAME_CONTAINERS_LISTS_TABLE.' fcl ';
		$sql .= 'JOIN '.CONTAINERS_LISTS_TABLE.' cl ON fcl.containers_list_id=cl.id ';
		$sql .= 'WHERE fcl.page_id='.$pageId.' AND fcl.frame_id='.$frameId.';';
		return $this->sendQuery($sql);
	}
	
	function dbGetContainersListContainersIdAndType($containersListId)
	{
		$sql  = 'SELECT ct.id AS container_id, ct.type_name AS type_name ';
		$sql .= 'FROM '.CONTAINERS_LISTS_CONTAINERS_TABLE.' clct ';
		$sql .= 'JOIN '.CONTAINERS_TABLE.' ct ON clct.container_id=ct.id ';
		$sql .= 'WHERE clct.containers_list_id='.$containersListId.' AND ct.deleted=0;';
		return $this->sendQuery($sql);
	}
	
	function dbGetContainerContentsId($containerId, $contentType)
	{
		$sql  = 'SELECT ctn.id AS content_id ';
		$sql .= 'FROM '.CONTAINER_CONTENTS_TABLE.' ctctn ';
		$sql .= 'JOIN '.TYPE_TABLES_PREFIX.$contentType.' ctn ON ctctn.content_id=ctn.id ';
		$sql .= 'WHERE ctctn.container_id='.$containerId.' AND ctn.deleted=0;';
		return $this->sendQuery($sql);
	}
	
	/**
	 * Gets Contents From Container
	 *
	 * @param  integer $containerId
	 * @param  string  $contentType
	 * @param  boolean $get_deleted
	 * @return mixed resource or false
	 */
	function queryGetContents($containerId, $contentType, $get_deleted=false)
	{
		$sql  = '';
		$sql .= 'select ct.* ';
		$sql .= 'from `'.CONTAINER_CONTENTS_TABLE.'` ccts ';
		$sql .= 'join `'.TYPE_TABLES_PREFIX.$contentType.'` ct on ccts.content_id=ct.id ';
		$sql .= 'where ccts.container_id='.$containerId;
		$sql .= !$get_deleted? ' and ct.deleted=0;' : ';';
		
		return $this->sendQuery($sql);
	}
	
	/**
	 * @param  integer $pageId
	 * @param  integer $frameId
	 * @param  integer $containerId 0 to get all
	 * @param  boolean $get_deleted get deleted containers
	 * @return mixed resource or false
	 */
	function queryGetContainersFromPage($pageId, $frameId, $get_deleted=false)
	{
		$sql  = '';
		$sql .= 'select';
		$sql .= ' c.id as container_id, ';
		$sql .= ' c.acl_id as container_acl_id, ';
		$sql .= ' c.type_name as container_type_name ';
		$sql .= 'from `'.FRAME_CONTAINERS_TABLE.'` fcs ';
		$sql .= 'join `'.CONTAINERS_TABLE.'` c on fcs.container_id=c.id ';
		$sql .= 'where fcs.page_id='.$pageId;
		$sql .= ' and fcs.frame_id='.$frameId;
		$sql .= !$get_deleted? ' and c.deleted=0;' : ';';
		
		return $this->sendQuery($sql);
	}
	
	function queryGetContainersFromList($containersListId, $get_deleted=false)
	{
		$sql  = '';
		$sql .= 'select';
		$sql .= ' c.id as container_id, ';
		$sql .= ' c.acl_id as container_acl_id, ';
		$sql .= ' c.type_name as container_type_name ';
		$sql .= 'from `'.CONTAINERS_LISTS_CONTAINERS_TABLE.'` clcs ';
		$sql .= 'join `'.CONTAINERS_TABLE.'` c on clcs.container_id=c.id ';
		$sql .= 'where clcs.containers_list_id='.$containersListId;
		$sql .= !$get_deleted? ' and c.deleted=0;' : ';';
		
		return $this->sendQuery($sql);
	}
	
	/**
	 * Gets Containers Lists
	 *
	 * Retrieve all containers lists from given page and frame id
	 *
	 * @author vinadelmar <vinadelmar@users.sourceforge.net>
	 * @since  2006-03-30
	 * @param  integer $pageId
	 * @param  integer $frameId
	 * @param  integer $load_deleted
	 * @return mixed resource or false
	 */
	function queryGetContainersLists($pageId, $frameId, $get_deleted=false)
	{
		$sql  = '';
		$sql .= 'select';
		$sql .= ' cl.id as containers_list_id, ';
		$sql .= ' cl.acl_id as containers_list_acl_id ';
		$sql .= 'from `'.FRAME_CONTAINERS_LISTS_TABLE.'` fcls ';
		$sql .= 'join `'.CONTAINERS_LISTS_TABLE.'` cl ';
		$sql .= 'where fcls.page_id='.$pageId;
		$sql .= ' and fcls.frame_id='.$frameId;
		$sql .= !$get_deleted? ' and cl.deleted=0;' : ';';
		
		return $this->sendQuery($sql);
	}
	
	/**
	 * Get All Menus
	 *
	 * @param  integer $frameId
	 * @return resource false if error
	 */
	function queryGetMenus($frameId)
	{
		$sql  = '';
		$sql .= 'select';
		$sql .= ' mnu.id as menu_id, ';
		$sql .= ' mnu.acl_id as menu_acl_id ';
		$sql .= 'from `'.FRAME_MENUS_TABLE.'` fmnus ';
		$sql .= 'join `'.MENUS_TABLE.'` mnu on fmnus.menu_id=mnu.id ';
		$sql .= 'where fmnus.frame_id='.$frameId.';';
		
		$this->sendQuery($sql);
	}
	
	function queryGetAllGroups($get_users, $groupsIdsArray)
	{	
		$SQL  = 'SELECT gr.id AS group_id, gr.name AS group_name, gr.description AS group_description ';
		
		if ($get_users)
			$SQL .= ', grusr.id AS user_id ';
			
		$SQL .= 'FROM '.GROUPS_TABLE.' gr ';
		
		if ($get_users)
			$SQL .= 'JOIN '.GROUP_USERS_TABLE.' grusr ON grusr.group_id=gr.id ';
			
		if (!is_null($groupsIdsArray) && !empty($groupsIdsArray)) {
			$SQL .= 'where gr.id in ('.implode(',', $groupsIdsArray).') ';
		}
			
		$SQL .= 'ORDER BY group_name;';
		
		return $this->sendQuery($SQL);
	}
	
	function queryGetAllUsers($get_groups, $usersIdsArray)
	{
		$sql  = '';
		$sql .= 'select usr.id as user_id, usr.login as user_login, usr.password ';
		$sql .= 'as user_password, usr.lang_id as user_lang_id ';
		
		if ($get_groups)
			$sql .= ', grusrs.group_id as user_group_id ';
			
		$sql .= 'from `'.USERS_TABLE.'` usr ';
		
		if ($get_groups)
			$sql .= 'left join `'.GROUP_USERS_TABLE.'` grusrs on usr.id=grusrs.user_id ';
			
		if (!is_null($usersIdsArray) && !empty($usersIdsArray)) {
			$sql .= 'where usr.id in ('.implode(',', $usersIdsArray).') ';
		}
		
		$sql .= 'order by usr.login asc;';
			
		return $this->sendQuery($sql);
	}
	



	function queryGetContainerIdFromContentId($contentId, $typeName) {
		$sql  = 'select';
		$sql .= ' ct.id as id ';
		$sql .= ' from `'.CONTAINER_CONTENTS_TABLE.'` cct, `'.TYPE_TABLES_PREFIX.$typeName.'` c, `'.CONTAINERS_TABLE.'` ct';
		$sql .= ' where cct.content_id=c.id ';
		$sql .= ' and cct.container_id=ct.id';
		$sql .= ' and cct.content_id='.$contentId.';';
		return $this->sendQuery($sql);
	}

	function getContainersListIdFromContainerId($containerId) {
		$sql  = 'select';
		$sql .= ' clt.id as id ';
		$sql .= ' from `'.CONTAINERS_LISTS_CONTAINERS_TABLE.'` clct, `'.CONTAINERS_LISTS_TABLE.'` clt';
		$sql .= ' where clct.containers_list_id=clt.id ';
		$sql .= ' and clct.container_id='.$containerId.';';
		return $this->sendQuery($sql);
	}

	function getPageIdFromContainerId($containerId) {
		$sql  = '';
		$sql .= 'select';
		$sql .= ' pt.id as id ';
		$sql .= ' from `'.FRAME_CONTAINERS_TABLE.'` fct, `'.PAGES_TABLE.'` pt ';
		$sql .= ' where fct.frame_id=pt.frame_id';
		$sql .= ' and fct.page_id=pt.id';
		$sql .= ' and fct.container_id='.$containerId.';';
		return $this->sendQuery($sql);
	}

	function getPageIdFromContainersListId($containersListId) {
		$sql  = '';
		$sql .= 'select';
		$sql .= ' pt.id as id ';
		$sql .= ' from `'.FRAME_CONTAINERS_LISTS_TABLE.'` fclt, `'.PAGES_TABLE.'` pt ';
		$sql .= ' where fclt.frame_id=pt.frame_id';
		$sql .= ' and fclt.page_id=pt.id';
		$sql .= ' and fclt.containers_list_id='.$containersListId.';';
		return $this->sendQuery($sql);
	}



	/**
	 * @return mixed resource or false
	 * @deprecated
	 */
	function queryGetContentFromContainer($contentId, $contentType)
	{
		$sql  = '';
		$sql .= 'select';
		$sql .= ' c.id as id, ';
		$sql .= ' c.acl_id as acl_id ';
		$sql .= 'from `'.CONTAINER_CONTENTS_TABLE.'` ccns ';
		$sql .= 'join `'.TYPE_TABLES_PREFIX.$contentType.'` cn on ccns.content_id=cn.id ';
		$sql .= 'join `'.CONTAINERS_TABLE.'` c on ccns.container_id=c.id ';
		$sql .= 'where cn.id='.$contentId.';';
		
		return $this->sendQuery($sql);
	}
	
	/**
	 * @param  integer $contentId
	 * @param  string  $typeName
	 * @return mixed resource or false
	 */
	function queryGetContainerOfContent($contentId, $typeName)
	{
		$sql  = 'select';
		$sql .= ' c.id as id, ';
		$sql .= ' c.acl_id as acl_id ';
		$sql .= 'from `'.CONTAINER_CONTENTS_TABLE.'` ccts ';
		$sql .= 'join `'.TYPE_TABLES_PREFIX.$typeName.'` ct on ccts.content_id=ct.id ';
		$sql .= 'join `'.CONTAINERS_TABLE.'` c on ccts.container_id=c.id ';
		$sql .= 'where ccts.content_id='.$contentId.';';
		
		return $this->sendQuery($sql);
	}

	/**
	 * @param  integer $containerId
	 * @return mixed resource or false
	 */
	function queryGetContainersListOfContainer($containerId) {
		$sql  = 'select';
		$sql .= ' cl.id as id, ';
		$sql .= ' cl.acl_id as acl_id ';
		$sql .= ' from `'.CONTAINERS_LISTS_CONTAINERS_TABLE.'` clcs ';
		$sql .= ' join `'.CONTAINERS_LISTS_TABLE.'` cl on clcs.containers_list_id=cl.id ';
		$sql .= ' where clcs.container_id='.$containerId.';';
		return $this->sendQuery($sql);
	}

	/**
	 * @param integer $pageId
	 * @param integer $frameId
	 * @param integer $containerId
	 */
	function queryGetPageOfContainer($pageId, $frameId, $containerId) {
		$sql  = '';
		$sql .= 'select';
		$sql .= ' p.id as id, ';
		$sql .= ' p.acl_id as acl_id ';
		$sql .= ' from `'.FRAME_CONTAINERS_TABLE.'` fcs ';
		$sql .= ' join `'.PAGES_TABLE.'` p on fcs.page_id=p.id ';
		$sql .= ' where fcs.page_id='.$pageId;
		$sql .= ' and fcs.frame_id='.$frameId;
		$sql .= ' and fcs.container_id='.$containerId.';';
		return $this->sendQuery($sql);
	}

	function queryGetPageOfContainersList($pageId, $frameId, $containersListId) {
		$sql  = '';
		$sql .= 'select';
		$sql .= ' p.id as id, ';
		$sql .= ' p.acl_id as acl_id ';
		$sql .= 'from `'.FRAME_CONTAINERS_LISTS_TABLE.'` fcls ';
		$sql .= 'join `'.PAGES_TABLE.'` p on fcls.page_id=p.id ';
		$sql .= 'where fcls.page_id='.$pageId;
		$sql .= ' and fcls.frame_id='.$frameId;
		$sql .= ' and fcls.containers_list_id='.$containersListId;
		$sql .= ';';//' and fcls.containers_list_name=\''.$containersListName.'\';';
		
		return $this->sendQuery($sql);
	}
	
	function queryGetPageOfMenu($pageId, $frameId, $menuId) {
		$sql  = '';
		$sql .= 'select';
		$sql .= ' p.id as id,';
		$sql .= ' p.acl_id as acl_id ';
		$sql .= 'from `'.FRAME_MENUS_TABLE.'` fmnus ';
		$sql .= 'join `'.PAGES_TABLE.'` p on fmnus.frame_id=p.frame_id ';
		$sql .= 'where p.id='.$pageId; 
		$sql .= ' and fmnus.frame_id='.$frameId;
		$sql .= ' and fmnus.menu_id='.$menuId;
		$sql .= ';';//' and fmnus.menu_name=\''.$menuName.'\';';
		
		return $this->sendQuery($sql);
	}
	
	function queryGetPageOfPage($pageId) {
		$sql  = 'select ';
		$sql .= ' p2.id as id, ';
		$sql .= ' p2.acl_id as acl_id ';
		$sql .= 'from `'.PAGES_TABLE.'` p1 ';
		$sql .= 'join `'.PAGES_TABLE.'` p2 on p1.parent_id=p2.id ';
		$sql .= 'where p1.id='.$pageId.';';
		
		return $this->sendQuery($sql);
	}
	
	function queryGetContentVersions($contentId, $contentType) {
		$contentId = $this->quoteSmart($contentId);
		$contentType = $this->quoteSmart($contentType);
		
		$sql  = 'select ';
		$sql .= ' v.id as version_id, ';
		$sql .= ' v.date as version_date, ';
		$sql .= ' usr.login as user_login ';
		$sql .= 'from `'.VERSIONS_TABLE.'` v ';
		$sql .= 'join `'.USERS_TABLE.'` usr on v.user_id=usr.id ';
		$sql .= 'where v.type_name='.$contentType.' ';
		$sql .= 'and v.content_id='.$contentId.' ';
		$sql .= 'order by v.date desc;';
		
		return $this->sendQuery($sql);
	}
	
	/**
	 * Gets Frame Styles
	 *
	 * @param  integer $id Frame Id
	 * @return resource
	 */
	function getFrameStyles($id) {
		$sql  = '';
		$sql .= 'select a.frame_id, b.id, b.file ';
		$sql .= 'from `'.FRAME_STYLES_TABLE.'` a ';
		$sql .= 'join `'.STYLES_TABLE.'` b on a.style_id=b.id ';
		$sql .= 'where a.frame_id in ('.implode(',', (array)$id).')';
		return $this->sendQuery($sql);
	}
	
	/**
	 * Gets Frame Scripts
	 *
	 * @param  integer $id Frame Id
	 * @return resource
	 */
	function getFrameScripts($id) {
		$sql  = '';
		$sql .= 'select a.frame_id, b.id, b.file ';
		$sql .= 'from `'.FRAME_SCRIPTS_TABLE.'` a ';
		$sql .= 'join `'.SCRIPTS_TABLE.'` b on a.script_id=b.id ';
		$sql .= 'where a.frame_id in ('.implode(',', (array)$id).')';
		return $this->sendQuery($sql);
	}
	
	function getUserGroups($id) {
		$sql  = '';
		$sql .= 'select a.id, a.login, a.password, a.lang_id, b.group_id ';
		$sql .= 'from `'.USERS_TABLE.'` as a ';
		$sql .= 'join `'.GROUP_USERS_TABLE.'` as b on (a.id=b.user_id) ';
		$sql .= 'where a.id in ('.implode(',',(array)$id).')';
		return $this->sendQuery($sql);
	}
	/**#@-*/
} 

?>
