<?php
/*
 * This file is part of the easy-CMS project.
 * easy-CMS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * easy-CMS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with easy-CMS; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
/**
 * @package Core
 */

/**
 */
include_once('config.inc.php');
include_once('classes/db/DBConnectionMySQL.class.php');
include_once('classes/core/DBManipulator.class.php');

/**
* Translate functions and types from CMS to DBMS.
*
* @access   private
* @author	Cedric Francoys <cedric.francoys@easy-cms.org>
* @version	DBManipulatorMySQL.class, Sun Nov 14 16:48:15 CET 2004
* @package	Core
*/
class DBManipulatorMySQL extends DBManipulator {
	/**#@+
	 * @access	public
	 */
	/**
	 * Class constructor.
	 * Initialize the DBConnection object for SQL transactions.
	 * 
	 * @param	string	$dbmsType	typeof DBMS.
 	 * @param    string	$host		The hostname of the DB server.
	 * @param    string  $db			The name of the DB.
	 * @param    string  $user		The username to use for the connection to the DB.
	 * @param    string  $pass		The password to use for the connection to the DB.
 	 * @return   void  
	 */	    
	function DBManipulatorMySQL($host, $db, $user, $pass) {
		parent::DBManipulator($host, $db, $user, $pass);
		$this->debug('DBManipulatorMySQL.constructor (@line '.__LINE__.'), succes', 10);
		//$this->dbConnection = new DBConnectionMySQL($host, $db, $user, $pass); to be removed
  }
	
	function connect() {
		if(mysql_connect($this->dbData->getHostName(), $this->dbData->getUserName(), $this->dbData->getPassword())){
        $result = mysql_select_db($this->dbData->getDBName());
        if (!$result) {
          die("No database selected or unknown database name.");
        }
		}
		else {
			die("Unable to establish DB connection : check your parameters.");
		}
		$this->debug('DBManipulatorMySQL::connect(), success : connection established ', 10);
		return $result;
	}
	
	function disconnect() {
		if (!mysql_close()) {
			$this->setLastError(mysql_errno().' : '.mysql_error());
			$this->debug('DBManipulatorMySQL::disconnect(), warning : unable to close DBMS connection.');
			return false;
		}
		$this->debug('DBManipulatorMySQL::disconnect(), success : DBMS connection closed.', 10);
		return true;
	}
	
	/**
	 * 
	 * @since 2006-03-23
	 */
	function quoteSmart($value) {
		if (get_magic_quotes_gpc()) {
			$value = stripslashes($value);
		}
		
		if (!is_numeric($value)) {
			$value = "'".mysql_real_escape_string($value)."'";
		}
		
		return $value;
	}
	
	function sendQuery($sql) {
/*
		static $numQueries=0;
		echo 'Query #', ++$numQueries, ' : ', $sql, '<br/>';
*/
    $this->debug('DBManipulatorMySQL::sendQuery, notice : sending query ('.$sql.')', 10);

		if (($query = mysql_query($sql)) === false) {
			$this->setErrNo(mysql_errno());
			$this->setErrMsg(mysql_error());
			$this->debug('DBManipulatorMySQL::sendQuery, error : QUERY FAILURE('.$sql.')', 3);
			return false;
		}
		
		$this->setAffectedRows(mysql_affected_rows());
		
		if (is_resource($query)) {
			$this->setNumRows(mysql_num_rows($query));
		}
			
    $this->setLastId(mysql_insert_id());
		
    return $query;
	}
	
	function &getColumns($table) {
		$sql = "show full columns from `{$table}`;";
    //$query = "show full columns from `$table`;";
    return $this->sendQuery($sql);
  }

  function getDBMSType($cmsFieldType) {
		$dbmsType = '';
		
        switch ($cmsFieldType) {
		case BOOL:
			$dbmsType = 'TINYINT(1)';
			break;
			
		case INTEGER:
			$dbmsType = 'INT(11)';
			break;
			
		case FLOAT:
			$dbmsType = 'FLOAT';
			break;
			
		case DATE:
			$dbmsType = 'DATE';
			break;
			
		case TIME:
			$dbmsType = 'TIME';
			break;
			
		case COLOR:
			$dbmsType = 'CHAR(6)';
			break;
			
		case REFERENCE:
			$dbmsType = 'CHAR(255)';
			break;
			
		case STRING:
			$dbmsType = 'VARCHAR(255)';
			break;
			
		case SHORTTEXT:
			$dbmsType = 'TEXT';
			break;
			
		case TEXT:
			$dbmsType = 'LONGTEXT';
			break;
			
		case LINK:
			$dbmsType = 'BLOB';
			break;
			
		case DOCUMENT:
			$dbmsType = 'TINYTEXT';
			break;
		case IMAGE:
			$dbmsType = 'TINYBLOB';
			break;
			
		default :
			$dbmsType = -1;
        } 
		
        return $dbmsType;	
	}
	
  function getCMSType($dbFieldType) {
			
        switch (strtoupper($dbFieldType)) {
            case "TINYINT(1)" :
                return BOOL;
                break;
            case "INT(11)" :
                return INTEGER;
                break;
            case "FLOAT" :
                return FLOAT;
                break;
            case "DATE" :
                return DATE;
                break;
            case "TIME" :
                return TIME;
                break;
            case "CHAR(6)" :
                return COLOR;
                break;
            case "CHAR(255)" :
                return REFERENCE;
                break;				
            case "VARCHAR(255)" :
                return STRING;
                break;
            case "TEXT" :
                return SHORTTEXT;
                break;
            case "LONGTEXT" :
                return TEXT;
                break;
            case "BLOB" :
                return LINK;
                break;
            case "TINYTEXT" :
                return DOCUMENT;
                break;
            case "TINYBLOB" :
                return IMAGE;
                break;			
            default :
                break;
        } 
        return -1;
  }
	
	function getFieldsArray($table) {
		$fieldsArray = array();		
    $result = $this->getColumns($table);
    while ($row = $this->fetchArray($result)) {
			$dbFieldName = $this->getDBFieldName($row);
			if ($dbFieldName != 'id' && $dbFieldName != 'lang_id' && $dbFieldName != 'acl_id' && $dbFieldName != 'deleted' && $dbFieldName != 'published') {
				$dbFieldType = $this->getDBFieldType($row);
				$fieldsArray[$dbFieldName] = $this->getCMSType($dbFieldType);
      }
    }
		return $fieldsArray;
	}
	
	function getRecord($tableName, $id=-1, $cond='', $idField='id', $order='') {
		$sql = 'select * from `'.$tableName.'`';		
		if (($id && $id > 0) && $cond) {
			$sql .= ' where `'.$idField.'`='.$this->quoteSmart($id).' and '.$cond;
		}
    elseif ($id && $id > 0) {
			$sql .= ' where `'.$idField.'`='.$this->quoteSmart($id);
		}
    elseif ($cond) {
			$sql .= ' where '.$cond;
		}		
		if ($order) {
			$sql .= ' order by '.$order;
		}		
    return $this->sendQuery($sql);
	}

  function setRecord($tableName, $id, $fieldsArray, $cond='', $idField='id'){
		$sql  = '';
		$sql .= 'update `'.$tableName.'` set ';
		$fields = '';
		foreach ($fieldsArray as $key => $value) {
			$fields .= sprintf('`%s`=%s,', $key, $this->quoteSmart($value));
		}
		$sql .= substr($fields, 0, -1);
		if(($id>0 && $id!='') && $cond){
			$sql .= ' where `'.$idField.'`='.$this->quoteSmart($id);
			$sql .= ' and '.$cond;
		}elseif($id>0 && $id!=''){
			$sql .= ' where `'.$idField.'`='.$this->quoteSmart($id);
		}elseif($cond){
			$sql .= ' where '.$cond;
		}else{
			//too dangerous
			return null;
		}
		return $this->sendQuery($sql);
	}
	
	function addRecord($tableName, $fieldsArray) {
		if (!is_array($fieldsArray)) {
			return null;
		}
		else {
			$cols = '';
			$vals = '';
			foreach ($fieldsArray as $field => $val) {
				$cols .= '`'.$field.'`,';
				$vals .= $this->quoteSmart($val).',';
			}
			$cols = substr($cols, 0, -1); // removes trailing ','
			$vals = substr($vals, 0, -1); // removes trailing ','
			$sql = 'insert into `'.$tableName.'` ('.$cols.') values ('.$vals.');';
		}
		return $this->sendQuery($sql);
	}

	function delRecord($tableName, $id, $cond='', $idField='id') {
		$sql = 'delete from `'.$tableName.'`';
		if ($id && $cond) {
			$sql .= ' where `'.$idField.'`='.$this->quoteSmart($id);
			$sql .= ' and '.$cond;
		}
		elseif ($id) {
			$sql .= ' where `'.$idField.'`='.$this->quoteSmart($id);
		}
		elseif ($cond) {
			$sql .= ' where '.$cond;
		}
		else {
			return null;
		}
		return $this->sendQuery($sql);
	}

	function &fetchRow(&$array) {
		$row =& mysql_fetch_row($array);
    $this->setLastError(mysql_errno()." : ".mysql_error());
		$this->debug("DBConnectionMySQL.fetchRow ($array), status : success.", 10);		
		return $row;
	}

	function fetchArray($resource) {
		return mysql_fetch_array($resource);
	}

	function getDBFieldName($fieldArray) {
        return $fieldArray['Field'];
	}

	function getDBFieldType($fieldArray) {
        return $fieldArray['Type'];
	}

	function getDBFieldKey($fieldArray) {
        return $fieldArray['Key'];
	}

	function getTables($prefix) {
		$sql = 'SHOW TABLES LIKE \''.$prefix.'%\';';
		return $this->sendQuery($sql);
	}

	function getTable($tableName) {
		$sql = 'show tables like \''.$tableName.'\';';
		return $this->sendQuery($sql);
	}
	
	// countRows() n'est pas défini !!!
	function countTypeTables() {
		//$dbConnection = &$this->getDBConnection();	to be removed
		$result =& $this->getTable(TYPE_TABLES_PREFIX);
		return $dbConnection->countRows($result);
	}

	//voir questions-060202
	function tableExists($table) {
		/*
        $result = $this->getTable($table);
        return $this->fetchArray($result);
		*/
		
		$result = $this->getTable($table);
		
		if (!$result || !$this->getNumRows()) {
			return false;
		}
		
		return true;
	}

	function recordExists($table, $id, $cond = '', $idField = 'id') {
		$result = &$this->getRecord($table, $id, $cond, $idField);
		return ($this->fetchArray($result))?true:false;
	}
	
	function typeExists($typeName) {
		return $this->tableExists(TYPE_TABLES_PREFIX.$typeName);
	}

  function pageExists($pageId) {
		return $this->recordExists(PAGES_TABLE, $pageId);
	}

  function containerExists($containerId) {
		return $this->recordExists(CONTAINERS_TABLE, $containerId);
	}
	
	function menuExists($menuId) {
		return $this->recordExists(MENUS_TABLE, $menuId);
	}

	function containersListExists($containersListId) {
		return $this->recordExists(CONTAINERS_LISTS_TABLE, $containersListId);
	}

  function templateExists($typeName, $id) {
		return $this->recordExists(TEMPLATES_TABLE, $id, "`type`='$typeName'");
	}

	/*
    function getContainerContents($id) 
	{
		//$dbConnection = &$this->getDBConnection();	to be removed
		return $this->getRecord(CONTAINER_CONTENTS_TABLE, $id, "", "container_id");
	}
	*/

	/**
	 * @deprecated
	 */
	function &getTemplate($name, $id) {
		//$dbConnection = &$this->getDBConnection(); to be removed
		$result =& $this->getRecord(TEMPLATES_TABLE, $id, "`type`='$name'");
		$row =& $this->fetchArray($result);
		return $row["xsl"];
	}
	
	function &getTemplateId($templateName, $typeName) {
		//$dbConnection = &$this->getDBConnection(); to be removed
		$result =& $this->getRecord(TEMPLATES_TABLE, "", "`name`='$templateName' and `type`='$typeName'");
        $row =& $this->fetchArray($result);
		return $row["id"];
	}

	function getStaticContainerId($frameId, $containerName) {
		//$dbConnection = &$this->getDBConnection(); to be removed
		$result =& $this->getRecord(FRAME_CONTAINERS_TABLE, $frameId, "`container_name`='$containerName'", "frame_id");
	    if(!($row =& $this->fetchArray($result))){
			$this->debug("DBManipulatorMySQL.getStaticContainerId, error : non-existent record.", 2);
			return -1;
		}		
		return $row["container_id"];	
	}	 

	function getStaticContainersListId($frameId, $containersListName) {
		//$dbConnection = &$this->getDBConnection(); to be removed
		$result =& $this->getRecord(FRAME_CONTAINERS_LISTS_TABLE, $frameId, "`containers_list_name`='$containersListName'", "frame_id");
	    if(!($row =& $this->fetchArray($result))){
			$this->debug("DBManipulatorMySQL.getStaticContainersListId, error : non-existent record.", 2);
			return -1;
		}		
		return $row["containers_list_id"];	
	}	 

	function addFrameMenu($frameId, $menuId, $menuName) {
		$fieldsArray["frame_id" ] = $frameId;
		$fieldsArray["menu_id"  ] = $menuId;
		$fieldsArray["menu_name"] = $menuName;
		if(($this->addRecord(FRAME_MENUS_TABLE, $fieldsArray)) <= 0){
			$this->debug("DBManipulatorMySQL.addFrameMenu, error : unable to add new record.", 2);
			return -1;
		}
		return 1;
	}

	function addFrameContainer($frameId, $pageId, $containerId, $containerName) {
		$fieldsArray["frame_id"      ] = $frameId;
		$fieldsArray["page_id"       ] = $pageId;
		$fieldsArray["container_id"  ] = $containerId;
		$fieldsArray["container_name"] = $containerName;
		if(($this->addRecord(FRAME_CONTAINERS_TABLE, $fieldsArray)) <= 0){
			$this->debug("DBManipulatorMySQL.addFrameContainer, error : unable to add new record.", 2);
			return -1;
		}		
		return 1;
	}	 

	function removeFrameContainer($frameId, $pageId, $containerId, $containerName) {
		if(($this->delRecord(FRAME_CONTAINERS_TABLE, $frameId, "`page_id` = '$pageId' and `container_name` = '$containerName' and `container_id` = '$containerId'", 'frame_id')) <= 0){
			$this->debug("DBManipulatorMySQL.removeFrameContainer, error : unable to remove record.", 2);
			return -1;
		}
		return 1;
	}

	function addFrameContainersList($frameId, $pageId, $containersListId, $containersListName) {
		$fieldsArray["frame_id"            ] = $frameId;
		$fieldsArray["page_id"             ] = $pageId;
		$fieldsArray["containers_list_id"  ] = $containersListId;
		$fieldsArray["containers_list_name"] = $containersListName;
		if(($this->addRecord(FRAME_CONTAINERS_LISTS_TABLE, $fieldsArray)) <= 0){
			$this->debug("DBManipulatorMySQL.addFrameContainersList, error : unable to add new record.", 2);
			return -1;
		}		
		return 1;
	}	 

	function &getPageByAlias($alias, $langId) {
		$sql = "SELECT `".PAGES_TABLE."`.`id`, `".NAMES_TABLE."`.`lang_id` FROM `".NAMES_TABLE."` inner join `".PAGES_TABLE."` on `".PAGES_TABLE."`.`alias_id` = `".NAMES_TABLE."`.`id` WHERE `".NAMES_TABLE."`.`value`='".$alias."'";
    if(($result = $this->sendQuery($sql))) {
			$pageId = 0;
	    while(($row = &$this->fetchArray($result))){
				if(!$pageId) {
					$pageId = $row['id'];
				}
				else {
					if($row['lang_id'] == $langId) {
						$pageId = $row['id'];
					}
				}
			}
			return $pageId;
		}
		$this->debug("DBManipulatorMySQL.getPageByAlias, error : unable to send the 'get page' query for page alias '$alias'.", 2);
		return -1;
	}
	/**
	 * Create Content Type Table
	 *
	 * @param  string $typeName
	 * @param  array  $fieldsArray
	 * @return boolean
	 */
	function queryNewContentTable($typeName, $fieldsArray) {
		$tableName = TYPE_TABLES_PREFIX.$typeName;
		
		if ($this->tableExists($tableName)) {
			echo 'already exists';
			return false;
		}
		
		foreach ($fieldsArray as $name => $type) {
			$dbmsType = $this->getDBMSType($type);
			
			if ($dbmsType === -1) {
				echo 'wrong dbms type : name(',$name,') ',$type,' => ', $dbmsType;
				return false;
			}
			
			$fieldsArray[$name] = $dbmsType;
		}
		
		// mandatory fields
		$fieldsArray['published'] = $this->getDBMSType(constant('INTEGER'));
		$fieldsArray['lang_id'] = $this->getDBMSType(constant('INTEGER'));
		$fieldsArray['acl_id']  = $this->getDBMSType(constant('INTEGER'));
		$fieldsArray['deleted'] = $this->getDBMSType(constant('BOOL'));
		
		return $this->createTable($tableName, $fieldsArray);
	}
	
	/**
	 * Create content type
	 *
	 * @author vinadelmar <vinadelmar@users.sourceforge.net>
	 * @since  2006-02-10
	 * @param  string $typeName
	 * @param  array  $descrv associative array fieldName=>cmsType
	 * @return boolean false if error
	 * @deprecated
	 */
	function createContentType($typeName, $descrv) {
		$tableName = TYPE_TABLES_PREFIX.$typeName;
		
		$qry = $this->getTable($tableName);
		
		if ($this->getNumRows()>0) {
			$this->debug("DBManipulatorMySQL::createContentType(), warning : '{$typeName}' type already exists");
			return false;
		}
		
		foreach ($descrv as $fieldName => $cmsType) {
			$dbmsType = $this->getDBMSType($cmsType);
			if ($dbmsType==-1) {
				$this->debug("DBManipulatorMySQL::createContentType(), error : CMS type '{$cmsType}' unknown");
				return false;
			}
			$descrv[$fieldName] = $dbmsType;
		}
		
		if ($descrv['id']) {
			unset($descrv['id']);
		}
		
		if (!$descrv['published']) {
			$descrv['published'] = $this->getDBMSType(constant('INTEGER'));
		}

		if (!$descrv['lang_id']) {
			$descrv['lang_id'] = $this->getDBMSType(constant('INTEGER'));
		}
		
		if (!$descrv['acl_id']) {
			$descrv['acl_id'] = $this->getDBMSType(constant('INTEGER'));
		}
		
		if (!$descrv['deleted']) {
			$descrv['deleted'] = $this->getDBMSType(constant('BOOL'));
		}
		
		if ($this->createTable($tableName, $descrv)==true) {
			$this->debug("DBManipulatorMySQL::createContentType, success : new content type '{$typeName}' created.");
			return true;
		}
    else {
			$this->debug("DBManipulatorMySQL::createContentType, warning : new content type '{$typeName}' not created.");
			return false;
		}
		
		return $qry;
	}
	/**#@-*/
} 

?>