<?php
/*
 * This file is part of the easy-CMS project.
 * easy-CMS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * easy-CMS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with easy-CMS; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
/**
 * @package Core
 */

/**
 */
include_once('classes/core/CoreObject.class.php');

/**
 * Manager for session vars.
 *
 * @access   public
 * @author	Cedric Francoys <cedric.francoys@easy-cms.org>
 * @version	SessionVarsManager.class, Sun Nov 14 16:37:25 CET 2004
 * @package	Core
 */
class SessionVarsManager extends CoreObject {
	/**
	 * Class Constructor
	 *
	 */
	function SessionVarsManager() {
		if (!session_id()) {
			session_start();
		}
  }
	   
  function translateVarName($name) {
  	return $this->siteName."_".$name;
  }
  
  function storeVar($name, &$value) {
    if (isset($_SESSION[$name]) && $_SESSION[$name] != null) {
      $this->debug("SessionVarsManager.storeVar, warning : var '$name' already defined (var overwritten).", 4);
    }
    $_SESSION[$name] = &serialize($value);
  } 

  function removeVar($name) {
    $_SESSION[$name] = null;
  }

  function removeAllVars() {
    foreach ($_SESSION as $key => $value) {
      $this->removeVar($key);
    }
  }

  function checkVar($name) {
    return (isset($_SESSION[$name]) && $_SESSION[$name] != null);
  } 

  function &getVar($name, $defaultValue = null) {
    if (!$this->checkVar($name)) {
      return $defaultValue;
    }
    return unserialize($_SESSION[$name]);
  }
} 

?>