<?php
/*
 * This file is part of the easy-CMS project.
 * easy-CMS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * easy-CMS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with easy-CMS; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/**
 * @package Core
 */

/**
 */
include_once('classes/core/CoreObject.class.php');
include_once('classes/core/ValuesArray.class.php');
include_once('classes/core/FamilyManager.class.php');
include_once('classes/core/DBManipulatorsManager.class.php');
include_once('classes/core/ACL/ACL.class.php');
include_once('classes/core/ACL/ACLManager.class.php');
include_once('classes/core/users/User.class.php');
include_once('classes/core/users/UsersManager.class.php');
include_once('classes/core/groups/Group.class.php');
include_once('classes/core/groups/GroupsManager.class.php');
include_once('classes/core/frames/Frame.class.php');
include_once('classes/core/frames/FramesManager.class.php');
include_once('classes/core/pages/Page.class.php');
include_once('classes/core/pages/PagesManager.class.php');
include_once('classes/core/types/TypesManager.class.php');
include_once('classes/core/menus/MenusManager.class.php');
include_once('classes/core/menuNodes/MenuNodesManager.class.php');
include_once('classes/core/contents/ContentsManager.class.php');
include_once('classes/core/containers/ContainersManager.class.php');
include_once('classes/core/containersLists/ContainersListsManager.class.php');
include_once('classes/core/versions/ContentVersionsManager.class.php');
include_once('classes/core/CacheManager.class.php');
include_once('classes/core/HTMLManager.class.php');
include_once('classes/core/forms/FormsManager.class.php');

include_once('classes/core/URL.class.php');


// Temporary solution for the singleton implementation (static method doesn't work).
// Should be imporved with php5
$GLOBALS['site_instance'] = null;

/**
 * Site object : easy-CMS main element
 *
 * @author	Cedric Francoys <cedric.francoys@easy-cms.org>
 * @version	Site.class, Thu Dec 02 20:47:30 CET 2004
 * @package	Core
 */
class Site extends CoreObject {
	/**#@+
	 * @access	private
	 */

	/**
	 * @var object
	 */
	var $dbManipulator;

	/**
	 * @var object
	 */
  var $dbManager;

	/**
	 * @var object
	 */
	var $familyManager;

	/**
	 * @var object
	 */
	var $ACLManager;

	/**
	 * @var object
	 */
	var $usersManager;

	/**
	 * @var object
	 */
	var $groupsManager;

	/**
	 * @var object
	 */
	var $typesManager;

	/**
	 * @var object
	 */
	var $framesManager;

	/**
	 * @var object
	 */
	var $templatesManager;

	/**
	 * @var object
	 */
	var $pagesManager;

	/**
	 * @var object
	 */
	var $menusManager;

	/**
	 * @var object
	 */
	var $menuNodesManager;

	/**
	 * @var object
	 */
	var $containersListsManager;

	/**
	 * @var object
	 */
	var $containersManager;

	/**
	 * @var object
	 */
	var $contentsManager;

	/**
	 * @var object
	 */
  var $contentVersionsManager;

	/**
	 * @var object
	 */
	var $cacheManager;

	/**
	 * @var object
	 */
	var $formsManager;

	/**
	 * @var integer
	 */
	var $defaultPageId;
	var $defaultLangId;
	var $defaultDebugLevel;
	var $defaultMode;

	/**
	 * get values
	 *
	 * @var array
	 */
	var $getArray;

	/**
	 * post values
	 *
	 * @var	array
	 */
	var $postArray;

	/**
	 * session values
	 *
	 * @var array
	 */
	var $sessionArray;

	var $name;

	/**
	 * Class constructor.
	 * Initialize the Site object and the associated variables.
	 *
 	 * @param    integer  The default page (pid) of the site.
 	 * @param    string   The default mode in which the site is to be displayed.
 	 * @param    integer  The default language in which the site is to be displayed.
 	 * @return   void
	 */
	function Site($defaultPageId=1, $defaultMode=VIEW_MODE, $defaultLangId=1, $defaultDebugLevel=0) {
		$this->debug('Site::__construct, status : constructor invoked', 10);

		// set the default values
		$this->defaultMode        = $defaultMode;
		$this->defaultPageId      = $defaultPageId; // homepage
		$this->defaultLangId      = $defaultLangId; // default language
		$this->defaultDebugLevel  = DEBUG_LEVEL;

		// init the object used to communicate with the DBMS
		$this->dbManager = &new DBManipulatorsManager(DB_CONNECTION_DBMS,
                                                  DB_CONNECTION_HOST,
                                                  DB_CONNECTION_DB,
                                                  DB_CONNECTION_USER,
                                                  DB_CONNECTION_PASS);

		$this->dbManipulator = &$this->dbManager->getDBManipulator();
		$this->dbManipulator->connect();

		// init the session if necessary
		if(strlen(session_id()) <= 0){
			session_start();
		}

		// $_GET and $_POST arrays are used by the user to send data to easy-CMS
		$this->getArray		= new ValuesArray($_GET);
		$this->postArray	= new ValuesArray($_POST);
		// data are stored into the $_SESSION array for persistence between pages requests
		$this->sessionArray	= new ValuesArray($_SESSION, $this->name, true);

		// we are displaying a page of the website, not an UI element (form or admin page)
		if($this->getSubmittedVar('display', RENDER) == RENDER){
			// check the URL for easy navigation (allow use of back and forward buttons)
			$this->checkURL();
		}

		// register vars that need to be persistent
		$this->registerVars();

		// special chars not allowed in the site name
		$specialChars = array(".", ":", ";", "/", "\\", "-", "_", "@");
		// the site name is based on the server name (DNS) and the root directory holding the web site (containing index.php)
		$this->name = str_replace($specialChars, "", $this->getHostName().$this->getScriptPath());
  }

	function getDefaultLangId() {
		return $this->defaultLangId ;
	}

	function getClassName(){
		return 'Site';
	}

	// todo
	function getRootPageId() {
		return 1;
	}

	// todo
	function getRootAclId() {
		return 1;
	}

 	/**
	 * The class destructor. !!At this time this function need to be called manually.!!
	 * Waiting for a better implementation of OOP mechanisms (with PHP 5).
	 *
	 * @return   void
	 */
	function siteDestructor()	{
		$this->dbManipulator->disconnect();
		$this->savePersistentVars();
		$now = date("D M j G:i:s Y");
		$this->debug("Page generation complete.\n*\n*\nABOVE DEBUG INFORMATIONS GENERATED ON : $now\n*\n*", 0);
		exit(1);
	}

	/**
	 * Gets Site Instance
	 *
	 * Returns a reference to the site instance. The site object is
	 * used as singleton.
	 *
	 * @static
	 * @return object
	 */
	function &getInstance()	{
		if (is_null($GLOBALS['site_instance'])) {
			$GLOBALS['site_instance'] = &new Site();
		}
		return $GLOBALS['site_instance'];
	}

	/**
	 * Gets DBManipulator
	 *
 	 * @return object
	 */
	function &getDBManipulator() {
		return $this->dbManipulator;
	}

  /**
	 * Gets Site Name
	 *
	 * The name of the site is a string (unique id) based on the host name
	 * and the path to easy-CMS scritps
	 *
 	 * @return string
	 * @deprecated
	 */
	function getName(){
		return $this->name;
	}

	/**
	 * Gets Site Name
	 *
	 * The name of the site is a string (unique id) based on the host name
	 * and the path to easy-CMS scritps
	 *
	 * @return string
	 */
	function getSiteName(){
		return $this->name;
	}

	/**
	 * Returns the postArray
	 *
 	 * @return   array
	 * @todo check deprecation
	 */
	function &getPostArray(){
    return $this->postArray;
	}

	/**
	 * Returns the getArray
	 *
	 * @return array
	 * @todo check deprecation
	 */
	function &getGetArray(){
    return $this->getArray;
	}

	/**
	 * Returns the sessionArray
	 *
	 * @return   array
	 * @todo check deprecation
	 */
	function &getSessionArray() {
    	return $this->sessionArray;
	}

	/**
	 * Returns the name of the server hosting the easy-CMS scripts reside
	 *
	 * @return   string
	 */
	function getURL() {
    	return  $_SERVER['SERVER_NAME'].$_SERVER['REQUEST_URI'];
	}

  /**
	 * Returns the name of the server hosting the easy-CMS scripts reside
	 *
	 * @return string
	 */
	function getHostName() {
    	return $_SERVER["SERVER_NAME"];
	}

	/**
	 * Extracts the path of the current script (format is [dir1]/[dir2]/[dir3])
	 *
	 * @return string
	 */
	function getScriptPath() {
    	$dirName = dirname($_SERVER["PHP_SELF"]);
    	// remove the first slash
    	return substr($dirName, 1);
	}

	/**
	 * Gets Script Name
	 *
	 * The filename of the script currently running
	 *
 	 * @return string
	 */
	function getScriptName() {
    	return basename($_SERVER["PHP_SELF"]);
	}

    /**
	 * Gets Location
	 *
	 * The name of the site is a string (unique id) based on the host name
	 * and the path to easy-CMS scritps
	 * i.e. : http://machine.domain.extention/path/scriptname
	 *
 	 * @return string
	 */
	function getLocation() {
		$scriptPath = $this->getScriptPath();
		$location = "http://".$this->getHostName();
		if(strlen($scriptPath)) {
           $location .= "/".$scriptPath;
		}
		return $location."/".$this->getScriptName();
	}


	function redirectTo($location) {
		$sname = session_name();
		$sid = session_id();
		if( strlen($sid) < 1 ) {
		   header("Location: ".$location);
		   exit();
		}
		if( isset( $_COOKIE[$sname] ) || strpos($location, $sname."=".$sid) !== false ) {
		   header("Location: ".$location);
		   exit();
		}
		else {
			if( strpos( $location, "?" ) > 0 ) {
				$separator = "&";
			}
			else {
				$separator = "?";
			}
			$fixed = $location . $separator . $sname."=".$sid;
			header("Location: ".$fixed);
			exit();
		}
	}

	/**
	 * Returns the value of a submitted variable.
	 *
	 *
 	 * @param    string   The name of the variable for which we want the associated value.
 	 * @param    object   The value to assigned by default (if no value has been given).
 	 * @return   string
	 */
	function getSubmittedVar($varName, $defaultValue=null) {
		if (isset($_POST[$varName])) {
			$value = $_POST[$varName];
		}
		elseif (isset($_GET[$varName])) {
			$value = $_GET[$varName];
		}
		else {
			$value = $defaultValue;
		}
		$this->debug("Site::getSubmittedVar(), status : valueof `{$varName}` is {$value}", 10);
		return $value;
	}

	function setSubmittedVar($varName, $value) {
		$_POST[$varName] = &$value;
	}

	/**
	 * Returns the value of a persistent variable.
	 *
	 *
 	 * @param    string   The name of the variable for which we want the associated value.
 	 * @param    object   The value to assigned by default (if no value has been given).
 	 * @return   string
	 */
	function &getPersistentVar($varName, $defaultValue = null){
		if(($value = $this->sessionArray->getVar($varName)) == null){
			$this->debug("Site.getPersistentVar($varName), warning : missing variable (default value is '$defaultValue').", 3);
			return $defaultValue;
		}
		$this->debug("Site.getPersistentVar($varName), status : success (value is '$value').", 10);
		return $value;
	}

	/**
	* Assigns a value to a specified persistent var.
	*
 	*
	* @param    string    The name of the var.
 	* @param    object    The value we want the var to be assigned to.
	* @return   void
	*/
	function setPersistentVar($varName, $value){
		$this->debug("Site.setPersistentVar($varName) invoked for value '$value'.", 10);
		$this->sessionArray->storeVar($varName, $value);
	}

	/**
	* Removes the specified persistent var.
	*
 	* @access   private
	* @param    string    The name of the var we want to remove.
	* @return   void
	*/
	function deletePersistentVar($varName){
		$this->debug("Site.deletePersistentVar($varName), removing var '$varName'.", 10);
		$this->sessionArray->removeVar($varName);
	}

	/**
	* Removes all persistent vars.
	*
 	* @access   private
	* @return   void
	*/
	function deletePersistentVars(){
		$this->debug("Site.deletePersistentVars, removing all persistent vars.", 10);
		$this->sessionArray->removeAllVars();
    session_destroy();
	}

	/**
	* Copies all persistent vars to the PHP $_SESSION array.
	*
 	* @access   private
	* @return   void
	*/
	function savePersistentVars(){
		$this->debug("Site.savePersistentVars, saving persistent vars to _SESSION array.", 10);
		// copy the persistent vars into the PHP global _SESSION array
		$this->sessionArray->copyTo($_SESSION);
	}

	function getCurrentURL($includeVars=true) {
		if(($pid = $this->getPersistentVar("pid")) == null) {
			$pid = $this->defaultPageId;
		}
		$url = $this->getLocation()."?pid=$pid";

		// add non-persistent vars to the URL
		// ? urlencode necessary
		if($includeVars) {
			// GET vars
			foreach($this->getArray->getValuesTable() as $key => $value){
				if($key != 'pid') {
					$url .= "&{$key}={$value}";
				}
			}
			// POST vars
			// what for long POST vars ?
			foreach($this->postArray->getValuesTable() as $key => $value){
				if($key != 'pid') {
					$url .= "&{$key}={$value}";
				}
			}
		}
		return $url;
	}

	/**
	 * Check if the URL encloses the pid (to be navigation friendly) and reloads the page if necessary.
	 *
	 * @access   private
	 */
	function checkURL() {
		// check if the URL contains a page alias
		if($this->getSubmittedVar('resolve_alias', false)) {
		  $langId = $this->getPersistentVar("lid", $this->getDefaultLangId());
		  $pagesManager = &$this->getPagesManager();
			$path = explode('/', $_SERVER['REQUEST_URI']);
			for($i=1; isset($path[$i]) && $path[$i] == $this->getScriptPath(); ++$i);
			$pageAlias = $path[$i];
			if($pos = strpos($path[$i], '?')) {
				$pageAlias = substr($path[$i], 0, $pos);
			}
			if( !isset($path[$i]) || ($page = &$pagesManager->getPageByAlias($pageAlias, $langId)) <= 0){
				//unexistent page
				header('HTTP/1.0 404 Not Found');
				print('<html><header><title>Page Not Found</title></header><body>Sorry but the page you requested was not found on this server.</body></html>');
				die();
			}
			else {
				header('HTTP/1.0 200 OK');
				header('Status: 200 OK');
				$pid = $page->getPageId();
				$this->setPersistentVar('pid', $pid);
				$this->setSubmittedVar('pid', $pid);
			}
		}

		$display = $this->getSubmittedVar('display', RENDER);
		// the pid must be in the url (to be navigation friendly)
		if($display == RENDER && $this->getSubmittedVar("pid") == null && $this->getScriptName() == "index.php"){
			if(($pid = $this->getPersistentVar("pid")) == null) {
				//$pid = $this->defaultPageId;
				//$this->postArray->storeVar("pid", $this->defaultPageId);
				$this->setPersistentVar('pid', $this->defaultPageId);
			}
			else {
				$url = $this->getCurrentURL();
				$this->redirectTo($url);
				exit();
			}
		}
	}

	/**
	 * Retrieves the actual value of a variable and stores it as persistent.
	 *
 	 * @access private
	 * @param  string $varName
	 * @param  mixed $defaultValue
	 * @return void
	 */
	function registerVar($varName, $defaultValue) {
		if (($value = $this->getSubmittedVar($varName)) == null){
			$value = $this->getPersistentVar($varName, $defaultValue);
		}
		$this->setPersistentVar($varName, $value);
	}

	/**
	* Manage the registration of the site's variables.
	*
	*
 	* @access   private
	* @return   void
	*/
	function registerVars() {
		// check if some action is required
		if(($action = $this->getSubmittedVar("action")) != null){
			switch($action) {
				case LOGIN :
					// check if both user and password variables have been posted
					if(($userName = $this->getSubmittedVar("login")) != null && ($password = $this->getSubmittedVar("password")) != null){
						$usersManager = &$this->getUsersManager();
						if (($user = &$usersManager->getUser($usersManager->getUserId($userName, $password))) <= 0){
							//unknown user or mismatch error
						}
						else {
							$lid = $user->getUserLangId();
							$homePageId = $user->getUserHomePageId();
							$this->setPersistentVar('user', $user);
							$this->setPersistentVar('user_id', $user->getUserId());
							$this->setPersistentVar('lid', $lid);
							// check if a redirection to user's homepageis required
							if($this->getPersistentVar('pid', $this->defaultPageId) != $homePageId) {
								$pagesManager = &$this->getPagesManager();
								if($pagesManager->pageExists($homePageId)) {
									$this->setPersistentVar('pid', $homePageId);
									$this->savePersistentVars();
									$url = $this->getCurrentURL(false);
									$this->redirectTo($url);
									exit();
								}
							}
						}
					}
					else{
						$this->debug('Site::registerVars, warning : login process not initiated');
          }
					break;
				case LOGOUT :
						$this->deletePersistentVars();
					break;
				default :
					break;
			}
		}

		// some vars need to be persistent (pid, lid, mode, ... more to come)
		$this->registerVar('lid', $this->defaultLangId);
		$this->registerVar('debug', $this->defaultDebugLevel);
		$this->registerVar('pid', $this->defaultPageId);

		$pagesManager = &$this->getPagesManager();
		if(!$pagesManager->pageExists($this->getSubmittedVar("pid", $this->defaultPageId))){
			// page does not exist
			$this->setPersistentVar('pid', $this->defaultPageId);
		}

		if(($mode = $this->getSubmittedVar('mode')) == null){
			$mode = $this->getPersistentVar('mode', $this->defaultMode);
		}

		if ($mode == VIEW_MODE) {
			$this->setPersistentVar('mode', $mode);
		}
		else {
			// only identified users can switch to edit mode
			if ($this->getCurrentUserId() != USER_ID_ANONYMOUS && $mode == EDIT_MODE) {
				// the mode var can be set persistent only when walue is either EDIT_MODE or VIEW_MODE
				$this->setPersistentVar('mode', $mode);
			}
		}
	}

	/**
	 * Returns a constant-string corresponding to the current mode
	 *
	 *
	 * @return   string
	 */
	function getCurrentMode(){
		if($this->getPersistentVar("mode") != null) {
			$mode = &$this->getPersistentVar("mode");
		}
		else {
			// default mode
			$mode = &$this->defaultMode;
		}
		return $mode;
	}

	/**
	 * @return integer
	 */
	function &getCurrentUserId() {
		$user = &$this->getCurrentUser();
		return $user->getUserId();
	}

	/**
	 * @return object
	 */
	function &getCurrentUser() {
		$user = &$this->getPersistentVar('user', null);
		if (is_null($user)) {
			// create an anonymous user
			$usersManager = &$this->getUsersManager();
			$userId = &$this->getPersistentVar('user_id', 0);
			if($userId) {
				$user = &$usersManager->getUser($userId);
			}
			else {
				if (is_null($anonymousUser = &$usersManager->getUser(USER_ID_ANONYMOUS))) {
	        $this->debug("Site::getCurrentUser, error : unable to load ANONYMOUS (id=".USER_ID_ANONYMOUS.")user.", 2);
				}
	      else {
	        $this->debug("Site::getCurrentUser, notice : unidentified user, switching to anonymous user", 8);
	        $this->setPersistentVar('user', $anonymousUser);
	        $this->setPersistentVar('user_id', USER_ID_ANONYMOUS);
	        $user = &$anonymousUser;
	      }
			}
		}

		return $user;
	}

	function setCurrentUser(&$user) {
	}

	/**
	 * Gets Id of the current page
	 *
	 * @return integer
	 */
	function getCurrentPageId() {
		$pid = $this->getPersistentVar('pid');
		return $pid;
	}

	/**
	 * Gets Current Page
	 *
	 * @return object
	 */
	function &getCurrentPage($loadFrame=true, $loadAcl=true) {
		$pid = $this->getPersistentVar('pid');
		$pagesManager = &$this->getPagesManager();

		if (!($page = $pagesManager->getPage($pid))) {
			$this->debug('Site::getCurrentPage, error : unable to get page #'.$pid, 3);
			return null;
		}

		if (!$page->getPageFrame()) {
			$framesManager = &$this->getFramesManager();
			$frame = &$framesManager->getFrame($page->getPageFrameId());
			$page->setPageFrame($frame);
		}

		if (!$page->getPageAcl()) {
			$aclManager = &$this->getACLManager();
			$acl = &$aclManager->getACL($page->getPageAclId());
			$page->setPageAcl($acl);
		}

		return $page;

		// if page does not exist then display the default page
		/*
		if (!$pagesManager->pageExists($pid)) {
			$pid = $this->defaultPageId;
    	}
		*/

    	// return a reference to the page object
		//return $pagesManager->getPage($pid);
	}

	/**
	 * Returns the html code of a given page object.
	 *
 	 * @param    object   A reference to the page object we want to be displayed.
 	 * @return   string
	 */
	function &generatePageHTML(&$page) {
		// must be improved (multi-caching and user rights recognition)
		if(!is_object($user = &$this->getCurrentUser())) {
      // error : user object missing
      $this->debug("Site.generatePageHTML(), error : missing object user.", 1);
      return -1;
		}

		$langId = $this->getPersistentVar("lid");

		// check redirection
		if(strlen($page->getPageLink()) > 0) {
			if($url=$page->getPageURL()) {
				$this->redirectTo($url);
				exit(0);
			}
		}

		// static environment
		if ($user->getUserId() == USER_ID_ANONYMOUS) {
			$cacheManager = &$this->getCacheManager();
			// get the final HTML code from cache
			$html = &$cacheManager->getHTML($page, $langId);
		}
		// dynamic environment
		else {
			// get start time
			$mtime = microtime();
			$startTime = explode(" ", $mtime);
      $mode = $this->getPersistentVar("mode");

			$aclManager = &$this->getACLManager();

			$acl = &$aclManager->getACL($page->getPageAclId());

			$user = &$this->getCurrentUser();

			if ($acl->userHasViewRight($user) && ($mode == EDIT_MODE || $page->isPublished())) {

				$htmlManager = &new HTMLManager($page->getPageTitle($langId),NORMAL_HEADER,'', $mode);

				// add some meta tags
				$htmlManager->addMeta("Description", $page->getPageDescription($langId));
				$htmlManager->addMeta("Keywords", $page->getPageKeywords($langId));

				$cmsPath = &$this->getScriptPath();

				// add easy-CMS specific styles only in edit mode
        if($mode == EDIT_MODE) {
					if(strlen($cmsPath)) {
						$fullPath = "/$cmsPath/includes/html/styles/style.css";
          }
					else {
						$fullPath = "/includes/html/styles/style.css";
          }
					$htmlManager->addStyle($fullPath);
				}

				// add easy-CMS specific scripts
				if(strlen($cmsPath)) {
					$fullPath = "/$cmsPath/includes/html/scripts/scripts.js";
        }
				else {
					$fullPath = "/includes/html/scripts/scripts.js";
        }
				$htmlManager->addScript($fullPath);

				// add page specific scripts
				foreach($page->getHTMLScripts() as $script){
					$fullPath = "/".REPOSITORY_FOLDER."/".SCRIPTS_FOLDER."/".$script;
					if(strlen($cmsPath)) {
						$fullPath = "/$cmsPath/".REPOSITORY_FOLDER."/".SCRIPTS_FOLDER."/".$script;
          }
					$htmlManager->addScript($fullPath);
				}

				// add page specific styles
				foreach($page->getHTMLStyles() as $style){
					$fullPath = "/".REPOSITORY_FOLDER."/".STYLES_FOLDER."/".$style;
					if(strlen($cmsPath))
						$fullPath = "/$cmsPath/".REPOSITORY_FOLDER."/".STYLES_FOLDER."/".$style;
					$htmlManager->addStyle($fullPath);
				}

				// add the page content
				$htmlManager->addHTML($page->getHTMLBody($langId, $user, $mode));

				// get end time
				$mtime = microtime();
				$endTime = explode(" ", $mtime);
				$totaltime = round($endTime[1] + $endTime[0] - $startTime[1] - $startTime[0], 2);
				$now = date("D M j G:i:s Y");
				$htmlManager->addHTML("<!-- This page was generated on $now in $totaltime seconds -->");

				// add debug informations
				if($this->getPersistentVar("debug") > 0) {
					$debug = &Debug::getInstance();
					$debugInfo = $debug->getReport();
					$htmlManager->addHTML($debugInfo);
				}

				// get the resulting HTML code
				$html = &$htmlManager->getHTML();
			}
			else {
				$html = "<html><body>You don't have permissions to view this page or this page has not been published yet.<br /><br />try to switch to <a href=\"?mode=edit\">edit mode</a> or <a href=\"?action=logout\">logout</a>.</body></html>";
			}
		}

		return $html;
	}

	/**
	 * Returns the html code of a given form object.
	 *
 	 * @param    object   A reference to the form object we want to be displayed.
 	 * @return   string
 	 * @deprecated
	 */
	function &generateFormHTML(&$form) {
		$html = '';
		if (($user = $this->getPersistentVar('user')) != null) {
			$htmlManager = &$form->getHTMLManager();
			$html = &$htmlManager->getHTML();
		}
		return $html;
	}

	/**
	 * Gets FamilyManager
	 *
	 * @return object
	 */
	function &getFamilyManager() {
		if (!isset($this->familyManager)) {
			$this->familyManager = &new FamilyManager($this);
		}
		return $this->familyManager;
	}

	/**
	 * Gets ACLManager
	 *
	 * @return object
	 */
	function &getACLManager() {
		if (!isset($this->ACLManager)) {
			$dbManipulator = &$this->getDBManipulator();
			$this->ACLManager = &new ACLManager($dbManipulator);
		}
		return $this->ACLManager;
	}

	/**
	 * Gets UsersManager
	 *
	 * @return object
	 */
	function &getUsersManager() {
		if (!isset($this->usersManager)) {
			$dbManipulator = &$this->getDBManipulator();
			$this->usersManager = &new UsersManager($dbManipulator);
		}
		return $this->usersManager;
	}

	/**
	 * Gets GroupsManager
	 *
	 * @return object
	 */
	function &getGroupsManager() {
		if (!isset($this->groupsManager)) {
			$dbManipulator = &$this->getDBManipulator();
			$this->groupsManager = &new GroupsManager($dbManipulator);
		}
		return $this->groupsManager;
	}

	function &getTypesManager() {
		if (!isset($this->typesManager)) {
			$this->typesManager = &new TypesManager($this->dbManipulator);
		}
		return $this->typesManager;
	}

	/**
	 * Gets FramesManager
	 *
	 * @return object
	 */
	function &getFramesManager() {
		if (!isset($this->framesManager)) {
			$dbManipulator = &$this->getDBManipulator();
			$this->framesManager = &new FramesManager($dbManipulator);
		}
		return $this->framesManager;
	}

	/**
	 * Gets TemplatesManager
	 *
	 * @return object
	 */
	function &getTemplatesManager() {
		if (!isset($this->templatesManager)) {
			$dbManipulator = &$this->getDBManipulator();
			$this->templatesManager = &new TemplatesManager($dbManipulator);
		}
		return $this->templatesManager;
	}

	/**
	 * Gets PagesManager
	 *
	 * @return object
	 */
	function &getPagesManager() {
		if (!isset($this->pagesManager)) {
			$dbManipulator = &$this->getDBManipulator();
			$framesManager = &$this->getFramesManager();
			$aclManager = &$this->getACLManager();
			$menusManager = null; //&$this->getMenusManager();
			$containersListsManager = &$this->getContainersListsManager();
			$containersManager = &$this->getContainersManager();
			$this->pagesManager = &new PagesManager($dbManipulator, $framesManager, $aclManager, $menusManager, $containersListsManager, $containersManager);
			$menusManager = &$this->getMenusManager();
			$this->pagesManager->setMenusManager($menusManager);
		}
		return $this->pagesManager;
	}

	/**
	 * Gets MenuNodesManager
	 *
	 * @return object
	 */
	function &getMenuNodesManager() {
		if(!isset($this->menuNodesManager)){
			$dbManipulator = &$this->getDBManipulator();
			$pagesManager = &$this->getPagesManager();
			$menusManager = &$this->getMenusManager();

			$this->menuNodesManager = &new MenuNodesManager($dbManipulator, $pagesManager, $menusManager);
		}
		return $this->menuNodesManager;
	}

	/**
	 * Gets MenusManager
	 *
	 * @return object
	 */
	function &getMenusManager() {
		if(!isset($this->menusManager)){
			$dbManipulator = &$this->getDBManipulator();
			$aclManager = &$this->getACLManager();
			$langId = $this->getPersistentVar('lid');
			$pagesManager = &$this->getPagesManager();
			$templatesManager = &$this->getTemplatesManager();
			$menuNodesManager = null;
			$this->menusManager = &new MenusManager($dbManipulator, $aclManager, $pagesManager, $menuNodesManager, $templatesManager, $langId);
			$menuNodesManager = &$this->getMenuNodesManager();
			$this->menusManager->setMenuNodesManager($menuNodesManager);
		}
		return $this->menusManager;
	}

	/**
	 * Gets ContentsManager
	 *
	 * @return object
	 */
	function &getContentsManager() {
		if(!isset($this->contentsManager)){
			$aclManager = &$this->getACLManager();
			$typesManager = &$this->getTypesManager();
			//$langId = $this->getPersistentVar('lid');
			//$this->contentsManager = &new ContentsManager($this->dbManipulator, $aclManager, $typesManager, $langId);
			$this->contentsManager = &new ContentsManager($this->dbManipulator, $aclManager, $typesManager);
		}
		return $this->contentsManager;
	}

	/**
	 * Gets ContainersManager
	 *
	 * @return object
	 */
	function &getContainersManager() {
		if(!isset($this->containersManager)){
			$dbManipulator = &$this->getDBManipulator();
			$aclManager = &$this->getACLManager();
			$contentsManager = &$this->getContentsManager();
			$typesManager = &$this->getTypesManager();
			$templatesManager = &$this->getTemplatesManager();
			//$langId = $this->getPersistentVar('lid');
			//$this->containersManager = &new ContainersManager($this->dbManipulator, $aclManager, $typesManager, $contentsManager, $templatesManager, $langId);
			$this->containersManager = &new ContainersManager($this->dbManipulator, $aclManager, $typesManager, $contentsManager, $templatesManager);
		}
		return $this->containersManager;
	}

	/**
	 * Gets ContainersListsManager
	 *
	 * @return object
	 */
	function &getContainersListsManager() {
		if(!isset($this->containersListsManager)){
			$aclManager = &$this->getACLManager();
			$containersManager = $this->getContainersManager();
			$this->containersListsManager = &new ContainersListsManager($this->dbManipulator, $aclManager, $containersManager);
		}
		return $this->containersListsManager;
	}

	/**
	 * Gets ContentsVersionsManager
	 *
	 * @return object
	 */
	function &getContentVersionsManager() {
		if(!isset($this->contentVersionsManager)){
			$typesManager = &$this->getTypesManager();
		  $this->contentVersionsManager = &new ContentVersionsManager($this->dbManipulator, $typesManager);
    }
    return $this->contentVersionsManager;
  }

	/**
	 * Gets CacheManager
	 *
	 * @return object
	 */
	function &getCacheManager() {
		if(!isset($this->cacheManager)){
			$pagesManager = &$this->getPagesManager();
		  $this->cacheManager = &new CacheManager($this->dbManipulator, $pagesManager);
    }
    return $this->cacheManager;
  }

	/**
	 * Gets FormsManager
	 *
	 * @return object
	 */
	function &getFormsManager() {
		if(!isset($this->formsManager)){
		  $this->formsManager = &new FormsManager($this);
    }
    return $this->formsManager;
  }

	// todo : see family.class.php
	function getParentObject($object) {
		switch($object->getClassName()) {
			case content :
				$contentId = $object->getContentId();
				if($result = $this->dbManipulator->queryGetContainerIdFromContentId($contentId)){
					if($row = $this->dbManipulator->fetchArray($result)) {
						$containerId = $row['id'];
						$containersManager = &$this->getContainersManager();
						return $containersManager->getContainer($containerId, false);
					}
				}
				else {
					//error
				}
				break;
			case container :
				$containerId = $object->getContainerId();
				// container in containersList
				if($result = $this->dbManipulator->queryGetContainersListIdFromContainerId($containerId)) {
					$row = $this->dbManipulator->fetchArray($result);
					if($row) {
						$containersListId = $row['id'];
						$containersListsManager = &$this->getContainersListsManager();
						return $containersListsManager->getContainersList($containersListId, false);
					}
					else {
						// container in page
						if($result = $this->dbManipulator->queryGetPageIdFromContainerId($containerId)) {
							$row = $this->dbManipulator->fetchArray($result);
							$pageId = $row['id'];
							$pagesManager = &$this->getPagesManager();
							return $pagesManager->getPage($pageId, false, true, false, false);
						}
						else {
							//error
						}
					}
				}
				else {
					//error
				}
				break;
		}
	}
}
?>