<?php
/*
 * This file is part of the Easy-CMS project.
 * Easy-CMS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * Easy-CMS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Easy-CMS; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
/**
 * @package Core
 */
 
/**
 * Defines URL vars separator
 */
define('URL_DELIM', '&');

/**
 */
include_once('classes/core/CoreObject.class.php');

/**
 * @author  vinadelmar <vinadelmar@users.sourceforge.net
 * @since   2006-03-06
 * @version 1.0.0d
 * @package Core
 */
class URL extends CoreObject
{
	var $varsArray;
	
	/**
	 * Class Constructor
	 */
	function URL()
	{
		$this->varsArray = array();
		
		$this->leechVars();
		
		$this->debug('URL::__construct(), status : constructor invoked.', 10);
	}
	
	/**
	 * Gets Vars From URL
	 */
	function leechVars()
	{
		foreach ($_GET as $vname => $vval) {
			$this->varsArray[$vname] = $vval;
		}
	}
	
	/**
	 * Spreads Variable Through URL
	 * 
	 * @param string $vname nameof variable
	 * @param string $vval valueof variable
	 */
	function spreadVar($vname, $vval)
	{
		$this->varsArray[$vname] = $vval;
	}
	
	/**
	 * Catchs Variable From URL
	 *
	 * @param string $vname nameof variable
	 * @return mixed string or null
	 */
	function catchVar($vname)
	{
		if (!isset($this->varsArray[$vname]))
			return null;
		return $this->varsArray[$vname];
	}
	
	/**
	 * Returns Full URL
	 *
	 * @return string
	 */
	function makeURL()
	{
		$url = '?';
		
		foreach ($this->varsArray as $vname => $vval) { 
			$url .= $vname.'='.$vval.URL_DELIM;
		}
		
		$url = substr($url, 0, (0-strlen(URL_DELIM)));
		$url = 'http://'.$_SERVER['SERVER_NAME'].$_SERVER['PHP_SELF'].$url;
		
		return $url;
	}
}

?>