<?php
/*
 * This file is part of the easy-CMS project.
 * easy-CMS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * easy-CMS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with easy-CMS; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

/**
 * @package    Core
 * @subpackage Containers
 */

/**
 */
include_once('classes/core/CoreObject.class.php');
include_once('classes/core/DBManipulator.class.php');
include_once('classes/core/ACL/ACLManager.class.php');
include_once('classes/core/ACL/ACL.class.php');
include_once('classes/core/users/User.class.php');
include_once('classes/core/users/UsersManager.class.php');
include_once('classes/core/types/Type.class.php');
include_once('classes/core/types/TypesManager.class.php');
include_once('classes/core/containers/ContainersManager.class.php');
include_once('classes/core/contents/ContentsManager.class.php');
include_once('classes/core/templates/Template.class.php');
include_once('classes/core/templates/TemplatesManager.class.php');
include_once('classes/utils/SortedList.class.php');
include_once('classes/utils/SortedListIterator.class.php');
include_once('classes/core/nodes/myNode.class.php');
include_once('interface/egManager.class.php');
include_once('interface/egContainer.class.php');
include_once('interface/egContextMenu.class.php');

/**
 * Container Class
 *
 * A container holds infos about template, sort order, number to be shown and
 * exhaustive list of contents that are to be displayed in this container.
 *
 * @access     public
 * @author	   Cedric Francoys <cedric.francoys@easy-cms.org>
 * @version	   Container.class, Sat Nov 13 11:37:29 CET 2004
 * @package    Core
 * @subpackage Containers
 */
class Container extends CoreObject {
	/**#@+
	 * @access private
	 */
	/**
	 * @var integer
	 */
  var $id;

	/**
	 * @var integer
	 */
	var $nameId;

	/**
	 * @var string
	 */
	var $typeName;

	/**
	 * @var integer
	 */
	var $templateId;

	/**
	 * @var integer
	 */
	var $sortingType;

	/**
	 * @var string
	 */
	var $sortField;

	/**
	 * @var integer
	 */
	var $sortOrder;

	/**
	 * @var integer
	 */
	var $shownFrom;

	/**
	 * @var integer
	 */
	var $countShown;

	/**
	 * @var integer
	 */
	var $cloneId;

	/**
	 * @var integer
	 */
	var $deleted;

	/**
	 * @var integer
	 */
	var $published;

	/**
	 * @var integer
	 */
	var $aclId;

	/**
	 * @var array
	 */
	var $namesTable;

	/**
	 * @var object
	 */
	var $template;

	/**
	 * @var object
	 */
	var $acl;

	/**
	 * @var integer
	 */
	var $containersListId;

	/**
	 * @var
	 */
	var $contentTypeDescr;

	/**
	 * @var array
	 */
	var $contentsTable;

	/**
	 * @var array
	 */
	var $objectsList;

	/**
	 * @deprecated
	 * @todo approve and clean
	 */
	//var $containersManager;
	/**#@-*/

	/**#@+
	 * @access public
	 */
	/**
	 * Constructor
	 *
	 * @param integer $id Container Id
	 * @param integer $nameId Container Name Id
	 * @param string $typeName Container Type Name
	 * @param integer $templateId Container Template Id
	 * @param integer $sortingType Sorting Type
	 * @param string $sortField Sort Field
	 * @param integer $sortOrder Sort Order
	 * @param integer $shownFrom Show From the nth Content
	 * @param integer $countShown Show n Contents
	 * @param integer $cloneId Original Container Id (if any)
	 * @param integer $deleted Is Container Deleted
	 * @param integer $aclId Container ACL Id
	 */
	function Container($id=0, $nameId=0, $typeName='', $templateId=0, $sortingType=0,
		$sortField='', $sortOrder=0, $shownFrom=0, $countShown=0, $cloneId=0,
			$deleted=0, $aclId=0) {
		$this->setContainerId($id);
		$this->setContainerNameId($nameId);
		$this->setContainerTypeName($typeName);
		$this->setContainerTemplateId($templateId);
		$this->setContainerSortingType($sortingType);
		$this->setContainerSortField($sortField);
		$this->setContainerSortOrder($sortOrder);
		$this->setContainerShownFrom($shownFrom);
		$this->setContainerCountShown($countShown);
		$this->setContainerCloneId($cloneId);
		$this->setContainerDeleted($deleted);
		$this->setContainerAclId($aclId);
		$this->namesTable = array();
		$this->contentsTable = array();
	}

	function getClassName(){
		return 'Container';
	}

	/**
	 * Gets Container Id
	 *
	 * @return integer
	 */
	function getContainerId(){
		return $this->id;
	}

	/**
	 * Sets Container Id
	 *
	 * @param integer $id Container Id
	 */
	function setContainerId($id){
		$this->id = $id;
	}

	/**
	 * Gets Container Name Id
	 *
	 * @return integer
	 */
	function getContainerNameId(){
		return $this->nameId;
	}

	/**
	 * Sets Container Name Id
	 *
	 * @param integer $nameId
	 */
	function setContainerNameId($nameId){
		$this->nameId = $nameId;
	}

	/**
	 * Gets Container Type Name
	 *
	 * Indicates which kind of Content the Container will hold
	 *
	 * @return string
	 */
	function getContainerTypeName(){
		return $this->typeName;
	}

	/**
	 * Sets Container Type Name
	 *
	 * Indicates which kind of Content the Container will hold
	 *
	 * @param string $typeName
	 */
	function setContainerTypeName($typeName){
		$this->typeName = $typeName;
	}

	/**
	 * Gets Container Template Id
	 *
	 * @return integer
	 */
	function getContainerTemplateId(){
		return $this->templateId;
	}

	/**
	 * Sets Container Template Id
	 *
	 * @param integer $templateId
	 */
	function setContainerTemplateId($templateId){
		$this->templateId = $templateId;
	}

	/**
	 * Sets Container "SortingType" Property
	 *
	 * Indicates if we must operate a field or index based sort
	 *
	 * @return integer
	 */
	function getContainerSortingType(){
		return $this->sortingType;
	}

	/**
	 * Sets Container "SortingType" Property
	 *
	 * Indicates if we must operate a field or index based sort
	 *
	 * @param integer $sortingType
	 */
	function setContainerSortingType($sortingType){
		$this->sortingType = $sortingType;
	}

	/**
	 * Sets Container "SortField" Property
	 *
	 * Indicates on which Content field applies the sort
	 *
	 * @return string
	 */
	function getContainerSortField(){
		return $this->sortField;
	}

	/**
	 * Sets Container "SortField" Property
	 *
	 * Indicates on which Content field applies the sort
	 *
	 * @param string $sortField
	 */
	function setContainerSortField($sortField){
		$this->sortField = $sortField;
	}

	/**
	 * Gets Container "SortOrder" Property
	 *
	 * Sort order is ascending or descending
	 *
	 * @return integer
	 */
	function getContainerSortOrder(){
		return $this->sortOrder;
	}

	/**
	 * Sets Container "SortOrder" Property
	 *
	 * Sort order is ascending or descending
	 *
	 * @param integer $sortOrder
	 */
	function setContainerSortOrder($sortOrder){
		$this->sortOrder = $sortOrder;
	}

	/**
	 * Gets Container "ShownFrom" Property
	 *
	 * Indicates at which position of the Content list, we start displaying
	 * Content objects
	 *
	 * @return integer
	 */
	function getContainerShownFrom(){
		return $this->shownFrom;
	}

	/**
	 * Sets Container "ShownFrom" Property
	 *
	 * Indicates at which position of the Content list, we start displaying
	 * Content objects
	 *
	 * @param integer $shownFrom
	 */
	function setContainerShownFrom($shownFrom){
		$this->shownFrom = $shownFrom;
	}

	/**
	 * Gets Container "CountShown" Property
	 *
	 * Indicates how many Content objects have to be displayed
	 *
	 * @return integer
	 */
	function getContainerCountShown(){
		return $this->countShown;
	}

	/**
	 * Sets Container "CountShown" Property
	 *
	 * Indicates how many Content objects have to be displayed
	 *
	 * @param integer $countShown
	 */
	function setContainerCountShown($countShown){
		$this->countShown = $countShown;
	}

	/**
	 * Gets Container Clone Id
	 *
	 * If a Container is a clone, it loads its content from another Container
	 *
	 * @return integer
	 */
	function getContainerCloneId(){
		return $this->cloneId;
	}

	/**
	 * Sets Container Clone Id
	 *
	 * If a Container is a clone, it loads its content from another Container
	 *
	 * @param integer $cloneId
	 */
	function setContainerCloneId($cloneId){
		$this->cloneId = $cloneId;
	}

	/**
	 * Gets Container Deleted
	 *
	 * @return integer
	 */
	function getContainerDeleted(){
		return $this->deleted;
	}

	/**
	 * Sets Container Deleted
	 *
	 * @param integer $deleted
	 */
	function setContainerDeleted($deleted){
		$this->deleted = $deleted;
	}

	/**
	 * Gets Container Acl Id
	 *
	 * @return integer
	 */
	function getContainerAclId(){
		return $this->aclId;
	}

	/**
	 * alias for getContainerAclId
	 *
	 * @return integer
	 */
	function getAclId() {
		return $this->aclId;
	}

	/**
	 * Sets Container Acl Id
	 *
	 * @param integer $aclId
	 */
	function setContainerAclId($aclId){
		$this->aclId = $aclId;
	}

	/**
	 * Gets Container Name
	 *
	 * @return string
	 */
	function getContainerName($langId){
		$name = '';
		if(isset($this->namesTable[$langId])){
			$name = $this->namesTable[$langId];
		}
		return $name;
	}

	/**
	 * Sets Container Name
	 *
	 * @param string $name
	 */
	function setContainerName($name, $langId){
		$this->namesTable[$langId] = $name;
	}

	/**
	 * Gets Container Template
	 *
	 * @return object
	 */
	function &getContainerTemplate(){
		if (!isset($this->template))
			return null;
		return $this->template;
	}

	/**
	 * Sets Containter Template
	 *
	 * @param object $template
	 */
	function setContainerTemplate(&$template){
		$this->template = &$template;
	}

	/**
	 * Gets Container ACL
	 *
	 * @return object
	 */
	function &getContainerAcl(){
		if (!isset($this->acl))
			return null;
		return $this->acl;
	}

	/**
	 * Sets Container ACL
	 *
	 * @param object $acl
	 */
	function setContainerAcl(&$acl){
		$this->acl = &$acl;
	}

	/**
	 * Sets Container Published
	 *
	 * @param object $published
	 */
	function setContainerPublished($published){
		$this->published = $published;
	}

	function getContainerPublished(){
		return $this->published;
	}

	function isPublished(){
		return (bool) $this->getContainerPublished();
	}

	/**
	 * Gets ContainersList Id
	 *
	 * Indicates if Container is contained into a ContainersList
	 *
	 * return integer
	 */
	function getContainersListId(){
		return $this->containersListId;
	}

	/**
	 * Sets Containers List
	 *
	 * Indicates if Container is contained into a ContainersList
	 *
	 * @param integer $containersListId
	 */
	function setContainersListId($containersListId){
		$this->containersListId = $containersListId;
	}

	/**
	 * Gets Content Table
	 *
	 * @return array
	 */
	function &getContentsTable(){
		if (!isset($this->contentsTable)) {
			return null;
		}
		return $this->contentsTable;
	}

	/**
	 * Sets Content Table
	 *
	 * @param array $table Array of Content objects
	 */
	function setContentsTable(&$table){
		$this->contentsTable = &$table;
	}

	/**
	 * Gets Content Count
	 *
	 * Number of Content object holded by Container
	 *
	 * @return integer
	 */
	function getContentsCount(){
		if (!isset($this->contentsTable)) {
			return -1;
		}
		return count($this->contentsTable);
	}

	/**
	 * Adds a content object to the contentsTable
	 *
	 * @param object $content
	 */
	function addContent(&$content){
		if(!is_object($content)) {
			$this->debug('Container::addContent, error : trying to add a non-object to the contentsTable.', 4);
			return;
		}
		$this->contentsTable[] = &$content;
	}

	/**
	 * Gets Content
	 *
	 * @author vinadelmar
	 * @since  2006-08-30
	 * @param  integer $contentId Content Id
	 * @return object
	 */
	function &getContent($contentId){
		if (!isset($this->contentsTable[$contentId])) {
			return null;
		}
		return $this->contentsTable[$contentId];
	}


	function getContainerValuesTable() {
    $valuesTable = array();

    foreach($this->namesTable as $langId => $name) {
      $valuesTable[$langId]['name'] = $name;
    }

		$valuesTable['id'] = $this->getContainerId();
		$valuesTable['clone_id'] = $this->getContainerCloneId();
		$valuesTable['name_id'] = $this->getContainerNameId();
		$valuesTable['type_name'] = $this->getContainerTypeName();
		$valuesTable['sorting_type'] = $this->getContainerSortingType();
		$valuesTable['sort_field'] = $this->getContainerSortField();
		$valuesTable['sort_order'] = $this->getContainerSortOrder();
		$valuesTable['count_shown'] = $this->getContainerCountShown();
		$valuesTable['shown_from'] = $this->getContainerShownFrom();
		$valuesTable['template_id'] = $this->getContainerTemplateId();
		$valuesTable['acl_id'] = $this->getContainerAclId();
		$valuesTable['deleted'] = $this->getContainerDeleted();

    return $valuesTable;
  }

	/**
	 * Gets Container Value
	 *
	 * @param  string $fieldName
	 * @return mixed
	 */
	function getContainerValue($fieldName, $langId=1) {
		if ($fieldName == 'id') {
			return $this->getContainerId();
		}
		if ($fieldName == 'clone_id') {
			return $this->getContainerCloneId();
		}
		if ($fieldName == 'name_id') {
			return $this->getContainerNameId();
		}
		if ($fieldName == 'name') {
			return $this->getContainerName($langId);
		}
		if ($fieldName == 'sorting_type') {
			return $this->getContainerSortingType();
		}
		if ($fieldName == 'sort_field') {
			return $this->getContainerSortField();
		}
		if ($fieldName == 'sort_order') {
			return $this->getContainerSortOrder();
		}
		if ($fieldName == 'count_shown') {
			return $this->getContainerCountShown();
		}
		if ($fieldName == 'shown_from') {
			return $this->getContainerShownFrom();
		}
		if ($fieldName == 'template_id') {
			return $this->getContainerTemplateId();
		}
		if ($fieldName == 'type_name') {
			return $this->getContainerTypeName();
		}
		if ($fieldName == 'acl_id') {
			return $this->getContainerAclId();
		}
		if ($fieldName == 'deleted') {
			return $this->getContainerDeleted();
		}
		if ($fieldName == 'published') {
			return $this->getContainerPublished();
		}
		return -1;
	}

	/**
	 * Gets Container Value
	 *
	 * @param  string $fieldName
	 * @return mixed
	 */
	function getValue($fieldName) {
		return $this->getContainerValue($fieldName);
	}

	/**
	 * Sets Container Values
	 *
	 * @param array $array
	 */
  function setContainerValues($array) {
		if(!is_array($array)) {
			return;
		}
    foreach($array as $key => $valuesTable) {
			if(is_int($key)) {
				$langId = $key;
				if(isset($valuesTable['name'])) {
					$this->setContainerName($valuesTable['name'], $langId);
				}
			}
    }
		if(isset($array['id'])) {
			$this->setContainerId($array['id']);
    }
		if(isset($array['clone_id'])) {
			$this->setContainerCloneId($array['clone_id']);
    }
		if(isset($array['name_id'])) {
			$this->setContainerNameId($array['name_id']);
    }
		if(isset($array['type_name'])) {
			$this->setContainerTypeName($array['type_name']);
    }
		if(isset($array['sorting_type'])) {
			$this->setContainerSortingType($array['sorting_type']);
    }
		if(isset($array['sort_field'])) {
			$this->setContainerSortField($array['sort_field']);
    }
		if(isset($array['sort_order'])) {
			$this->setContainerSortOrder($array['sort_order']);
    }
		if(isset($array['count_shown'])) {
			$this->setContainerCountShown($array['count_shown']);
    }
		if(isset($array['shown_from'])) {
			$this->setContainerShownFrom($array['shown_from']);
    }
		if(isset($array['template_id'])) {
			$this->setContainerTemplateId($array['template_id']);
    }
		if(isset($array['acl_id'])) {
			$this->setContainerAclId($array['acl_id']);
    }
		if(isset($array['deleted'])) {
			$this->setContainerDeleted($array['deleted']);
    }
		if(isset($array['published'])) {
			$this->setContainerPublished($array['published']);
    }
	}

  function setValues($array) {
		$this->setContainerValues($array);
	}

	/**
	 * Compares Containers
	 *
	 * @param  object $container Container Object
	 * @param  string $field Comparison Field
	 * @return integer
	 */
	function compareTo(&$container, $field, $langId=1){
		if ($field == '') {
			return 1;
		}
		$value1 = $this->getContainerValue($field, $langId);
		$value2 = $container->getContainerValue($field, $langId);
		if (is_numeric($value1) && is_numeric($value2)) {
			$value1 = sprintf("%05d", $value1);
			$value2 = sprintf("%05d", $value2);
		}
		return strcmp($value1, $value2);
	}

  	// deprecated
	function loadContent() {
		$this->sortContents();
	}

  function sortContents($langId) {
    if (is_array($this->contentsTable)) {
			$count = $this->getContentsCount();
			$sortField = $this->getContainerSortField();
			$sortOrder = $this->getContainerSortOrder();
			$this->objectsList = array();
			for($i = 0; $i < $count; ++$i) {
				$content = &$this->contentsTable[$i];
				$field = &$content->getContentFieldValue($langId, $sortField);
				$this->objectsList[$i] = substr($field->getValue(), 0, 20);
			}
			if($sortOrder == SORT_ASCENDING) {
				asort($this->objectsList);
			}
			else {
				arsort($this->objectsList);
			}
    }
  }

	/**
	 * Exports Container Into XML
	 *
	 * @param  object $user User Object
	 * @param  integer $langId Language Id
	 * @param  string $mode
	 * @return string
	 */
 	function toXML(&$user, $langId, $mode) {
		$containerId = $this->getContainerId();
		$cloneId = $this->getContainerCloneId();

		$max = $this->getContainerCountShown();
		$min = $this->getContainerShownFrom();

		$limit = $max+$min;
		$count = $this->getContentsCount();

		// start from position 0
		if ($min > 0) {
			$i = $min;
		}
		else {
			$i = 0;
		}

		$xml  = "<container>\n";

		if ($this->acl->userHasViewRight($user) && ($mode == EDIT_MODE || $this->isPublished())) {
			$xml .= "<name><![CDATA[".$this->getContainerName($langId)."]]></name>\n";
			$xml .= "<id>".$containerId."</id>\n";
			$xml .= "<clone-id>".$cloneId."</clone-id>\n";
			$xml .= "<contents>\n";

			// sorting by list
			if ($this->getContainerSortingType() == SORTING_BY_LIST) {
				for (; $i < $count && ($max == 0 || $i < $limit); ++$i) {
					if(!isset($this->contentsTable[$i]) || !is_object($this->contentsTable[$i])) {
						continue;
					}
					$content = &$this->contentsTable[$i];
					$contentId = $content->getContentId();

					$xml .= $content->toXML($user, $langId, $containerId, $cloneId, $mode);
				}
			}
			// sorting by field
			else {
				$this->sortContents($langId);
				$sortField = $this->getContainerSortField();
				if (is_array($this->objectsList)) {
					reset($this->objectsList);
					for ($j = 0; $j < $i; ++$j) {
						next($this->objectsList);
					}
					for (; $i < $count && ($max == 0 || $i < $limit); ++$i) {
						$index = key($this->objectsList);
						$content = &$this->contentsTable[$index];
						next($this->objectsList);
						$xml .= $content->toXML($user, $langId, $containerId, $cloneId, $mode);
					}
				}
			}
			$xml .= "</contents>\n";
		}
		$xml .= "</container>\n";

		return $xml;
	}

	/**
	 * Gets Container Controls
	 *
	 * @param  object $user User Object
	 * @param  string $mode
	 * @return string
	 */
	function getControls(&$user, $mode=VIEW_MODE) {
		$containerId      = $this->getContainerId();
		$cloneId          = $this->getContainerCloneId();
		$typeName         = $this->getContainerTypeName();
		$containersListId = $this->getContainersListId();

		$html = '';

		if ($this->acl->userHasEditRight($user) && $mode == EDIT_MODE) {

      $menu = &new egContextMenu("menu_container_".$containerId, 0, 0, 150, 350);
			// add content
			if($cloneId != 0){
        $menu->addListItem(new egMenuItem("mnu_ct_".$containerId."_1", LANG_CONTAINER_MENU_ADD, "interface/icons/add.png", "launchContentEditionWindow(\'container_id=$cloneId&amp;content_id=0&amp;type_name=$typeName\');"));
			}
			else {
        $menu->addListItem(new egMenuItem("mnu_ct_".$containerId."_1", LANG_CONTAINER_MENU_ADD, "interface/icons/add.png", "launchContentEditionWindow(\'container_id=$containerId&amp;content_id=0&amp;type_name=$typeName\');"));
			}
	    $menu->addSeparator();
			// move up
      $menu->addListItem(new egMenuItem("mnu_ct_".$containerId."_2", LANG_CONTAINER_MENU_MOVE_UP, "interface/icons/move_up.png", "moveUpCtn_$containerId();"));
			// move down
      $menu->addListItem(new egMenuItem("mnu_ct_".$containerId."_3", LANG_CONTAINER_MENU_MOVE_DOWN, "interface/icons/move_down.png", "moveDownCtn_$containerId();"));
	    $menu->addSeparator();
			// remove container
			if ($this->acl->userHasRemoveRight($user)) {
        $menu->addListItem(new egMenuItem("mnu_ct_".$containerId."_4", LANG_CONTAINER_MENU_REMOVE, "interface/icons/remove.png", "launchContainerDeletionWindow(\'container_id=$containerId\');"));
			}
	    $menu->addSeparator();
			// container properties
	    $menu->addListItem(new egMenuItem("mnu_ct_".$containerId."_5", LANG_CONTAINER_MENU_EDIT, "interface/icons/edit.png", "launchContainerEditionWindow(\'container_id=$containerId\');"));

      $main = &new egContainer("eg_ctn_ct_".$containerId, 0, 0, 0, 0);

      $main->addObject($menu);

      $manager = &egManager::getInstance();
    	$manager->addContainer($main);
      $scripts = new egScript();

      $line = "function moveUpCtn_".$containerId."() {
window.location.href = 'index.php?display=".EDIT_CONTAINERS_LIST."&action=".MOVE_CONTAINER_UP."&container_id=$containerId&containers_list_id=$containersListId';
}
function moveDownCtn_".$containerId."() {
window.location.href = 'index.php?display=".EDIT_CONTAINERS_LIST."&action=".MOVE_CONTAINER_DOWN."&container_id=$containerId&containers_list_id=$containersListId';
}";
      $scripts->addLine($line);
      $manager->addScripts($scripts);
			$html .= "<a class=\"easy-CMS_UI_Style_propertiesIcon\" href=\"javascript:egShowContextMenu(contextMenu_"."menu_container_".$containerId.");\"><img src=\"interface/icons/properties.png\" /></a>";
    }

		return $html;
	}

	/**
	 * Exports Container Into HTML
	 *
	 * @param  object $user User
	 * @param  integer $langId
	 * @param  string $mode
	 * @param  boolean $drawBorder
	 * @return string
	 */
 	function toHTML(&$user, $langId, $mode=VIEW_MODE, $drawBorder=true) {
		if ($user == null) {
			$this->debug("Container.toHTML, error : user not defined (empty html string returned).", 2);
			return "";
		}

		$html = "";
		$containerId = $this->getContainerId();
		$cloneId = $this->getContainerCloneId();

		if ($this->acl->userHasViewRight($user) && ($mode == EDIT_MODE || $this->isPublished())) {
			$xml = &$this->toXML($user, $langId, $mode);

			if (!is_object($this->template)) {
        $this->debug("Container.toHTML, error : Container(id='.$containerId.') has no template.", 2);
				return '';
			}

      $html = &$this->template->processXML($xml, $mode);
		  $max = &$this->getContainerCountShown();
		  $min = &$this->getContainerShownFrom();
			$limit = $max+$min;
			$count = $this->getContentsCount();

			// start from position 0
			if($min > 0) {
				$i = $min-1;
			}
			else {
				$i = 0;
			}

			// sorting by list
			if ($this->getContainerSortingType() == SORTING_BY_LIST) {
				if (is_array($this->contentsTable)) {
					for(; $i < $count && ($max == 0 || $i < $limit); ++$i) {
						if(!isset($this->contentsTable[$i]) || !is_object($this->contentsTable[$i])) {
							continue;
						}
						$content = &$this->contentsTable[$i];
						$contentId = $content->getContentId();

						$html .= $content->getControls($user, $containerId, $cloneId, $mode);
					}
				}
			}
			// sorting by field
			else {
				$sortField = $this->getContainerSortField();
				if(is_array($this->objectsList)) {
					reset($this->objectsList);
					for($j = 0; $j < $i; ++$j) {
						next($this->objectsList);
					}
					for (; $i < $count && ($max == 0 || $i < $limit); ++$i) {
						$index = key($this->objectsList);
						$content = &$this->contentsTable[$index];
						next($this->objectsList);
						$html .= $content->getControls($user, $containerId, $cloneId, $mode);
					}
				}
   		}

			if ($this->acl->userHasEditRight($user) && $mode == EDIT_MODE && $drawBorder) {
				$head = "";
				$tail = "";
				$head .= "<div class=\"easy-CMS_UI_Style_outer_frame\">\n";
				$head .= "<div class=\"leftBorder\">\n";
				$head .= "<div class=\"rightBorder\">\n";
				$head .= "	<div class=\"header\">\n";
				$head .= "         <div class=\"headerInner\">\n";
				$head .= "		<div class=\"left\"><div class=\"title\">".$this->getContainerName($langId)."</div></div>\n";
				$head .= "		<div class=\"right\">\n";
				$head .= "			<div class=\"properties\">\n";
				$head .= $this->getControls($user, EDIT_MODE);
				$head .= "			</div>\n";
				$head .= "		</div>\n";
				$head .= "         </div>\n";
				$head .= "	</div>\n";
				$head .= "	<div class=\"inner_frame\">\n";
				$tail .= "	</div>\n";
				$tail .= "</div>\n";
				$tail .= "</div>\n";
				$tail .= "</div>\n";
				$html = $head.$html.$tail;
			}
		}

		return $html;
	}

	/**
	 * @deprecated
	 */
	function getHTMLContentList($mode) {
		$form = "";
		$form .= "<script type=\"text/javascript\">\n";
		$form .= "function saveContent(){}\n";
		$form .= "</script>\n";
		$form .= "<table border=\"0\" cellspacing=\"0\" cellpadding=\"0\">\n";
		$form .= "<form action=\"".$_SERVER['PHP_SELF']."\" method=\"post\">\n";
		$form .= "   <tr>\n";
		$form .= "   <td valign=\"top\"><b>Clone of container :</b></td>\n";
		$form .= "   <td width=\"5\"><span class=\"size_xxs\">&nbsp;</span></td>\n";
		$form .= "   <td><input name=\"clone_id\" value=\"".$this->getCloneId()."\"></td>\n";
		$form .= "   </tr>\n";
		$form .= "   <tr><td height=\"20\"></td></tr>\n";
		$form .= "   <tr>\n";
		$form .= "   <td valign=\"top\"><b>Elements :</b></td>\n";
		$form .= "   <td width=\"5\"><span class=\"size_xxs\">&nbsp;</span></td>\n";
		$form .= "   <td></td>\n";
		$form .= "   </tr>\n";
		$form .= "   <tr><td height=\"4\"></td></tr>\n";
		$form .= "<tr><td></td></tr>\n";
		$form .= "<input type=\"hidden\" name=\"display\" value=\"".EDIT_CONTAINER."\">\n";
		$form .= "<input type=\"hidden\" name=\"mode\" value=\"$mode\">\n";
		$form .= "<input type=\"hidden\" name=\"container_id\" value=\"".$this->getId()."\">\n";
		$form .= "</form>\n";
		$form .= "</table>\n";
		return $form;
	}

	/**
	 * @deprecated
	 */
	function getHTMLSummary($mode) {
		$str = "";

		$str .= "<table border=\"0\" cellspacing=\"2\" cellpadding=\"0\">\n";
		$str .= "   <tr>\n";
		$str .= "   <td valign=\"top\" nowrap=\"nowrap\"><b>Name :</b></td>\n";
		$str .= "   <td width=\"4\"></td>\n";
		$str .= "   <td valign=\"top\">".$this->getName()."</td>\n";
		$str .= "   </tr>\n";
		$str .= "   <tr><td height=\"4\"></td></tr>\n";
		$str .= "<tr><td></td></tr>\n";
		$str .= "</table>\n";
		$str .= "<input type=\"hidden\" name=\"mode\" value=\"$mode\">\n";
		$str .= "<input type=\"hidden\" name=\"container_id\" value=\"".$this->getId()."\">\n";
		return $str;
	}
	/**#@-*/
}
?>