<?php
/*
 * This file is part of the easy-CMS project.
 * easy-CMS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * easy-CMS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with easy-CMS; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

/**
 * @package    Core
 * @subpackage Containers
 */

/**
 */
include_once('classes/core/DBAccessorObject.class.php');
include_once('classes/core/DBManipulator.class.php');
include_once('classes/core/containers/Container.class.php');
include_once('classes/core/contents/ContentsManager.class.php');
include_once('classes/core/contents/Content.class.php');

/**
 * Manage the instances of Container objects.
 *
 * @access     public
 * @author	   Cedric Francoys <cedric.francoys@easy-cms.org>
 * @version	   ContainersManager.class, Sat Nov 13 11:39:53 CET 2004
 * @package	   Core
 * @subpackage Containers
 */
class ContainersManager extends DBAccessorObject {
	/**#@+
	 * @access private
	 */
	/**
	 * @var object
	 */
	var $typesManager;

	/**
	 * @var object
	 */
	var $templatesManager;

	/**
	 * @var object
	 */
  var $aclManager;

	/**
	 * @var object
	 */
	var $contentsManager;

	/**
	 * @var integer
	 */
	//var $langId;

	/**
	 * Array of Container objects
	 *
	 * @var array
	 */
	var $containersTable;
	/**#@-*/

	/**
	 * Class constructor
	 *
	 * @param object  $dbManipulator
	 * @param object  $aclManager
	 * @param object  $typesManager
	 * @param object  $contentsManager
	 * @param object  $templatesManager
	 * @param integer $langId
	 */
	function ContainersManager(&$dbManipulator, &$aclManager, &$typesManager, &$contentsManager, &$templatesManager){
		parent::DBAccessorObject($dbManipulator);
		$this->aclManager = &$aclManager;
		$this->typesManager = &$typesManager;
		$this->contentsManager = &$contentsManager;
		$this->templatesManager = &$templatesManager;
		//$this->langId = &$langId;
		$this->containersTable = array();
	}

	/**
	 * Return instance of types manager object
	 *
	 * @return object
	 */
	function &getTypesManager() {
		return $this->typesManager;
	}

	/**
	 * Return instance of acl manager object
	 *
	 * @return object
	 */
	function &getAclManager() {
		return $this->aclManager;
	}

	/**
	 * Loads Container
	 *
	 * @param  mixed   $id container id
	 * @param  boolean $loadContent
	 * @param  boolean $loadDeleted
	 * @param  integer $langId
	 * @param  boolean $loadAcl
	 * @param  boolean $loadTemplate
	 * @return boolean
	 */
	function loadContainer($containerId, $loadContent=true, $loadDeleted=false, $langId=LOAD_ALL_LANGUAGES,	$loadAcl=true, $loadTemplate=true, $loadTranslation=true){
		$db = &$this->getDBManipulator();
		$cond = '`id` in ('.implode(',', (array)$containerId).')';
		$loaded = false;
		if($res = $db->getRecord(CONTAINERS_TABLE, -1, $cond)) {
			while($fields = $db->fetchArray($res)) {
				$id          = $fields['id'];
				$nameId      = $fields['name_id'];
				$typeName    = $fields['type_name'];
				$templateId  = $fields['template_id'];
				$sortingType = $fields['sorting_type'];
				$sortField   = $fields['sort_field'];
				$sortOrder   = $fields['sort_order'];
				$shownFrom   = $fields['shown_from'];
				$countShown  = $fields['count_shown'];
				$cloneId     = $fields['clone_id'];
				$deleted     = $fields['deleted'];
				$published   = $fields['published'];
				$aclId       = $fields['acl_id'];
				if((!$loadDeleted && !$deleted) || $loadDeleted){
					$this->containersTable[$id] = &new Container($id, $nameId, $typeName, $templateId, $sortingType, $sortField, $sortOrder, $shownFrom, $countShown, $cloneId, $deleted, $aclId);
					$this->containersTable[$id]->setContainerPublished($published);
					if($loadContent) {
						$this->loadContainerContents($id);
					}
					if($loadTemplate) {
						$this->loadContainerTemplate($id);
					}
					if($loadAcl) {
						$this->loadContainerAcl($id);
					}
					if($loadTranslation) {
						$this->loadContainerTranslation($id);
					}
				}
				$loaded = true;
			}
		}
		return $loaded;
 	}

	/**
	 * Loads Container's Contents
	 *
	 * @param  integer $containerId Container Id
	 * @return boolean
	 */
	function loadContainerContents($containerId){
		$db = &$this->getDBManipulator();
		$loaded = false;
    if(!$containerId) {
      return false;
    }
		if($container = &$this->getContainer($containerId)){
			$typeName = $container->getContainerTypeName();
			$cloneId = $container->getContainerCloneId();
			$loadId = $containerId;
			if($cloneId > 0) {
				$loadId = $cloneId;
			}
			if($res = $db->getRecord(CONTAINER_CONTENTS_TABLE, $loadId, '', 'container_id')) {
				$contentsIdList = array();
				while($fields = $db->fetchArray($res)){
          $index = $fields['index'];
					$contentsIdList[$index] = $fields['content_id'];
				}
				if(count($contentsIdList) > 0){
          ksort($contentsIdList);
					if($this->contentsManager->loadContent($contentsIdList, $typeName)){
						foreach($contentsIdList as $contentId){
							if($content = &$this->contentsManager->getContent($contentId, $typeName)) {
								$loaded = true;
								$container->addContent($content);
								unset($content);
							}
						}
					}
				}
			}
		}
		return $loaded;
	}

	/**
	 * Loads Container's Template
	 *
	 * @param  integer $containerId
	 * @return boolean
	 */
	function loadContainerTemplate($containerId){
		$loaded = false;
		if($container = &$this->getContainer($containerId)){
			$typeName = $container->getContainerTypeName();
			$templateId = $container->getContainerTemplateId();
			if($template = &$this->templatesManager->getTemplate($typeName, $templateId)){
				$container->setContainerTemplate($template);
				$loaded = true;
			}
		}
		return $loaded;
	}

	/**
	 * Loads Container's ACL
	 *
	 * @param  integer $containerId
	 * @return boolean
	 */
	function loadContainerAcl($containerId) {
		$loaded = false;
		if($container = &$this->getContainer($containerId)){
			$aclId = $container->getContainerAclId();
			if($acl = &$this->aclManager->getACL($aclId)){
				$container->setContainerAcl($acl);
				$loaded = true;
			}
		}
		return $loaded;
	}

	/**
	 * Loads Container Translation
	 *
	 * @param  integer $containerId
	 * @return boolean
	 */
	function loadContainerTranslation($containerId){
		$db = &$this->getDBManipulator();
		$loaded = false;
		if($container = &$this->getContainer($containerId)){
			if($res = $db->getRecord(NAMES_TABLE, $container->getContainerNameId())){
				while($fields = $db->fetchArray($res)){
					$langId = (int)$fields['lang_id'];
					$label = $fields['value'];
					$container->setContainerName($label, $langId);
					$loaded = true;
				}
			}
		}
		return $loaded;
	}

	/*
	function loadContainerLabels($id) {
	}
	*/


	/**
	 * Stores container
	 *
	 * @param  integer $containerId
	 * @param  boolean $formerCloneBool Tells if container formerly was a clone
	 * @return integer Container ID or <0 if error
	 */
  function storeContainer($containerId, $formerCloneBool=false) {
		$this->storeLanguageDependencies($containerId);

		$container = &$this->getContainer($containerId);

		if (is_null($container)) {
			return -1;
		}

		$fieldsArray = array(
			 'sorting_type' => $container->getContainerSortingType()
			,'sort_field'   => $container->getContainerSortField()
			,'sort_order'   => $container->getContainerSortOrder()
			,'count_shown'  => $container->getContainerCountShown()
			,'shown_from'   => $container->getContainerShownFrom()
			,'template_id'  => $container->getContainerTemplateId()
			,'clone_id'     => $container->getContainerCloneId()
			,'name_id'      => $container->getContainerNameId()
			,'type_name'    => $container->getContainerTypeName()
			,'deleted'      => $container->getContainerDeleted()
			,'published'    => $container->getContainerPublished()
		);

    // check if the clone_id matches an existing container
    if(!is_numeric($fieldsArray['clone_id'])) {
      $fieldsArray['clone_id'] = 0;
    }
    else {
      if($fieldsArray['clone_id'] <= 0 || !$this->containerExists($fieldsArray['clone_id'])) {
        $fieldsArray['clone_id'] = 0;
      }
    }

    if(!is_numeric($fieldsArray['count_shown'])) {
      $fieldsArray['count_shown'] = 0;
    }

    if(!is_numeric($fieldsArray['shown_from'])) {
      $fieldsArray['shown_from'] = 0;
    }

		// new container : id 0 is not allowed in the DB
		if ($containerId == 0) {
			if (!$this->dbManipulator->queryInsert(CONTAINERS_TABLE, $fieldsArray)) {
				$this->debug('ContainersManager::storeContainer, error : unable to create new container', 1);
				return -1;
			}
			$newId = $this->dbManipulator->getLastId();
			$container->setContainerId($newId);
			$this->setContainer($container);
			// free the temporary container entry (0)
			unset($this->containersTable[0]);
			$this->containersTable[0] = null;
			// return a value > 0, the id of the new container
			$this->debug('ContainersManager::storeContainer, success : new container created successfully', 9);
			if($container->getContentsCount() < 1){
				return $newId;
			}
			else {
				$containerId = $newId;
			}
		}
		else {
			if (!$this->dbManipulator->queryUpdate(CONTAINERS_TABLE, $fieldsArray, $containerId)) {
				$this->debug('ContainersManager::storeContainer, error : unable to update container #'.$containerId, 1);
				return -1;
			}
		}

		$cloneId = $fieldsArray['clone_id'];

		// if formerly was a clone, exit now
		if (!$cloneId && $formerCloneBool) {
			return $containerId;
		}

		$loadId = $containerId;
		if($cloneId > 0) {
			$loadId = $cloneId;
		}

		// make contents list
		$result = $this->dbManipulator->querySelect(CONTAINER_CONTENTS_TABLE, $loadId, '', 'container_id', '`index`');

		if (!$result) {
			$this->debug('ContainersManager::storeContainer, error : unable to get contents list for container #'.$loadId, 2);
			return -1;
		}
		else {
			$contentsTableBool = array();
			while($row = $this->dbManipulator->fetchArray($result)){
				$contentId = $row['content_id'];
				$contentsTableBool[$contentId] = true;
			}
		}

		$contentsTable = &$container->getContentsTable();
		$count = count($contentsTable);

		for ($i = 0; $i < $count; ++$i) {
			$contentId = $contentsTable[$i]->getContentId();

			$fieldsArray = array();
			$fieldsArray['index'] = $i+1;

			if(isset($contentsTableBool[$contentId])) {
				if (!$this->dbManipulator->queryUpdate(CONTAINER_CONTENTS_TABLE, $fieldsArray, $loadId, 'container_id', '`content_id`='.$contentId)) {
					$this->debug("ContainersManager.storeContainer, error : unable to set record for list of container '$loadId'.", 2);
					return -1;
				}
			}
			else {
				$fieldsArray['content_id']   = $contentId;
				$fieldsArray['container_id'] = $loadId;

				$result = $this->dbManipulator->sendQuery("SELECT max(`index`) as `index` FROM `".CONTAINER_CONTENTS_TABLE."` WHERE `container_id` = $loadId;");
				if(!($row = $this->dbManipulator->fetchArray($result))){
					return -1;
				}

				$fieldsArray['index'] = $row['index']+1;

				if (!($result = $this->dbManipulator->queryInsert(CONTAINER_CONTENTS_TABLE, $fieldsArray))) {
					$this->debug('ContainersManager::storeContainer, error : unable to new entry in contents list of container #'.$loadId, 2);
					return -1;
			 	}
			}
		}

		$this->debug('ContainersManager::storeContainer, success : container #'.$containerId.' stored successfully', 9);
		return $containerId;
	}

	function loadLanguageDependencies($containerId) {
		$varsTable["name"] = &$this->containersTable[$containerId]->getNameId();

		foreach($varsTable as $key => $value){
			if (($result = &$this->dbManipulator->getRecord(NAMES_TABLE, $value, "lang_id=".$this->getLangId())) < 0 ){
				$fieldsArray[$key] = "";
				$this->debug("ContainersManager.loadLanguageDependencies, error : container '$containerId' unknown name for language '".$this->getLangId()."'.", 2);
			}
			else{
				if (!($row = &$this->dbManipulator->fetchArray($result))){
					$fieldsArray[$key] = "";
					$this->debug("ContainersManager.loadLanguageDependencies, warning : container '$containerId' unknown $key for language '".$this->getLangId()."' (".$key."_id is $value).", 3);
				}
				else
					$fieldsArray[$key] = $row["value"];
			}
		}

		$this->containersTable[$containerId]->setValues($fieldsArray);
		$this->debug("ContainersManager.loadLanguageDependencies, status: success.", 10);
	}

	/**
	 * Stores Container Translation
	 *
	 * @param  integer $containerId
	 * @param  integer $langId Language Id
	 * @return boolean
	 */
	function storeContainerTranslation($containerId, $langId) {
		$db = $this->getDBManipulator();
		$container = &$this->getContainer($containerId, false);

		if (!$container) {
			return false;
		}
		if ($containerId == 0) {
		// create new label id's for the container fields
			$labels = array(
				'name'        => ''
			);
			$containerValues = array();
			foreach ($labels as $key => $value) {
				$record = array();
				$record['lang_id'] = '1';
				$record['value'] = '';
				$res = $db->addRecord(NAMES_TABLE, $record);
				if ($res && $db->getLastId()) {
					$containerValues[$key.'_id'] = $db->getLastId();
				}
			}
			$container->setContainerValues($containerValues);
		}
		$labels = array(
			 'name'        => $container->getContainerNameId()
		);
		$containerValues = array();
		$valuesTableLang = &$container->getContainerValuesTable();
  	foreach($valuesTableLang as $langId => $valuesTable) {
			if(!is_int($langId)) {
				continue;
			}
			foreach ($labels as $key => $labelId) {
				$record = array();
				$record['value'] = $this->html_encode($valuesTable[$key]);
				//$record['value'] = $valuesTable[$key];
				if ($labelId == 0) {
					// create new record
					$record['lang_id'] = $langId;
					$res = $db->addRecord(NAMES_TABLE, $record);
					if ($res && $db->getLastId()) {
						$containerValues[$key.'_id'] = $db->getLastId();
					}
				}
				else {
					// update record or create new record
					$res = $db->getRecord(NAMES_TABLE, $labelId, '`lang_id`='.$langId);
					if ($res && $db->getNumRows()) {
						$res = $db->setRecord(NAMES_TABLE, $labelId, $record, '`lang_id`='.$langId);
					}
					elseif ($res && !$db->getNumRows()) {
						$record['id'] = $labelId;
						$record['lang_id'] = $langId;
						$res = $db->addRecord(NAMES_TABLE, $record);
					}
				}
			}
		}
		$container->setContainerValues($containerValues);
		return true;
  }

	function storeLanguageDependencies($containerId, $langId=LOAD_ALL_LANGUAGES) {
    $this->storeContainerTranslation($containerId, $langId);
  }

	/**
	 * Stores Language Dependencies
	 *
	 * @param  integer $containerId
	 * @return boolean
	 */
	function _storeLanguageDependencies($containerId) {
		$container = &$this->getContainer($containerId);

		if (!$container) {
			$this->debug('ContainersManager::storeLanguageDependencies, error : container #'.$containerId.' not defined', 1);
			return false;
		}

		// new container
		if ($containerId == 0) {
			$varsTable = array();
			$varsTable['name'] = $container->getContainerName();

			$containerFieldsArray = array();

			foreach($varsTable as $key => $value){
				$labelFieldsArray = array();
				$labelFieldsArray['value'] = $value;
				$labelFieldsArray['lang_id'] = $this->getLangId();
	        	if (!$this->dbManipulator->queryInsert(NAMES_TABLE, $labelFieldsArray)) {
					$this->debug('ContainersManager::storeLanguageDependencies, error : unable to create new label', 1);
					return -1;
				}
				$containerFieldsArray[$key.'_id'] = $this->dbManipulator->getLastId();
			}
			$container->setValues($containerFieldsArray);
			$this->debug("ContainersManager.storeLanguageDependencies, new labels created successfully.", 10);
			return 1;
		}
		else {
			$containerNameId = $container->getContainerNameId();
			$containerName = $container->getContainerName();

			$varsTable = array();
			$varsTable[$containerNameId] = $containerName;

			foreach ($varsTable as $key => $value) {
				$labelFieldsArray = array();
				$labelFieldsArray['value'] = $value;

				if ($this->dbManipulator->recordExists(NAMES_TABLE, $key, '`lang_id`='.$this->getLangId())) {
	        		if (!$this->dbManipulator->queryUpdate(NAMES_TABLE, $labelFieldsArray, $key, 'id', '`lang_id`='.$this->getLangId())){
						$this->debug("ContainersManager.storeLanguageDependencies, status : error.", 1);
						return -1;
					}
				}
				else {
					$labelFieldsArray['id'] = $key;
					$labelFieldsArray['lang_id'] = $this->getLangId();
	        		if (!$this->dbManipulator->queryInsert(NAMES_TABLE, $labelFieldsArray)) {
						$this->debug("ContainersManager.storeLanguageDependencies, status : error.", 1);
						return -1;
					}
				}

				$this->debug("ContainersManager.storeLanguageDependencies, labels updated successfully.", 10);
			}
		}

		return true;
	}

	/**
	 * Removes Container
	 *
	 * @param  integer $containerId
	 * @return boolean
	 */
  function removeContainer($containerId) {
		if (!($container = &$this->getContainer($containerId))) {
			$this->debug('ContainersManager::removeContainer, error : trying to remove unexisting container #'.$containerId, 2);
			return false;
		}

		$container->setContainerDeleted(1);

		if (!$this->storeContainer($containerId)) {
			return false;
		}

		return true;
  }

	/**
	 * Adds Content Into Container
	 *
	 * @param  integer $containerId
	 * @param  integer $contentId
	 * @return boolean
	 */
	function addContent($containerId, $contentId){
		$dbManipulator = &$this->getDBManipulator();
		if($container = &$this->getContainer($containerId)){
			$fields = array();
			$fields['container_id'] = $containerId;
			$fields['content_id'] = $contentId;

			$result = $dbManipulator->sendQuery("SELECT max(`index`) as `index` FROM `".CONTAINER_CONTENTS_TABLE."` WHERE `container_id` = $containerId;");
			if(!($row = $dbManipulator->fetchArray($result))){
				return false;
			}

			$fields['index'] = $row['index']+1;

			if(!$dbManipulator->addRecord(CONTAINER_CONTENTS_TABLE, $fields)){
				return false;
			}
		}
		return true;
	}

	/**
	 * Removes Content From Container
	 *
	 * @param  integer $containerId
	 * @param  integer $contentId
	 * @return boolean
	 */
	function removeContent($containerId, $contentId){
		$db = &$this->getDBManipulator();
		$removed = false;
		if($db->delRecord(CONTAINER_CONTENTS_TABLE, $containerId, "`content_id`=$contentId", 'container_id')){
			$removed = true;
		}
		return $removed;
  }

  function checkContainer($containerId) {
  	return isset($this->containersTable[$containerId]);
  }

	/**
	 * Tells if a container is present in the database
	 *
	 * @param  integer $containerId
	 * @return boolean
	 */
	function containerExists($containerId) {
		// try to load the container
		$this->getContainer($containerId);
		// returns true if the container exists
		return $this->checkContainer($containerId);
	}

  	/**
	 * Gets Container
	 *
 	 * @param  integer $containerId
	 * @param  boolean $loadContent
 	 * @return mixed object or null
	 */
	function &getContainer($containerId, $loadContent=true, $reload=false){
  	if ($reload || !$this->checkContainer($containerId)){
			if (!$this->loadContainer($containerId, $loadContent)){
				$this->debug('ContainersManager::getContainer, error : unable to get container #'.$containerId, 3);
				return null; //-1;
			}
		}
		$this->debug('ContainersManager::getContainer, success : got container #'.$containerId, 9);
  	return $this->containersTable[$containerId];
	}

	/**
	 * Sets Container into manager
	 *
	 * @param  object $container
	 * @return boolean
	 */
	function setContainer(&$container) {
		$containerId = $container->getContainerId();
		$this->containersTable[$containerId] = &$container;
		$this->debug('ContainersManager::setContainer, succes : container #'.$containerId.' set', 9);
		return true;
	}

	/**
	 * @deprecated use {@link setContainer}
	 */
	function addContainer(&$container) {
		if ($this->checkContainer($container->getContainerId())){
			$this->debug("ContainersManager.addContainer id:".$container->getContainerId().", warning : container of id '".$container->getContainerId()."' already loaded in container manager : value overwritten.", 3);
			//return -1;
		}
		$this->containersTable[$container->getContainerId()] = &$container;

		$this->debug("ContainersManager.addContainer id:".$container->getContainerId().", status : success.", 10);
		return 1;
	}

	/**
	 * Gets New Container
	 *
	 * Returns a new Container object
	 *
	 * @param  integer $aclId
	 * @return object
	 */
	function &getNewContainer($aclId=0) {
		$id          = 0;
		$nameId      = 0;
		$typeName    = '';
		$templateId  = 0;
		$sortingType = 1;
		$sortField   = '';
		$sortOrder   = 1;
		$shownFrom   = 0;
		$countShown  = 0;
		$cloneId     = 0;
		$deleted     = 0;

		$this->containersTable[0] = &new Container($id, $nameId, $typeName,	$templateId, $sortingType, $sortField, $sortOrder, $shownFrom, $countShown, $cloneId, $deleted, $aclId);
    $this->containersTable[0]->setContainerPublished(PUBLICATION_DEFAULT_VALUE);
		return $this->containersTable[0];
	}

	function getParentObjectValuesArray($containerId, $pageId, $frameId) {
		$result = $this->dbManipulator->queryGetPageOfContainer($pageId, $frameId, $containerId);

		if (!$result) {
			return null;
		}

		if (!$this->dbManipulator->getNumRows()) {
			$result = $this->dbManipulator->queryGetContainersListOfContainer($containerId);

			if (!$result || !$this->dbManipulator->getNumRows()) {
				return null;
			}
		}

		$row = $this->dbManipulator->fetchArray($result);

		return $row;
	}

	/**
	 * Gets Languages
	 *
	 * Returns associative array of available languages
	 *
	 * @return array
	 * @todo discussion about the right place for this function (managers interface ? / dbManipulator ?)
	 */
	function getLangsArray() {
		$dbManipulator = &$this->getDBManipulator();
		$result        = $dbManipulator->getRecord(LANGUAGES_TABLE, -1, '', 'id', 'name');
		if (!$result) {
			return null;
		}
		$langsArray = array();
		while ($row = $dbManipulator->fetchArray($result)) {
			$langId = $row['id'];
			$langsArray[$langId] = $row['name'];
		}
		return $langsArray;
	}

  /**
   * Updates Container ACL
   *
   * @param  integer $containerId Container Id
   * @param  integer $aclId New ACL Id
   * @return boolean
   */
  function updateContainerACL($containerId, $aclId){
		$container = &$this->getContainer($containerId);
		$oldAclId = $container->getContainerAclId();

    $db = &$this->getDBManipulator();
    $fields = array('acl_id' => $aclId);

    if(!$db->setRecord(CONTAINERS_TABLE, -1, $fields, "`id`='$containerId'")){
			$this->debug("ContainersManager.updateContainerACL : error, unable to set new acl_id for container (id=$containerId).", 3);
			return false;
		}

		$contentsTable = &$container->getContentsTable();

		for($i=0; $i < count($contentsTable); ++$i) {
			$content = &$contentsTable[$i];
			if($content->getContentAclId() == $oldAclId) {
				$this->contentsManager->updateContentACL($content->getContentId(), $content->getContentTypeName(), $aclId);
			}
		}
		return true;
/*
    $updated = false;
    $db = &$this->getDBManipulator();
    $fields = array('acl_id' => $aclId);
    $cond = '`id` in ('.implode(',', (array)$id).')';
    if($db->setRecord(CONTAINERS_TABLE, -1, $fields, $cond)){
    	$updated = true;
	    $res = $db->getRecord(CONTAINERS_TABLE, -1, $cond);
	    if($res && $db->getNumRows()){
	      while($rec = $db->fetchArray($res)){
	        $containerId = (int)$rec['id'];
	        $typeName = $rec['type_name'];
	        $deleted = true;
	        $res2 = $db->getContainerContents($containerId, $typeName, $deleted);
	        if(!$res2){
	        	$updated = false;
	        	break;
	        }
          $contentsIdList = array();
          while($rec2 = $db->fetchArray($res2)){
            $contentsIdList[] = (int)$rec2['id'];
          }
          if(count($contentsIdList)){
	          if(!$this->contentsManager->updateContentACL($contentsIdList, $typeName, $aclId)){
	          	$updated = false;
	            break;
	          }
          }
	      }
	    }else{
	    	$updated = false;
	    }
    }
    return $updated;
*/
  }

	/**
	 * Returns all content types available
	 *
	 * @author vinadelmar
	 * @since  2006-06-10
	 * @return array
	 */
	function getContentTypesArray() {
		$contentTypesArray = array();

		$prefix = TYPE_TABLES_PREFIX;
		$prefixLen = strlen($prefix);

		$result = $this->dbManipulator->getTables($prefix);

		if (!$result) {
			return null;
		}

		while ($row = $this->dbManipulator->fetchArray($result)) {
			$contentTypesArray[] = substr($row[0], $prefixLen);
		}

		return $contentTypesArray;
	}

}

?>