<?php
/*
 * This file is part of the easy-CMS project.
 * easy-CMS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * easy-CMS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with easy-CMS; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

/**
 * @package    Core
 * @subpackage Contents
 */

/**
 */
include_once('config.inc.php');
include_once('classes/core/CoreObject.class.php');
include_once('classes/core/types/TypesManager.class.php');
include_once('classes/core/types/Type.class.php');
include_once('classes/core/contents/ContentsManager.class.php');
include_once('classes/core/nodes/myNodeContent.class.php');
include_once('interface/egManager.class.php');
include_once('interface/egContainer.class.php');
include_once('interface/egContextMenu.class.php');


/**
 * Content Class
 *
 * Generic content class. Holds fields value for a specified CMS type.
 *
 * @access     public
 * @author	   Cedric Francoys <cedric.francoys@easy-cms.org>
 * @version	   Content.class, Sun Nov 14 16:56:31 CET 2004
 * @package    Core
 * @subpackage Contents
 */
class Content extends CoreObject {
	/**#@+
	 * @access private
	 */
	/**
	 * @var integer Content Id
	 */
    var $id;

	/**
	 * @var string Content Type Name
	 */
    var $typeName;

	/**
	 * @var array Associative array of Easy-CMS types objects
	 */
    var $valuesTable;

	/**
	 * @var integer Deleted Content
	 */
    var $deleted;

	/**
	 * @var integer Published Content
	 */
    var $published;

	/**
	 * @var integer Content ACL Id
	 */
    var $aclId;

	/**
	 * @var object ACL
	 */
    var $acl;
	/**#@-*/

	/**
	 * @deprecated
	 * @todo approve deprecation
	 */
  //var $typesTable;

	/**
	 * @deprecated
	 * @todo approve deprecation
	 */
  //var $contentsManager;

	function getClassName() {
		return 'Content';
	}

	/**#@+
	 * @access public
	 */
	/**
	 * Class constructor
	 *
	 * @param integer $id Content ID
	 * @param string  $typeName Content type
	 * @param array   $valuesTable associative array of Easy-CMS types objects
	 * @param integer $deleted Is Content Deleted
	 * @param integer $aclId Content's ACL ID
	 */
	function Content($id, $typeName, &$valuesTable, $deleted, $aclId) {
		$this->setContentId($id);
		$this->setContentTypeName($typeName);
		$this->setContentValuesTable($valuesTable);
		$this->setContentDeleted($deleted);
		$this->setContentAclId($aclId);
	}

	/**
	 * Gets Content Id
	 *
	 * @return integer
	 */
	function getContentId() {
		return $this->id;
	}

	/**
	 * Sets Content Id
	 *
	 * @param integer $id Content Id
	 */
  function setContentId($id) {
		$this->id = $id;
	}

	/**
	 * Gets Content Type Name
	 *
	 * @return string
	 */
	function getContentTypeName() {
		return $this->typeName;
	}

	/**
	 * Sets Content Type Name
	 *
	 * @param string $typeName Content Type Name
	 */
	function setContentTypeName($typeName) {
		$this->typeName = $typeName;
	}

	/**
	 * Gets Content Values
	 *
	 * Returns associative array of Easy-CMS types objects
	 *
	 * @return array
	 */
	function &getContentValuesTable() {
		return $this->valuesTable;
	}

	/**
	 * Sets Content Values
	 *
	 * @param array $valuesTable Associative array of easy-CMS types objects
	 * values already set are overwritten
	 */
	function setContentValuesTable(&$valuesTable) {
    foreach($valuesTable as $langId => $langValuesTable) {
      foreach($langValuesTable as $field => $value) {
		    $this->valuesTable[$langId][$field] = $value;
      }
    }
	}


	/**
	 * Gets Content Deletion
	 *
	 * Returns the deletion status of the content
	 *
	 * @return integer
	 */
	function getContentDeleted() {
		return $this->deleted;
	}

	/**
	 * Gets Content Publication
	 *
	 * Returns the publication status of the content
	 *
	 * @return integer
	 */
	function getContentPublished() {
		return $this->published;
	}

	function isPublished() {
		return (bool) $this->getContentPublished();
	}

	/**
	 * Sets Content Deletion
	 *
	 * Tells if Content is deleted or not
	 *
	 * @param integer $deleted 0|1
	 */
	function setContentDeleted($deleted) {
		$this->deleted = $deleted;
	}

	/**
	 * Sets Content Publication
	 *
	 * Tells if Content is published or not
	 *
	 * @param integer $published 0|1
	 */
	function setContentPublished($published) {
		$this->published = $published;
	}

	/**
	 * Gets Content ACL Id
	 *
	 * @return integer
	 */
	function getContentAclId() {
		return $this->aclId;
	}

	/**
	 * alias for getContentAclId
	 *
	 * @return integer
	 */
	function getAclId() {
		return $this->aclId;
	}

	/**
	 * Sets Content ACL Id
	 *
	 * @param integer $aclId ACL Id
	 */
	function setContentAclId($aclId) {
		$this->aclId = $aclId;
	}

	/**
	 * Gets Content ACL
	 *
	 * Returns a reference to the ACL object used by Content
	 *
	 * @return object
	 */
	function &getContentAcl() {
		if (!isset($this->acl))
			return null;
		return $this->acl;
	}

	/**
	 * Sets Content ACL
	 *
	 * @param object $acl ACL object
	 */
	function setContentAcl(&$acl) {
		$this->acl = &$acl;
	}

	/**
	 * Returns value for given field
	 *
	 * @param  string $field
	 * @return mixed  <0 if error
	 */
	function getContentFieldValue($langId, $field) {
		/*
        if (!$this->checkField($field)) {
            return -1;
		}
        return $this->valuesTable[$field];
		*/
		if (!$this->contentFieldExists($langId, $field)) {
			return null;
		}

		return $this->valuesTable[$langId][$field];
	}

	/**
	 * Set value
	 *
	 * @param  string $field
	 * @param  object $valueObj
	 * @return mixed
	 */
	function setContentFieldValue($langId, $name, $value) {
		if ($this->valueExists($langId, $name)) {
			return false;
		}

		$this->valuesTable[$langId][$name] = $value;

		return true;
	}

	/**
	 * Content Value Exists
	 *
	 * Tells if specific value is defined for Content
	 *
	 * @param  string $field value name
	 * @return boolean
	 */
	function contentFieldExists($langId, $field) {
		return isset($this->valuesTable[$langId][$field]);
	}

	/**
	 * @return boolean
	 * @todo check code
	 */
	function compareTo(&$contentObj, $field, $langId) {
		if ($field == '') {
			return 1;
    }
		if(!($subObj1 = $this->getContentFieldValue($langId, $field))) {
      return -1;
    }
		if(!($subObj2 = $contentObj->getContentFieldValue($langId, $field))) {
      return 1;
    }
		return $subObj1->compareTo($subObj2);
	}

	/**
 	 * @return string
 	 *
 	 */
	function toHTML($langId)	{
		$valuesTable = &$this->getContentValuesTable();
 		$str = "";
		foreach ($valuesTable[$langId] as $key => $value) {
			$valueSummary = htmlentities(String::summarize($value->toString(), 40));
			$cr = array("\n", "\r", "\r\n");
			$valueSummary = str_replace($cr, '', $valueSummary);
			$str .= "<b>$key : </b>&nbsp;&nbsp;".$valueSummary."<br />";
		}
 		return $str;
 	}


	/**
	 * Exports Content Into XML
	 *
	 * @param  object $user User object
	 * @param  integer $containerId Container ID
	 * @param  string $mode
	 * @return string XML
	 */
  function toXML(&$user, $langId, $containerId=0, $cloneId=0, $mode=VIEW_MODE) {
		$id          = $this->getContentId();
		$typeName    = $this->getContentTypeName();
		$valuesTable = &$this->getContentValuesTable();

		$realContainerId = $containerId;

		if($cloneId > 0) {
			$realContainerId = $cloneId;
		}

		$this->debug('Content::toXML, status : method invoked for Content(id='.$id.' type_name="'.$typeName.'")', 10);

    $xml = '';
		if ($this->acl->userHasViewRight($user) && ($mode == EDIT_MODE || $this->isPublished())) {
      if(isset($valuesTable[$langId])) {
        $xml .= '<'.$typeName.'>'."\n";
  			$xml .= '  <id>'.$id.'</id>'."\n";
  			$xml .= '  <container-id>'.$realContainerId.'</container-id>'."\n";
        foreach($valuesTable[$langId] as $key => $value) {
          $xml .= '  <'.$key.'>'.$value->toXML().'</'.$key.'>'."\n";
        }
        if ($this->acl->userHasEditRight($user) && $mode == EDIT_MODE) {
  				$xml .= '  <content_controls>'."\n";
  				$xml .= '    <type>'.$typeName.'</type>'."\n";
  				$xml .= '    <id>'.$id.'</id>'."\n";
  				$xml .= '    <container-id>'.$containerId.'</container-id>'."\n";
  				$xml .= '    <clone-id>'.$cloneId.'</clone-id>'."\n";
  				$xml .= '  </content_controls>'."\n";
  			}
  			$xml .= '</'.$typeName.'>'."\n";
      }
    }
		return $xml;
	}

	/**
	 * Gets Content Controls
	 *
	 * Content controls pop-up menu
	 *
	 * @param  object $user User Object
	 * @param  integer $containerId Container Id
	 * @param  string $mode
	 * @return string html
	 */
	function getControls(&$user, $containerId=0, $cloneId=0, $mode=VIEW_MODE) {

		$contentId  = $this->getContentId();
		$typeName   = $this->getContentTypeName();
		$acl        = &$this->getContentAcl();

		$realContainerId = $containerId;
		if($cloneId > 0) {
			$realContainerId = $cloneId;
		}

		$html = '';

		if ($acl->userHasEditRight($user) && $mode == EDIT_MODE) {
      $menu = &new egContextMenu("menu_content_".$containerId."_".$cloneId."_".$contentId, 0, 0, 150, 350);

			// move up
      $menu->addListItem(new egMenuItem("mnu_cn_".$containerId."_".$cloneId."_".$contentId."_2", LANG_CONTENT_MENU_MOVE_UP, "interface/icons/move_up.png", "moveUpCn_".$containerId."_".$cloneId."_".$contentId."();"));
			// move down
      $menu->addListItem(new egMenuItem("mnu_cn_".$containerId."_".$cloneId."_".$contentId."_3", LANG_CONTENT_MENU_MOVE_DOWN, "interface/icons/move_down.png", "moveDownCn_".$containerId."_".$cloneId."_".$contentId."();"));
	    $menu->addSeparator();
			// remove content
			if ($this->acl->userHasRemoveRight($user)) {
        $menu->addListItem(new egMenuItem("mnu_cn_".$containerId."_".$cloneId."_".$contentId."_4", LANG_CONTENT_MENU_REMOVE, "interface/icons/remove.png", "launchContentDeletionWindow(\'container_id=$realContainerId&amp;content_id=$contentId&amp;type_name=$typeName\');"));
			}
	    $menu->addSeparator();
			// content properties
	    $menu->addListItem(new egMenuItem("mnu_cn_".$containerId."_".$cloneId."_".$contentId."_5", LANG_CONTENT_MENU_EDIT, "interface/icons/edit.png", "launchContentEditionWindow(\'container_id=$realContainerId&amp;content_id=$contentId&amp;type_name=$typeName\');"));

      $main = &new egContainer("eg_ctn_cn_".$containerId."_".$cloneId."_".$contentId, 0, 0, 0, 0);

      $main->addObject($menu);

      $manager = &egManager::getInstance();
    	$manager->addContainer($main);
      $scripts = new egScript();

      $line = "function moveUpCn_".$containerId."_".$cloneId."_".$contentId."() {
window.location.href = 'index.php?display=".EDIT_CONTAINER."&action=".MOVE_CONTENT_UP."&container_id=$realContainerId&content_id=$contentId';
}
function moveDownCn_".$containerId."_".$cloneId."_".$contentId."() {
window.location.href = 'index.php?display=".EDIT_CONTAINER."&action=".MOVE_CONTENT_DOWN."&container_id=$realContainerId&content_id=$contentId';
}";
      $scripts->addLine($line);

      $manager->addScripts($scripts);
    }
		return $html;
	}
	/**#@-*/
}

?>