<?php
/*
 * This file is part of the Easy-CMS project.
 * Easy-CMS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * Easy-CMS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Easy-CMS; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *  
 */

/**
 * @package    Core
 * @subpackage Contents
 */
 
include_once('config.inc.php');
include_once('classes/core/DBAccessorObject.class.php');
include_once('classes/core/DBManipulator.class.php');
include_once('classes/core/types/Type.class.php');
include_once('classes/core/types/TypesManager.class.php');
include_once('classes/core/contents/Content.class.php');
include_once('classes/core/versions/ContentVersionsManager.class.php');

include_once('classes/types/Bool.class.php');
include_once('classes/types/Color.class.php');
include_once('classes/types/Date.class.php');
include_once('classes/types/Document.class.php');
include_once('classes/types/Image.class.php');
include_once('classes/types/Integer.class.php');
include_once('classes/types/Float.class.php');
include_once('classes/types/Reference.class.php');
include_once('classes/types/String.class.php');
include_once('classes/types/ShortText.class.php');
include_once('classes/types/Link.class.php');
include_once('classes/types/Text.class.php');
include_once('classes/types/Time.class.php');


/**
 * ContentsManager Class
 *
 * Manages instances of Content
 *
 * @access     public
 * @author	   Cedric Francoys <cedric.francoys@easy-cms.org>
 * @version	   ContentsManager.class, Sun Apr 03 11:11:13 CEST 2005
 * @package    Core
 * @subpackage Contents
 */
class ContentsManager extends DBAccessorObject {
	/**#@+
	 * @access private
	 */
	/**
	 * TypesManager
	 *
	 * @var object
	 */
	var $typesManager;
	
	/**
	 * ACLManager
	 *
	 * @var object
	 */
	var $aclManager;
	
	/**
	 * @var array
	 */
	var $contentsDescr;
	
	/**
	 * 
	 */
	var $typesArray;
	
	/**
	 * Content Objects Table
	 *
	 * @var array
	 */
	var $contentsTable;
	
	/**#@-*/
	
	 
	/**
	 * Class constructor
	 *
	 * @param object  $dbManipulator instance of DBManipulator
	 * @param object  $aclManager instance of ACLManager
	 * @param object  $typesManager instance of TypesManager
	 * @param integer $langId current language
	 */
  function ContentsManager(&$dbManipulator, &$aclManager, &$typesManager) {
		parent::DBAccessorObject($dbManipulator);
		$this->aclManager = &$aclManager;
		$this->typesManager = &$typesManager;
		$this->contentsTable = array();
		$this->contentsDescr = array();
  }

	/**
	 * Gets ACLManager
	 *
	 * @return object
	 */ 
	function &getAclManager() {
		return $this->aclManager;
	}

	/**
	 * Gets TypesManager
	 *
	 * @return object
	 */
	function &getTypesManager() {
		return $this->typesManager;
	}


	function &getContentTypesFields() {
    $db = &$this->getDBManipulator();
		$prefix = TYPE_TABLES_PREFIX;
		$len = strlen($prefix);
		$result = &$db->getTables($prefix);
    $contentTypesFieldsArray = array();
		while($row = &$db->fetchRow($result)){
      $typeName = substr($row[0], $len);
			$contentTypesFieldsArray[$typeName] = $db->getFieldsArray($row[0]);
		}
    return $contentTypesFieldsArray;
  }

	function &getContentTypesTemplates() {
    $db = &$this->getDBManipulator();
		$prefix = TYPE_TABLES_PREFIX;
		$len = strlen($prefix);
		$result = &$db->getTables($prefix);
    $contentTypesTemplatesArray = array();
		while($row = &$db->fetchRow($result)){
      $typeName = substr($row[0], $len);
			$contentTypesTemplatesArray[$typeName] = array();
		  $result1 = &$db->getRecord(TEMPLATES_TABLE, -1, "type='$typeName'");
		  while($row1 = &$db->fetchArray($result1)){
        $contentTypesTemplatesArray[$typeName][$row1['id']] = $row1['name'];
      }
		}
    return $contentTypesTemplatesArray;
  }

	/**
	 * Returns instance of "simple type" class
	 *
	 * @param  integer $type
	 * @param  value   $mixed
	 * @return mixed  object or null if error
	 * @todo discuss deprecation (private method?)
	 */
	function &createFieldObject($type, $value) {
		return $this->typesManager->createTypeObject($type, $value);
	}
	
	/**
	 * Load content
	 *
	 * Load content from content_type_* table. First tries to get
	 * instance of complex type $typeName. Then tries to get record from
	 * corresponding table in database where $id is the record id. 
	 * If successful, create instance of content object with values from record 
	 * and add content to contents manager.
	 *
	 * @param  integer $id
	 * @param  string  $typeName
	 * @param  boolean $loadDeleted
	 * @return boolean
	 * @todo approve modifications
	 */
	function loadContent($id, $typeName, $loadDeleted=false, $loadAcl=true, $langId=LOAD_ALL_LANGUAGES) {
		$db = &$this->getDBManipulator();
		
		$tableName = TYPE_TABLES_PREFIX.$typeName;
		
		if (!isset($this->contentsDescr[$typeName])) {
			$this->contentsDescr[$typeName] = $db->getFieldsArray($tableName);
		}

		if($langId != LOAD_ALL_LANGUAGES) {
			$cond = '`lang_id`= '.$langId;
		}
    else {
      $cond = '';
    }

		if (is_array($id)) {
			$csv = implode(',', $id);
      if(strlen($cond)) {
			 $cond .= ' and `id` in ('.$csv.')';
      }
      else {
			 $cond = ' `id` in ('.$csv.')';
      }
			$res = $db->getRecord($tableName, 0, $cond);
		}
		else {
			$csv = $id;
			$res = $db->getRecord($tableName, $id, $cond);
		}
		
		if (!$res || !$db->getNumRows()) {
			$this->debug('ContentsManager::loadContent, error : unable to load Content(id='.$csv.' type_name="'.$typeName.'")', 3);
			return false;
		}
		
		while ($record = $db->fetchArray($res)) {
			$contentId   = $record['id'];
			$aclId       = $record['acl_id'];
			$deleted     = $record['deleted'];
			$published   = $record['published'];
			$langId			 = $record['lang_id'];

			if(!$deleted || $loadDeleted) {
				$valuesTable = array();
				foreach ($this->contentsDescr[$typeName] as $field => $fieldType) {
					switch ($fieldType) {
						case INTEGER:
							$valuesTable[$langId][$field] = &new Integer($record[$field]);
							break;
						case FLOAT:
							$valuesTable[$langId][$field] = &new Float($record[$field]);
							break;
						case BOOL:
							$valuesTable[$langId][$field] = &new Bool($record[$field]);
							break;
						case STRING:
							$valuesTable[$langId][$field] = &new String($record[$field]);
							break;
						case SHORTTEXT:
							$valuesTable[$langId][$field] = &new ShortText($record[$field]);
							break;
						case TEXT:
							$valuesTable[$langId][$field] = &new Text($record[$field]);
							break;
						case COLOR:
							$valuesTable[$langId][$field] = &new Color($record[$field]);
							break;
						case LINK:
							$valuesTable[$langId][$field] = &new Link($record[$field]);
							break;
						case DATE:
							$valuesTable[$langId][$field] = &new Date($record[$field]);
							break;
						case TIME:
							$valuesTable[$langId][$field] = &new Time($record[$field]);
							break;
						case DOCUMENT:
							$valuesTable[$langId][$field] = &new Document($record[$field]);
							break;
						case IMAGE:
							$valuesTable[$langId][$field] = &new Image($record[$field]);
							break;
						case REFERENCE:
							$valuesTable[$langId][$field] = &new Reference($record[$field]);
							break;
					}
				}

	      if ($this->checkContent($contentId, $typeName)) {
	        $this->contentsTable[$typeName][$contentId]->setContentValuesTable($valuesTable);
	      }
	      else {
	  			$content = &new Content($contentId, $typeName, $valuesTable, $deleted, $aclId);
					$content->setContentPublished($published);

	  			if ($loadAcl) {
	  				if ($acl = &$this->getContentAcl($aclId)) {
	  					$content->setContentAcl($acl);
	  				}
	  			}

	  			$this->addContent($content);
	      }
			}
		}
		return true;
	}
	
	/**
	 * Gets Content ACL
	 *
	 * @param  integer $aclId ACL Id
	 * @return object
	 */
	function &getContentAcl($aclId) {
		$acl = &$this->aclManager->getACL($aclId);
		return $acl;
	}

	/**
	 * Sets Content
	 *
	 * @param  integer $id
	 * @param  string  $typeName
	 * @param  array   $array Associative array [lang][type] => value
	 * @return boolean
	 * @todo approve modifications
	 */
	function setContent($id, $typeName, $array) {
		// to change : type and typesManager calls should be removed (need some additional functions)
		if (!($type = &$this->typesManager->getType($typeName))) {
			$this->debug("ContentsManager.setContent, error : type '".$typeName."'unknown.", 1);
			return false;
		}
		if (!($content = &$this->getContent($id, $typeName))) {
			return false;
		}
		if (!($simpleTypesArray = $type->getSimpleTypesArray())) {
			return false;
		}
		
		$valuesTable = array();
		
		$langsArray = &$this->getLangsArray();

		foreach ($langsArray as $langId => $langName) {
			if(isset($array[$langId])) {
				foreach ($simpleTypesArray as $name => $valueType) {
          if(!isset($array[$langId][$name])) {
            // error : invalid array was submitted
          }
          else {
  					$valuesTable[$langId][$name] = $this->typesManager->createTypeObject($valueType, $array[$langId][$name]);
          }
				}
			}
		}
		if(isset($array['deleted'])) {
			$content->setContentDeleted($array['deleted']);
		}
		if(isset($array['published'])) {
			$content->setContentPublished($array['published']);
		}
		if(isset($array['acl_id'])) {
			$content->setContentAclId($array['acl_id']);
		}
		$content->setContentValuesTable($valuesTable);
		
		return true;
	}
    
	/**
	 * Stores Content
	 *
	 * @param  integer $contentId
	 * @param  string  $contentType
	 * @return integer Content ID or <0 if error
	 */
	function storeContent($id, $typeName) {
		if (!($type = &$this->typesManager->getType($typeName))) {
			return 0;
		}
		if (!($content = &$this->getContent($id, $typeName))) {
			return 0;
		}

		$aclId   = (!$id) ? 1 : $content->getContentAclId();
		$deleted = $content->getContentDeleted();
		$published = $content->getContentPublished();

		$fieldsArray = array();
		$valuesTableLang = &$content->getContentValuesTable();

		foreach($valuesTableLang as $langId => $valuesTable) {
        foreach($valuesTable as $name => $value) {
            $fieldsArray[$name] = $value->toSQL();
        }

				// control fields
				$fieldsArray['lang_id'] = $langId;
				$fieldsArray['acl_id']  = $aclId;
				$fieldsArray['deleted'] = $deleted;
				$fieldsArray['published'] = $published;

				if(!$id || !$type->recordExists($id, $langId)){
					if (!($newId = $type->addRecord($id, $fieldsArray, $langId))) {
						$this->debug('ContentsManager::storeContent, error : unable to add record to `'.TYPE_TABLES_PREFIX.$typeName.'` table', 3);
						return 0;
					}
					$id = $newId;
					$content->setContentId($id);
					$this->addContent($content);
				}
				else {
					$type->setRecord($id, $fieldsArray, $langId);
				}
	
		}
		$this->debug('ContentsManager::storeContent, success : content #'.$id.' stored', 9);

		return $id;	
	}
	
	/**
	 * Gets Content's Versions
	 *
	 * @todo check for uselessness
	 */
	function getContentVersionsArray($id, $typeName, $langId) {
		$versionsArray = array();
		
		$result = $this->dbManipulator->queryGetContentVersions($contentId, $contentType, $langId);
		
		if (!$result || !$this->dbManipulator->getNumRows()) {
			return null;
		}
		
		return $versionsArray;
	}

	/**
	 * Removes Content
	 *
	 * @param  integer $id
	 * @param  string  $typeName
	 * @return boolean
	 */
	function removeContent($id, $typeName) {
		if (!($content = &$this->getContent($id, $typeName))){
			$this->debug("ContentsManager.removeContent, error : trying to remove unexisting content '$id'.", 2);
			return false;
		}
		$content->setContentDeleted(1);
		if (!$this->storeContent($id, $typeName)) {
			return false;
		}
		return true;
		/*
		if (($content = &$this->getContent($id, $typeName)) < 0){
			$this->debug("ContentsManager.removeContent, error : trying to remove unexisting content '$id'.", 2);
			return -1;
		}
		
		$deleted = 1;
		
		$content->setDeleted($deleted);
		$this->storeContent($id, $typeName);
		
		return 1;
		*/
	}

	/**
	 * Check for instance of content object
	 *
	 * @param  integer $id content id
	 * @param  string  $typeName content type
	 * @return boolean
	 * @deprecated due to naming convention
	 * @todo approve deprecation
	 */
  function checkContent($id, $typeName) {
    return isset($this->contentsTable[$typeName][$id]);
  }
	
	/**
	 * Tells if content exists in database
	 *
	 * @param  integer $id
	 * @param  string  $typeName
	 * @return boolean
	 * @todo approve modifications
	 */
	function contentExists($id, $typeName){
		return isset($this->contentsTable[$typeName][$id]);
	}
	/*
	function contentExists($id, $typeName) {
		// try to load the container
		$this->getContent($id, $typeName);
		// returns true if the container has been sucessfully loaded
		return $this->checkContent($id, $typeName);
	}
	*/

  /**
	 * Gets Content
	 *
	 * First checks if instance already exists. If not tries to load it.
	 * 
 	 * @param  integer $id
	 * @param  string $typeName
 	 * @return object
	 */
  function &getContent($id, $typeName, $langId=LOAD_ALL_LANGUAGES) {
    if (!$this->contentExists($id, $typeName)) {
			if (!$this->loadContent($id, $typeName, $langId)) {
				$this->debug("ContentsManager.getContent, error : unable to load content '$id'.", 2);
				return null;
			}
		}
		$this->debug('ContentsManager::getContent, success : got Content(id='.$id.' type_name="'.$typeName.'")', 10);
		return $this->contentsTable[$typeName][$id];
  }
    
	/**
	 * Add Content to Manager
	 *
	 * @param  object $content
	 * @return boolean
	 * @todo approve modifications
	 */
  function addContent(&$content) {
		// check if content already exists
		/*
    	if ($this->checkContent($content->getId(), $content->getTypeName())){
			$this->debug("ContentsManager.addContent, error : content of id '".$content->getId()."' already loaded in contents manager.", 2);
			return -1;
		}
		*/
		$id = $content->getContentId();
		$typeName = $content->getContentTypeName();
		$this->contentsTable[$typeName][$id] = &$content;
		/*
		if (!$this->contentExists($id, $typeName)) {
      //$this->contentsArray[$type][$id] = $content;
      $this->contentsTable[$typeName][$id] = &$content;
      $this->debug("ContentsManager.addContent, status : success.", 10);
		}
		*/
		$this->debug('ContentsManager::addContent, status : Content(id='.$id.' type_name="'.$typeName.'") added', 10);
		return true;
	}

	/**
	 * Gets New Content
	 *
	 * @param  string  $typeName
	 * @param  integer $aclId
	 * @return mixed   object or <0 if error
	 */
	function &getNewContent($typeName, $aclId=0){
		if(($type = &$this->typesManager->getType($typeName)) < 0){
			$this->debug("ContentsManager.getNewContent, error : type '".$this->getTypeName()."'unknown.", 1);
			return -1;
		}
		if (($typesTable = &$type->getFieldsTable()) < 0){
			$this->debug("ContentsManager.getNewContent, errror : unable to get fields for content '".$this->getId()."'.", 1);
			return -1;
		}

		$langsArray = $this->getLangsArray();

		foreach ($langsArray as $langId => $langName) {
			foreach ($typesTable as $key => $value) {
        $empty = '';
				$valuesTable[$langId][$key] = &$this->typesManager->createTypeObject($value, $empty);
			}
    }

		$id = 0	;
		$deleted = 0;
		$content = &new Content($id, $typeName, $valuesTable, $deleted, $aclId);
		return $content;
	}
	
	/**
	 * Gets Languages
	 *
	 * Returns associative array of available languages
	 *
	 * @return array
	 * @todo discussion about the right place for this function (managers interface ? / dbManipulator ?)
	 */
	function getLangsArray() {
		$dbManipulator = &$this->getDBManipulator();	
		$result        = $dbManipulator->querySelect(LANGUAGES_TABLE, -1, '', 'id', '`name`');
		if (!$result) {
			return null;
		}
		$langsArray = array();
		while ($row = $dbManipulator->fetchArray($result)) {
			$langId = (int )$row['id'];
			$langsArray[$langId] = $row['name'];
		}
		return $langsArray;
	}
	
	/**
	 * @param  integer $contentId
	 * @param  string  $typeName
	 * @return array
	 * @todo   discussion
	 */
	function getParentObjectValuesArray($contentId, $typeName) {
		$result = $this->dbManipulator->queryGetContainerOfContent($contentId, $typeName);
		
		if (!$result || !$this->dbManipulator->getNumRows()) {
			return null;
		}
		
		$row = $this->dbManipulator->fetchArray($result);
		
		return $row;
	}
	
	/**
	 * Updates Content `acl_id` field
	 *
	 * @param  integer $id Content ID
	 * @param  string $typeName Content Type
	 * @param  integer $aclId ACL ID
	 * @return boolean
	 */
	function updateContentACL($id, $typeName, $aclId) {
    $updated = false;
    $db = &$this->getDBManipulator();
    $fields = array('acl_id' => $aclId);
    $cond = '`id` in ('.implode(',', (array)$id).')';
    if($db->setRecord(TYPE_TABLES_PREFIX.$typeName, -1, $fields, $cond)){
      $updated = true;
    }
    return $updated;
	}
	
	/**
	 * @deprecated
	 * @todo remove
	 */
	function _storeContentIntoXML($contentId, $contentType) {
		$site = &Site::getInstance();
		$currUser = &$site->getCurrentUser();
		
		$content = &$this->getContent($contentId, $contentType);
		$xml = '';
		
		if (is_null($content)) {
			return false;
		}
		
		$versionId = 0;
		$versionDate = date('Y-m-d h:i:s');
		
		$fieldsArray = array(
			 'date'       => $versionDate
			,'content_id' => $contentId
			,'type_name'  => $contentType
			,'user_id'    => $currUser->getUserId()
		);
		
		$result = $this->dbManipulator->queryInsert(VERSIONS_TABLE, $fieldsArray);
		
		$versionId = $this->dbManipulator->getLastId();
		
		if ($versionId == 0 || $versionId === false) {
			return false;
		}
		
		$basicTypesArray = array();
		
		foreach ($content->getTypesTable() as $fieldName => $typeObj) {
			$typeObjName = get_class($typeObj);
			$basicTypesArray[$fieldName] = constant(strtoupper($typeObjName));
		}
		
		$result = $this->dbManipulator->querySelect(TYPE_TABLES_PREFIX.$contentType, $contentId, '', 'id', '`lang_id`');
		
		if (!$result || !$this->dbManipulator->getNumRows()) {
			return false;
		}
		
    /*
		$xml .= '<?xml version="1.0" encoding="utf-8" ?'.'>'."\n";
		$xml .= '<content-type id="'.$contentId.'" type="'.$contentType.'">'."\n";
		*/
		$xml  = '';
		$xml .= '<version id="'.$versionId.'">'."\n";
		
		while ($row = $this->dbManipulator->fetchArray($result)) {
			$xml .= '<lang id="'.$row['lang_id'].'">'."\n";
			
			foreach ($basicTypesArray as $fieldName => $typeName) {
				$typeObj = $this->typesManager->createTypeObject($typeName, $row[$fieldName]);
				$xml .= '<'.$fieldName.'>'."\n";
				$xml .= $typeObj->toXML();
				$xml .= '</'.$fieldName.'>'."\n";
			}
			
			$xml .= '</lang>'."\n";
		}
		
		$xml .= '</version>'."\n";
		
		//$fxml = fopen('', 'w');
		
		XMLContentParser::addXML();
		
		//echo '<pre>',htmlspecialchars($xml),'</pre>';

		return true;
	}
} 

?>