<?php
/*
 * This file is part of the easy-CMS project.
 * easy-CMS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * easy-CMS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with easy-CMS; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
/**
 * ContentEditionForm : edition form for Contents
 *
 * @package    Core
 * @subpackage Forms
 */

/**
 */
include_once('config.inc.php');
include_once('classes/core/Site.class.php');
include_once('classes/core/forms/EditionForm.class.php');
include_once('classes/core/forms/ContentForm.class.php');

include_once('classes/core/types/TypesManager.class.php');
include_once('classes/core/contents/Content.class.php');
include_once('classes/core/contents/ContentsManager.class.php');
include_once('classes/core/pages/Page.class.php');
include_once('classes/core/pages/PagesManager.class.php');
include_once('classes/core/containers/Container.class.php');
include_once('classes/core/containers/ContainersManager.class.php');

include_once('classes/core/versions/ContentVersionsManager.class.php');

include_once('classes/types/Date.class.php');

include_once('interface/egScript.class.php');
include_once('interface/egManager.class.php');
include_once('interface/egContainer.class.php');
include_once('interface/egMenuItem.class.php');
include_once('interface/egFrame.class.php');
include_once('interface/egToolTip.class.php');
include_once('interface/egRichText.class.php');
include_once('interface/egLink.class.php');
include_once('interface/egStatic.class.php');
include_once('interface/egEdit.class.php');
include_once('interface/egCheckBox.class.php');
include_once('interface/egRadioButton.class.php');
include_once('interface/egPressButton.class.php');
include_once('interface/egDropDownListBox.class.php');
include_once('interface/egDropDownPropertyList.class.php');
include_once('interface/egPropertyList.class.php');
include_once('interface/egPropertySheet.class.php');
include_once('interface/egPropertyPage.class.php');

/**
 * ContentEditionForm : edition form for Contents
 *
 * @access     public
 * @author	   Cedric Francoys <cedric.francoys@easy-cms.org>
 * @version	   ContentEditionForm.class, Tue Dec 14 22:12:56 CET 2004
 * @package	   Core
 * @subpackage Forms
 */
class ContentEditionForm extends EditionForm {

	/**
 	 * Constructor
	 * 
	 * @param  object $content
 	 * @param  string $mode The mode in which the form is to be displayed.	
 	 * @return void  
	 */
	function ContentEditionForm(&$content, &$contentsManager) {
		parent::EditionForm($content, $contentsManager);
	}

	function populateUIContainer(&$guiContainer, $currLangId, $action) {
		if($action == ASK_DELETE_CONTENT) {
			$summary = $this->object->toHTML($currLangId);
			$txtLang = &new egStatic("sta_1", LANG_CONTENT_DELETION_MESSAGE." :<br /><br />".$summary."<br /><br />".LANG_CONTENT_DELETION_CONFIRM, 20, 20, 300, 0);
			$guiContainer->addObject($txtLang);
		}
		else {
			$langList = &new egDropDownPropertyList("ddl_lang_1", "Language", 400, 10, 80);
			$txtLang = &new egStatic("sta_1", LANG_LANGUAGE_LISTBOX." :", 330, 10, 80, 0, true);

			$guiContainer->addObject($langList);
			$guiContainer->addObject($txtLang);

			$valuesTable = &$this->object->getContentValuesTable();
			$langsArray = $this->objectManager->getLangsArray();

	    // look for the first defined language
			foreach ($langsArray as $langId => $langName) {
	      if(isset($valuesTable[$langId])) {
	        $referenceLangId = $langId;
	        break;
	      }
	    }

			foreach ($langsArray as $langId => $langName) {
	      $editionContainer = &new egContainer('edt_ctn_'.$langId);
	      $guiContainer->addContainer($editionContainer);
				$langList->addListItem(new egPropertyPage('lti_'.$langId, ucfirst($langName), $editionContainer->getContainerName()));

	      if($langId == $currLangId) {
	        $langList->setSelectedItemByLabel(ucfirst($langName));
	      }

	      // create same fields for this lang than in the reference language
	      if(!isset($valuesTable[$langId])) {
	        if(!isset($referenceLangId)) {
	          continue;
	        }
	        foreach ($valuesTable[$referenceLangId] as $field => $value) {
            $empty = '';
	          $value->setValue($empty);
	          $valuesTable[$langId][$field] = $value;
	        }
	      }

	    	$i = 0;
	  		$previousTop = 45;
				foreach ($valuesTable[$langId] as $field => $value) {

					$txtValue = &new egStatic("st_value_".$langId."_".$i, ucfirst($field)." :", 5, $previousTop, 80, 0, true);
					$type = $value->getType();

					switch($type) {
						case INTEGER:
							$objItem = &new egEdit("obj_item_".$langId."_".$i, $value->getValue(), 90, $previousTop, 37, 18, $langId.'['.$field.']');
							$previousTop += 25;
						  break;
						case FLOAT:
							$objItem = &new egEdit("obj_item_".$langId."_".$i, $value->getValue(), 90, $previousTop, 37, 18, $langId.'['.$field.']');
							$previousTop += 25;
						  break;
						case BOOL:
							$previousTop += 25;
						  break;
						case STRING:
							$objItem = &new egEdit("obj_item_".$langId."_".$i, $value->getValue(), 90, $previousTop, 390, 18, $langId.'['.$field.']');
							$previousTop += 25;
						  break;
						case SHORTTEXT:
							$objItem = &new egEdit("obj_item_".$langId."_".$i, $value->getValue(), 90, $previousTop, 390, 100, $langId.'['.$field.']');
							$previousTop += 107;
						  break;
						case TEXT:
							$objItem = &new egRichText("obj_item_".$langId."_".$i, $value->getValue(), 90, $previousTop, 390, 250, $langId.'['.$field.']');
							$previousTop += 260;
						  break;
						case COLOR:
							$previousTop += 25;
						  break;
						case LINK:
							$objItem = &new egContainer("obj_item_".$langId."_".$i, 90, $previousTop, 0, 0, true);
							$objItemEdit = &new egEdit("obj_item_edit_".$langId."_".$i, $value->getValue(), 0, 2, 305, 18, $langId.'['.$field.']');
							$objItemButton = &new egPressbutton("obj_item_button_".$langId."_1", LANG_CHOOSE_BUTTON, 315, 0, 80, null, "openWindow(\'select_page.php?parent_control_name=obj_item_edit_".$langId."_".$i."_value\',425,450,0,0);");

							$objItem->addObject($objItemEdit);
							$objItem->addObject($objItemButton);
							$previousTop += 25;
						  break;
						case DATE:
							$objItem = &new egContainer("obj_item_".$langId."_".$i, 90, $previousTop, 0, 0, true);
							$objItemDaysList   = &new egDropDownListBox("obj_item_days_".$langId."_".$i, 0, 0, 40, null, $langId.'['.$field.'][day]');
							$objItemMonthsList = &new egDropDownListBox("obj_item_months_".$langId."_".$i, 60, 0, 80, null, $langId.'['.$field.'][month]');
							$objItemYearsList  = &new egDropDownListBox("obj_item_years_".$langId."_".$i, 160, 0, 50, null, $langId.'['.$field.'][year]');

							$currDay = $value->getDay();
              if($currDay == 0) {
                $currDay = Date::getCurrentDay();
              }
							for($day = 1; $day <= 31; ++$day) {
								$dayNum = (($day<10)?"0":"").$day;
								$objItemDaysList->addListItem(new egListItem("lti_days_".$langId."_".$i."_".$day, $dayNum, null, $day));
							}
							$objItemDaysList->setSelectedItemByValue($currDay);

							$currMonth = $value->getMonth();
              if($currMonth == 0) {
                $currMonth = Date::getCurrentMonth();
              }
							for($month = 1; $month <= 12; ++$month) {
								$monthName = ucfirst(Date::getMonthName($month));
								$objItemMonthsList->addListItem(new egListItem("lti_months_".$langId."_".$i."_".$month, $monthName, null, $month));
							}
							$objItemMonthsList->setSelectedItemByValue($currMonth);

							$currYear = $value->getYear();
              if($currYear == 0) {
                $currYear = Date::getCurrentYear();
              }
							$fromYear = $currYear - 2;
							$toYear   = $currYear + 10;
							for ($year = $fromYear; $year <= $toYear; $year++) {
								$objItemYearsList->addListItem(new egListItem("lti_years_".$langId."_".$i."_".$year, $year, null, $year));
							}
							$objItemYearsList->setSelectedItemByValue($currYear);

							$objItem->addObject($objItemDaysList);
							$objItem->addObject($objItemMonthsList);
							$objItem->addObject($objItemYearsList);
							$previousTop += 25;
						  break;
						case TIME:
							$previousTop += 25;
						  break;
						case DOCUMENT:
							$objItem = &new egContainer("obj_item_".$langId."_".$i, 90, $previousTop, 0, 0, true);
							$objItemEdit = &new egEdit("obj_item_edit_".$langId."_".$i, $value->getValue(), 0, 2, 305, 18, $langId.'['.$field.']');
							$objItemButton = &new egPressbutton("obj_item_button_".$langId."_1", LANG_BROWSE_BUTTON, 315, 0, 80, null, "openWindow(\'select_file.php?parent_control_name=obj_item_edit_".$langId."_".$i."_value&repository_type=".DOCUMENTS_FOLDER."\',680,420,0,0);");

							$objItem->addObject($objItemEdit);
							$objItem->addObject($objItemButton);
							$previousTop += 25;
						  break;
						case IMAGE:
							$objItem = &new egContainer("obj_item_".$langId."_".$i, 90, $previousTop, 0, 0, true);
							$objItemEdit = &new egEdit("obj_item_edit_".$langId."_".$i, $value->getValue(), 0, 2, 305, 18, $langId.'['.$field.']');
							$objItemButton = &new egPressbutton("obj_item_button_".$langId."_1", LANG_BROWSE_BUTTON, 315, 0, 80, null, "openWindow(\'select_file.php?parent_control_name=obj_item_edit_".$langId."_".$i."_value&repository_type=".IMAGES_FOLDER."\',680,420,0,0);");

							$objItem->addObject($objItemEdit);
							$objItem->addObject($objItemButton);
							$previousTop += 25;
						  break;
						case REFERENCE:
							$previousTop += 25;
						  break;
					}
					$editionContainer->addObject($txtValue);
					$editionContainer->addObject($objItem);
					++$i;
	      }
				$emptyValue = &new egStatic("st_value_".$langId."_".$i, " ", 5, $previousTop, 80, 0, true);
				$editionContainer->addObject($emptyValue);
			}
		}
	}
}
?>