<?php
/*
 * This file is part of the Easy-CMS project.
 * Easy-CMS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * Easy-CMS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Easy-CMS; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

/**
 * @package    Core
 * @subpackage Frames
 */

/**
 */
include_once('config.inc.php');
include_once('classes/system/File.class.php');
include_once('classes/core/DBAccessorObject.class.php');
include_once('classes/core/containers/ContainersManager.class.php');
include_once('classes/core/containers/Container.class.php');
include_once('classes/core/containersLists/ContainersListsManager.class.php');
include_once('classes/core/containersLists/ContainersList.class.php');
include_once('classes/core/menus/MenusManager.class.php');
include_once('classes/core/menus/Menu.class.php');
include_once('classes/core/Site.class.php');

include_once('classes/core/parser/HTMLParser.class.php');

/**
 * Interpreter for pages templates and returns webpages(complete HTML code).
 *
 * @access     public
 * @author	   Cedric Francoys <cedric.francoys@easy-cms.org>
 * @version	   Frame.class, Sun Nov 14 16:40:59 CET 2004
 * @package	   Core
 * @subpackage Frames
 */
class Frame {
	/**#@+
	 * @access private
	 */
	/**
	 * Frame Id
	 *
	 * @var integer
	 */
	var $id;
	
	/**
	 * Frame Name
	 *
	 * @var string
	 */
	var $name;
	
	/**
	 * Frame Associated File
	 *
	 * @var string
	 */
	var $fileName;
	
	/**
	 * Frame Associated Styles
	 *
	 * @var array
	 */
	var $styles;
	
	/**
	 * Frame Associated Scripts
	 *
	 * @var array
	 */
	var $scripts;
	
	/**
	 * Frame Associated File Content
	 *
	 * @var string
	 */
	var $xhtml;
	
	/**
	 * @deprecated
	 * @todo approve and clean
	 */
	//var $file;
	
	/**
	 * @deprecated
	 * @todo approve and clean
	 */
	//var $langId;
	
	/**
	 * @deprecated
	 * @todo approve and clean
	 */
	//var $pageId;
	/**#@-*/
	
	/**#@+
	 * @access public
	 */
	/**
	 * Constructor
	 *
	 * @param integer $id Frame Id
	 * @param string  $name Frame Name
	 * @param string  $fileName Frame File Name
	 */
	function Frame($id=0, $name='', $fileName='') {	
		$this->setFrameId($id);
		$this->setFrameName($name);
		$this->setFrameFileName($fileName);
		$this->setFrameXHTML('');
		$this->styles = array();
		$this->scripts = array();
		$this->loadFrameXHTML();
	}
	
	/**
	 * Gets Frame Id
	 *
	 * @return integer
	 */
	function getFrameId(){
		return $this->id;
	}
	
	/**
	 * Sets Frame Id
	 *
	 * @param integer $id Frame Id
	 */
	function setFrameId($id){
		$this->id = $id;
	}
	
	/**
	 * Gets Frame Name
	 *
	 * @return string
	 */
	function getFrameName(){
		return $this->name;
	}
	
	/**
	 * Sets Frame Name
	 *
	 * @param string $name Frame Name
	 */
	function setFrameName($name){
		$this->name = $name;
	}
	
	/**
	 * Gets Frame File Name
	 *
	 * @return string
	 */
	function getFrameFileName(){
		return $this->fileName;
	}
	
	/**
	 * Sets Frame File Name
	 *
	 * @param string $fileName
	 */
	function setFrameFileName($fileName) {
		$this->fileName = $fileName;
	}
	
	/**
	 * Gets Frame Associated Styles
	 *
	 * @return array
	 */
	function getFrameStyles() {
		return $this->styles;
	}
	
	/**
	 * Adds Frame Style
	 *
	 * @param integer $styleId
	 * @param string $styleFile
	 */
	function addFrameStyle($styleId, $styleFile) {
		$this->styles[$styleId] = $styleFile;
	}
	
	/**
	 * Gets Frame Associated Scripts
	 *
	 * @return array
	 */
	function getFrameScripts() {
		return $this->scripts;
	}
	
	/**
	 * Adds Frame Script
	 *
	 * @param integer $scriptId
	 * @param string $scriptFile
	 */
	function addFrameScript($scriptId, $scriptFile){
		$this->scripts[$scriptId] = $scriptFile;
	}
	
	/**
	 * Gets Frame Associated File Content
	 *
	 * @return string
	 */
	function getFrameXHTML() {
		return $this->xhtml;
	}
	
	/**
	 * Sets Frame Associated File Content
	 *
	 * @param string $xhtml Frame XHTML
	 */
	function setFrameXHTML($xhtml){
		$this->xhtml = $xhtml;
	}

	/**
	 * Loads XHTML
	 *
	 * @return boolean
	 */
	function loadFrameXHTML() {
		$path  = REPOSITORY_FOLDER;
		$path .= '/'.TEMPLATES_FOLDER;
		$path .= '/'.$this->getFrameFileName();
		$cwd   = (strpos(getcwd(), '\\')) ? getcwd() : '/'.getcwd();
		$file  = &new File('', $cwd.'/'.$path);
		if (!($xhtml = $file->read()))
			return false;
		$this->setFrameXHTML($xhtml);
		return true;
	}
	
	/**
	 * Gets HTML
	 *
	 * Computes Frame and returns corresponding HTML
	 *
	 * @return string HTML
	 */
	//function &getHTML($user=null, $mode=VIEW_MODE) {
	function &getHTML($langId){
		$xhtml = &$this->getFrameXHTML();
		$htmlParser = &new HTMLParser($xhtml);
		$html = &$htmlParser->getResult($langId);
		return $html;
	}
	/**#@-*/
	
	/**
	 * @todo check deprecation
	 */
	/*
	function getERegValue() {
		$ereg = "(\\\"[^\\\"]+\\\")";
		return $ereg;	
	}
	*/
	
	/**
	 * @todo check deprecation
	 */
	/*
	function getERegAttr($attrName) {
		$ereg = "(";
		for($i = 0; $i < strlen($attrName);++$i){
			$ereg .= "[".strtoupper($attrName[$i]).strtolower($attrName[$i])."]";
		}
		$ereg .= "\s*=\s*\\\".*\\\")";
		return $ereg;	
	}
	*/
	
	/**
	 * @todo check deprecation
	 */
	//function getERegTag($tagName)
	//{
		//$ereg = "(<\s*easy-cms:";
		//$ereg = "(<\s*/?\s*easy-cms:";
		//for($i = 0; $i < strlen($tagName);++$i){
			//$ereg .= "[".strtoupper($tagName[$i]).strtolower($tagName[$i])."]";
		//}
		//$ereg .= "[^<>]+/\s*>)";
		//$ereg .= "[^<>]+\s*>)";		
		//return $ereg;	
	//}
	
	/**
	 * @todo check deprecation
	 */
	/*
	function getTags($xml, $tag = "") {
		if ( ($res = preg_match_all($this->getERegTag($tag), $xml, $matches, PREG_OFFSET_CAPTURE)) ){
			return $matches[0];
		}
		return null;	
	}
	*/
	
	/**
	 * @todo check deprecation
	 */
	/*
	function getAttribute($tag, $attribute) {
		if ( ($res = preg_match($this->getERegAttr($attribute), $tag, $matches)) ){
			return $matches[0];
		}
		return null;	
	}
	*/
	
	/**
	 * @todo check deprecation
	 */
	/*
	function getValue($attribute) {
		if ( ($res = preg_match($this->getERegValue(), $attribute, $matches)) ){
			return substr($matches[0], 1, strlen($matches[0])-2);
		}
		return null;	
	}
	*/

	/**
	 * @todo check deprecation
	 */
	/*
	function getTagInfos($tag, &$name, &$type) {
		$type = "openTag";
		for($begin = 1; $begin < strlen($tag) && $tag[$begin] == " "; ++$begin){}
		if($tag[$begin] == "/"){
			$type = "closeTag";
			++$begin;
		}
		for($end = $begin; $end < strlen($tag) && $tag[$end] != " " && $tag[$end] != ">"; ++$end){}
		if($tag[strlen($tag)-2] == "/")
			$type = "singleTag";		
		$name = substr($tag, $begin, $end-$begin);
	}
	*/

	/**
	 * @todo check deprecation
	 */
	/*
	function getTagType($tag) {
		return '';
	}
	*/
	
	/*
	 *
	 * DEPRECATED CODE BELOW
	 *
	 */
	 
	/**
	 * @deprecated use {@link getFrameId}
	 * @todo approve and clean
	 */
	/*
	function getId() {
		return $this->getFrameId();
	}
	*/
	
	/**
	 * @deprecated use {@link getFrameName}
	 * @todo approve and clean
	 */
	/*
	function getName() {
		return $this->getFrameName();
	}
	*/
	
	/**
	 * @deprecated
	 * @todo approve and clean
	 */
	/*
	function getPageId() {
		return $this->pageId;
	}
	*/
	
	/**
	 * @deprecated
	 * @todo approve and clean
	 */
	/*
	function &getMode() {
		return $this->mode;
	}
	*/
	
	/**
	 * @deprecated
	 * @todo approve and clean
	 */
	/*
	function getXHTML()
	{
		return $this->getFrameXHTML();
	}
	*/
	
	/**
	 * @deprecated
	 * @todo approve and clean
	 */
	/*
    function load() 
    {
		if (($result = &$this->dbManipulator->getRecord(FRAMES_TABLE, $this->getId())) < 0 ) {
			$this->debug("Frame.load, warning : frame '".$this->getId()."' unknown (load skipped).");
			return -1;				
		}
		$row = &$this->dbManipulator->fetchArray($result);
		$this->name = &$row["name"];
		$path = REPOSITORY_FOLDER."/".TEMPLATES_FOLDER."/".$row["file"];
		$cwd = (strpos(getcwd(), "\\"))?getcwd():"/".getcwd();
		$this->file = &new File("", $cwd."/".$path);
		$this->xhtml = &$this->file->read();
		$this->debug("Frame.load, frame '".$this->getId()."' : success.", 10);
		return 1;
	}
	*/
	
	/**
	 * @deprecated
	 * @todo approve and clean
	 */
	/*
	function getScripts() 
	{
		return $this->getFrameScripts();
	}
	*/

	/**
	 * @deprecated
	 * @todo approve and clean
	 */
	/*
	function getStyles() 
	{
		return $this->getFrameStyles();
	}
	*/
} 

?>
