<?php
/*
 * This file is part of the easy-CMS project.
 * easy-CMS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * easy-CMS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with easy-CMS; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

/**
 * @package    Core
 * @subpackage MenuNodes
 */

/**
 */
include_once('classes/core/DBAccessorObject.class.php');
include_once('classes/core/DBManipulator.class.php');
include_once('classes/core/menuNodes/MenuNode.class.php');
include_once('classes/core/pages/Page.class.php');
include_once('classes/core/pages/PagesManager.class.php');

/**
 * Manage the instances of Container objects.
 *
 * @access     public
 * @author	   Cedric Francoys <cedric.francoys@easy-cms.org>
 * @version	   MenuNodesManager.class, Sat Nov 13 11:39:53 CET 2004
 * @package	   Core
 * @subpackage MenuNodes
 */
class MenuNodesManager extends DBAccessorObject {
	/**#@+
	 * @access private
	 */
	/**
	 * @var object
	 */
	var $pagesManager;

	var $menusManager;
	/**
	 * Array of Container objects
	 *
	 * @var array
	 */
	var $menuNodesTable;
	/**#@-*/

	/**
	 * Class constructor
	 *
	 * @param object  $dbManipulator
	 * @param object  $pagesManager
	 */
	function MenuNodesManager(&$dbManipulator, &$pagesManager, &$menusManager){
		parent::DBAccessorObject($dbManipulator);
		$this->pagesManager = &$pagesManager;
		$this->menusManager = &$menusManager;
		$this->menuNodesTable = array();
	}

	/**
	 * Loads MenuNode
	 *
	 * @param  mixed   $menuNodeId
	 * @param  integer $langId
	 * @return boolean
	 */
	function loadMenuNode($menuNodeId, $menuId, $langId=LOAD_ALL_LANGUAGES){
    //echo "loading menuNode # $menuNodeId\n";
		$db = &$this->getDBManipulator();
		$cond = '`id` in ('.implode(',', (array)$menuNodeId).')';
		if($res = $db->getRecord(MENU_NODES_TABLE, -1, $cond)){
			while($fields = $db->fetchArray($res)){
				$id          = $fields['id'];
				$pageId      = $fields['page_id'];

				if(!is_object($page = &$this->pagesManager->getPage($pageId, false, false, true, $langId))) {
					// page does not exist or has been deleted : remove the associated MenuNode
					$this->removeMenuNode($menuNodeId);
					return false;
				}

				if(!is_object($menu = &$this->menusManager->getMenu($menuId))) {
					// no associated menu : error
					$this->debug('MenuNodesManager::loadMenuNode, error : unable to load associated menu # '.$menuId, 2);
					return false;
				}

				$acl = &$page->getPageAcl();

				$sortingType = $menu->getMenuSortingType();
				$sortField = $menu->getMenuSortField();
				$sortOrder = $menu->getMenuSortOrder();

				$this->menuNodesTable[$id] = &new MenuNode($id, $page->getPageId(), $sortingType, $sortField, $sortOrder, $acl->getAclId());
				$this->menuNodesTable[$id]->setMenuNodeMenuId($menuId);
				$this->menuNodesTable[$id]->setMenuNodePage($page);
				$this->menuNodesTable[$id]->setMenuNodeAcl($acl);
				$this->loadMenuNodeNodes($id, $menuId);
				$needUpdate = false;

				if($this->menuNodesTable[$id]->getNodesCount() < $this->pagesManager->countSubPages($page->getPageId())) {
					$pagesList = &$this->pagesManager->getSubPagesList($page->getPageId());
					foreach($pagesList as $subPageId) {
						if(!$this->pageIdInSubNodes($id, $subPageId)) {
							if(is_object($subPage = &$this->pagesManager->getPage($subPageId, false, false, true, $langId))) {
								$needUpdate = true;
								$acl = &$subPage->getPageAcl();

								$newMenuNode = &new MenuNode(0, $subPageId, $sortingType, $sortField, $sortOrder, $acl->getAclId());
								$newMenuNode->setMenuNodePage($subPage);
								$newMenuNode->setMenuNodeAcl($acl);
								$newMenuNode->setMenuNodeMenuId($menuId);
								$this->setMenuNode($newMenuNode);
								$newId = $this->storeMenuNode(0);
								$newMenuNode->setMenuNodeId($newId);
								$this->setMenuNode($newMenuNode);
								$this->menuNodesTable[$id]->addNode($newMenuNode);
								unset($newMenuNode);
								unset($subPage);
							}
						}
					}
				}
				if($needUpdate) {
					$this->storeMenuNode($id);
				}
				return true;
			}
		}
		return false;
 	}

	/**
	 * Loads MenuNode's Nodes
	 *
	 * @param  integer $menuNodeId MenuNode Id
	 * @return boolean
	 */
	function pageIdInSubNodes($nodeId, $pageId) {
		$node = &$this->menuNodesTable[$nodeId];
		foreach($node->nodesTable as $subNode) {
			if($subNode->getMenuNodePageId() == $pageId) {
				return true;
			}
		}
		return false;
	}

	/**
	 * Loads MenuNode's Nodes
	 *
	 * @param  integer $menuNodeId MenuNode Id
	 * @return boolean
	 */
	function loadMenuNodeNodes($menuNodeId, $menuId) {
		$db = &$this->getDBManipulator();
		$loaded = false;
		if($menuNode = &$this->getMenuNode($menuNodeId, $menuId)){
			$pageId = $menuNode->getMenuNodePageId();
			$pagesList = &$this->pagesManager->getSubPagesList($pageId);

			if($res = $db->getRecord(MENU_NODES_NODES_TABLE, $menuNodeId, '', 'parent_node_id')) {
				$nodesIdList = array();
				while($fields = $db->fetchArray($res)){
          $index = $fields['index'];
					$nodesIdList[$index] = $fields['child_node_id'];
				}
				if(count($nodesIdList) > 0){
          ksort($nodesIdList);
					foreach($nodesIdList as $nodeId){
						if($node = &$this->getMenuNode($nodeId, $menuId)) {
							// compare hierarchy in case of page move
							if(in_array($node->getMenuNodePageId(), $pagesList)) {
								$loaded = true;
								$node->setParentNodeId($menuNodeId);
								$menuNode->addNode($node);
							}
							else {
								// remove the node from the sub nodes list
								$this->removeNode($menuNodeId, $nodeId);
							}
							unset($node);
						}
					}
				}
			}
		}
		return $loaded;
	}


	/**
	 * Stores MenuNode
	 *
	 * @param  integer $menuNodeId
	 * @return integer menuNode ID or <0 if error
	 */
  function storeMenuNode($menuNodeId) {
		$menuNode = &$this->getMenuNode($menuNodeId);

		if (is_null($menuNode)) {
			return -1;
		}

		$fieldsArray = array(
			'page_id'      => $menuNode->getMenuNodePageId()
		);

		// new menuNode : id 0 is not allowed in the DB
		if ($menuNodeId == 0) {
			if (!$this->dbManipulator->queryInsert(MENU_NODES_TABLE, $fieldsArray)) {
				$this->debug('MenuNodesManager::storeMenuNode, error : unable to create new menuNode', 1);
				return -1;
			}
			$newId = $this->dbManipulator->getLastId();
			$menuNode->setMenuNodeId($newId);
			$this->setMenuNode($menuNode);
			// free the temporary menuNode entry (0)
			unset($this->menuNodesTable[0]);
			$this->menuNodesTable[0] = null;
			// return a value > 0, the id of the new menuNode
			$this->debug('MenuNodesManager::storeMenuNode, success : new menuNode created successfully', 9);
 			if($menuNode->getNodesCount() < 1){
				return $newId;
			}
			else {
				$menuNodeId = $newId;
			}
		}
		else {
			if (!$this->dbManipulator->queryUpdate(MENU_NODES_TABLE, $fieldsArray, $menuNodeId)) {
				$this->debug('MenuNodesManager::storeMenuNode, error : unable to update menuNode #'.$menuNodeId, 1);
				return -1;
			}
		}

		// make nodes list
		$result = $this->dbManipulator->querySelect(MENU_NODES_NODES_TABLE, $menuNodeId, '', 'parent_node_id', '`index`');

		if (!$result) {
			$this->debug('MenuNodesManager::storeMenuNode, error : unable to get nodes list for menuNode #'.$loadId, 2);
			return -1;
		}
		else {
			$nodesTableBool = array();
			while($row = $this->dbManipulator->fetchArray($result)){
				$nodeId = $row['child_node_id'];
				$nodesTableBool[$nodeId] = true;
			}
		}

		$nodesTable = &$menuNode->getNodesTable();
		$count = count($nodesTable);

		for ($i = 0; $i < $count; ++$i) {
			$nodeId = $nodesTable[$i]->getMenuNodeId();

			$fieldsArray = array();
			$fieldsArray['index'] = $i+1;

			if(isset($nodesTableBool[$nodeId])) {
				if (!$this->dbManipulator->queryUpdate(MENU_NODES_NODES_TABLE, $fieldsArray, $menuNodeId, 'parent_node_id', '`child_node_id`='.$nodeId)) {
					$this->debug("MenuNodesManager::storeMenuNode, error : unable to set record for list of menuNode '$menuNodeId'.", 2);
					return -1;
				}
			}
			else {
				$fieldsArray['menu_id']  = $menuNode->getMenuNodeMenuId();
				$fieldsArray['child_node_id']  = $nodeId;
				$fieldsArray['parent_node_id'] = $menuNodeId;

				$result = $this->dbManipulator->sendQuery("SELECT max(`index`) as `index` FROM `".MENU_NODES_NODES_TABLE."` WHERE `parent_node_id` = $menuNodeId;");
				if(!($row = $this->dbManipulator->fetchArray($result))){
					return -1;
				}

				$fieldsArray['index'] = $row['index']+1;

				if (!($result = $this->dbManipulator->queryInsert(MENU_NODES_NODES_TABLE, $fieldsArray))) {
					$this->debug('MenuNodesManager::storeMenuNode, error : unable to new entry in nodes list of menuNode #'.$menuNodeId, 2);
					return -1;
			 	}
			}
		}

		$this->debug('MenuNodesManager::storeMenuNode, success : menuNode #'.$menuNodeId.' stored successfully', 9);
		return $menuNodeId;
	}

	/**
	 * Removes MenuNode
	 *
	 * @param  integer $menuNodeId
	 * @return boolean
	 */
  function removeMenuNode($menuNodeId) {
		$db = &$this->getDBManipulator();
		if($db->delRecord(MENU_NODES_TABLE, $menuNodeId) && $db->delRecord(MENU_NODES_NODES_TABLE, $menuNodeId, '', 'parent_node_id')){
			if($this->checkMenuNode($menuNodeId)) {
				unset($this->menuNodesTable[$menuNodeId]);
			}
			return true;
		}
		return false;
  }

	/**
	 * Adds Node Into MenuNode
	 *
	 * @param  integer $menuNodeId
	 * @param  integer $nodeId
	 * @return boolean
	 */
	function addNode($menuNodeId, $nodeId){
		$dbManipulator = &$this->getDBManipulator();
		if($menuNode = &$this->getMenuNode($menuNodeId)){
			$fields = array();
			$fields['parent_node_id'] = $menuNodeId;
			$fields['child_node_id']  = $nodeId;

			$result = $dbManipulator->sendQuery("SELECT max(`index`) as `index` FROM `".MENU_NODES_NODES_TABLE."` WHERE `parent_node_id` = $menuNodeId;");
			if(!($row = $dbManipulator->fetchArray($result))){
				return false;
			}

			$fields['index'] = $row['index']+1;

			if(!$dbManipulator->addRecord(MENU_NODES_NODES_TABLE, $fields)){
				return false;
			}
		}
		return true;
	}

	/**
	 * Removes Content From Container
	 *
	 * @param  integer $containerId
	 * @param  integer $contentId
	 * @return boolean
	 */
	function removeNode($menuNodeId, $nodeId){
		$db = &$this->getDBManipulator();
		if($db->delRecord(MENU_NODES_NODES_TABLE, $menuNodeId, "`child_node_id`=$nodeId", 'parent_node_id')){
			return true;
		}
		return false;
  }

  function checkMenuNode($menuNodeId) {
  	return isset($this->menuNodesTable[$menuNodeId]);
  }

	/**
	 * Tells if a menuNode is present in the database
	 *
	 * @param  integer $menuNodeId
	 * @return boolean
	 */
	function menuNodeExists($menuNodeId) {
		// try to load the menuNode
		$this->getMenuNode($menuNodeId);
		// returns true if the menuNode exists
		return $this->checkMenuNode($menuNodeId);
	}

 	/**
	 * Gets MenuNode From a Menu
	 *
 	 * @param  integer $menuNodeId
 	 * @return mixed object or null
	 */
	function &getMenuNodeFromMenu(&$menu){
		$menuId = $menu->getMenuId();
		$pageId = $menu->getMenuRootPageId();
		$dbManipulator = &$this->getDBManipulator();

		$result = $dbManipulator->sendQuery("SELECT `parent_node_id` from (`".MENU_NODES_TABLE."` inner join `".MENU_NODES_NODES_TABLE."` on `id` = `parent_node_id`) where `".MENU_NODES_NODES_TABLE."`.`menu_id` = '$menuId' and `".MENU_NODES_TABLE."`.`page_id` = '$pageId';");

		if(!($row = $dbManipulator->fetchArray($result)) || !isset($row['parent_node_id'])){
			$this->debug('MenuNodesManager::getMenuNodeFromMenu, warning : unable to get menuNode for menu #'.$menuId."' with root page # '".$pageId."'", 3);
			$fieldsArray['page_id'] = $pageId;
			if (!($result = $this->dbManipulator->queryInsert(MENU_NODES_TABLE, $fieldsArray))) {
				return null;
			}
			$nodeId = $this->dbManipulator->getLastId();
		}
		else {
			$nodeId = $row['parent_node_id'];
		}
  	return $this->getMenuNode($nodeId, $menuId);
	}

 	/**
	 * Gets MenuNode
	 *
 	 * @param  integer $menuNodeId
 	 * @return mixed object or null
	 */
	function &getMenuNode($menuNodeId, $menuId=0){
		$this->debug('MenuNodesManager::getMenuNode, notice : getting menuNode #'.$menuNodeId, 10);
  	if (!$this->checkMenuNode($menuNodeId)){
			if (!$this->loadMenuNode($menuNodeId, $menuId)){
				$this->debug('MenuNodesManager::getMenuNode, error : unable to get menuNode #'.$menuNodeId, 3);
				return null;
			}
		}
		$this->debug('MenuNodesManager::getMenuNode, success : got menuNode #'.$menuNodeId, 9);
  	return $this->menuNodesTable[$menuNodeId];
	}

	/**
	 * Sets MenuNode into manager
	 *
	 * @param  object $menuNode
	 * @return boolean
	 */
	function setMenuNode(&$menuNode) {
		$menuNodeId = $menuNode->getMenuNodeId();
		$this->menuNodesTable[$menuNodeId] = &$menuNode;
		$this->debug('MenuNodesManager::setMenuNode, succes : menuNode #'.$menuNodeId.' set', 9);
		return true;
	}

	/**
	 * Gets New MenuNode
	 *
	 * Returns a new Container object
	 *
	 * @return object
	 */
	function &getNewMenuNode($aclId=1) {
		$id          = 0;
		$pageId      = 0;
		$sortingType = SORTING_BY_LIST;
		$sortField 	 = '';
		$sortOrder 	 = SORT_ASCENDING;

		$this->menuNodesTable[0] = &new MenuNode($id, $pageId, $sortingType, $sortField, $sortOrder, $aclId);
		return $this->menuNodesTable[0];
	}
}
?>