<?php
/*
 * This file is part of the easy-CMS project.
 * easy-CMS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * easy-CMS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with easy-CMS; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/**
 */
include_once('classes/core/CoreObject.class.php');
include_once('classes/core/menus/Menu.class.php');
include_once('classes/core/pages/PagesManager.class.php');
include_once('classes/core/menuNodes/MenuNodesManager.class.php');
include_once('classes/core/DBManipulator.class.php');
include_once('classes/core/ACL/ACL.class.php');
include_once('classes/core/ACL/ACLEntry.class.php');
include_once('classes/core/ACL/ACLManager.class.php');

/**
* Manage the instances of Menu objects.
*
* @access   public
* @author	Cedric Francoys <cedric.francoys@easy-cms.org>
* @version 	MenusManager.class,v 0.1 
* @package	Menus
*/
class MenusManager extends CoreObject {
	/**#@+
	 * @access private
	 */
  var $dbManipulator;
	var $pagesManager;
	var $menuNodesManager;
	var $templatesManager;
	var $aclManager;	
	var $langId;
	
	/**
	 * @var array
	 */
  var $menusTable;
	/**#@-*/
	

  function MenusManager(&$dbManipulator, &$aclManager, &$pagesManager, &$menuNodesManager, &$templatesManager, &$langId) {
    $this->dbManipulator = &$dbManipulator;
		$this->langId = &$langId;
		$this->menusTable = array();
		$this->pagesManager = &$pagesManager;
		$this->menuNodesManager = &$menuNodesManager;
		$this->templatesManager = &$templatesManager;
		$this->aclManager = &$aclManager;
  }
	
	function &getDBManipulator(){
		return $this->dbManipulator;
	}

	function &getMenuNodesManager(){
		return $this->menuNodesManager;
	}

	function &getTemplatesManager(){
		return $this->templatesManager;
	}

	function &getAclManager(){
		return $this->aclManager;
	}
	
	function &getPagesManager(){
		return $this->pagesManager;
	}
	
	function &getLangId(){
		return $this->langId;
	}

	function setMenuNodesManager(&$menuNodesManager){
		$this->menuNodesManager = &$menuNodesManager;
	}

  function loadMenu($id) {
		if (!$this->menuExists($id)){
			$this->debug("MenusManager.loadMenu, warning : menu '$id' unknown (load skipped).");
			return -1;
		}
		if(!$this->checkMenu($id)) {
			if (($result = &$this->dbManipulator->getRecord(MENUS_TABLE, $id)) < 0 ){
				$this->debug("MenusManager.loadMenu, error : unable to get menu '$id' from DB.", 2);
				return -1;
			}
			if(!($row = &$this->dbManipulator->fetchArray($result))){
				$this->debug("MenusManager.loadMenu, error : menu '$id' unknonwn.", 2);
				return -1;
			}
			$rootPageId = $row['root_page_id'];
			$nameId     = $row['name_id'];
			$templateId = $row['template_id'];
			$sortField  = $row['sort_field'];
			$sortOrder  = $row['sort_order'];
			$sortingType= $row['sorting_type'];
			$aclId      = $row['acl_id'];
			$maxLevel   = $row['max_level'];
			$deleted    = $row['deleted'];
			$published  = $row['published'];

			$this->debug("MenusManager.load, menu '$id' : success.", 10);
			$this->menusTable[$id] = &new Menu($id, $nameId, $templateId, $rootPageId, $sortField, $sortOrder);
			$this->menusTable[$id]->setMenuSortingType($sortingType);
			$this->menusTable[$id]->setMenuMaxLevel($maxLevel);
			$this->menusTable[$id]->setMenuDeleted($deleted);
			$this->menusTable[$id]->setMenuPublished($published);
			$this->menusTable[$id]->setMenuAclId($aclId);
			$this->menusTable[$id]->setMenuAcl($this->aclManager->getACL($aclId));
			$this->menusTable[$id]->setMenuMenuNodesManager($this->menuNodesManager);
			$this->menusTable[$id]->setMenuTemplatesManager($this->templatesManager);
			//$this->loadLanguageDependencies($id);
      $this->loadMenuTranslation($id);
		}
		return 1;	
  }

	/**
	 * Gets Languages
	 *
	 * Returns associative array of available languages
	 *
	 * @return array
	 * @todo discussion about the right place for this function (managers interface ? / dbManipulator ?)
	 */
	function getLangsArray() {
		$dbManipulator = &$this->getDBManipulator();
		$result        = $dbManipulator->getRecord(LANGUAGES_TABLE, -1, '', 'id', 'name');
		if (!$result) {
			return null;
		}
		$langsArray = array();
		while ($row = $dbManipulator->fetchArray($result)) {
			$langId = $row['id'];
			$langsArray[$langId] = $row['name'];
		}
		return $langsArray;
	}

	/**
	 * Stores Menu
	 *
	 * @param  integer $menuId
	 * @return integer Menu ID or <0 if error
	 */
  function storeMenu($menuId)	{
		$this->storeLanguageDependencies($menuId);
		
		$menu = &$this->getMenu($menuId);
		
		if (is_null($menu)) {
			$this->debug('MenusManager::storeMenu, error : menu #'.$menuId.' not defined', 3);
			return -1;
		}
		
		$fieldsArray = array(
			 'template_id'  => $menu->getMenuTemplateId(),
			 'root_page_id' => $menu->getMenuRootPageId(),
			 'sorting_type' => $menu->getMenuSortingType(),
			 'sort_field'   => $menu->getMenuSortField(),
			 'sort_order'   => $menu->getMenuSortOrder(),
			 'max_level'    => $menu->getMenuMaxLevel(),
			 'name_id'      => $menu->getMenuNameId(),
			 'published'    => $menu->getMenuPublished(),
			 'deleted'      => $menu->getMenuDeleted()
		);
		
		// new menu : id 0 is not allowed in the DB
		if($menuId == 0){
			if (!$this->dbManipulator->queryInsert(MENUS_TABLE, $fieldsArray)) {
				$this->debug('MenusManager::storeMenu, error : unable to create new menu', 1);
				return -1;			
			}
			$newId = $this->dbManipulator->getLastId();
			$menu->setMenuId($newId);
			// register the menu with its new id
			$this->setMenu($menu);
			// free the temporary menu entry (0)
			unset($this->menusTable[0]);	
			// return a value > 0, the id of the new menu
			$this->debug('MenusManager::storeMenu, success : new menu created successfully', 9);
			return $newId;			
		}
		else{		
			if (!$this->dbManipulator->queryUpdate(MENUS_TABLE, $fieldsArray, $menuId)) {
				$this->debug('MenusManager::storeMenu, error : unable to update menu #'.$menuId, 3);
				return -1;
			}
		}
		
		$this->debug('MenusManager::storeMenu, success : menu #'.$menuId.' stored successfully', 9);
		return $menuId;	
  }
	
  function removeMenu($id) {
  }


  /**
   * deprecated
   */
	function loadLanguageDependencies($menuId){
		$varsTable["name"] = &$this->menusTable[$menuId]->getNameId();

		foreach($varsTable as $key => $value){
			if (($result = &$this->dbManipulator->getRecord(NAMES_TABLE, $value, "lang_id=".$this->getLangId())) < 0 ){
				$this->debug("MenusManager.loadLanguageDependencies, error : menu '$menuId' unknown name for language '".$this->getLangId()."'.", 2);
				$fieldsArray[$key] = "";
			}
			else{
				if (!($row = &$this->dbManipulator->fetchArray($result))){
					$fieldsArray[$key] = "";
					$this->debug("MenusManager.loadLanguageDependencies, warning : menu '$menuId' unknown $key for language '".$this->getLangId()."' (".$key."_id is $value).", 3);
				}
				else
					$fieldsArray[$key] = $row["value"];
			}
		}

		$this->menusTable[$menuId]->setValues($fieldsArray);
		$this->debug("MenusManager.loadLanguageDependencies, status: success.", 10);
	}

	/**
	 * Loads Menu Translation
	 *
	 * @param  integer $menuId
	 * @return boolean
	 */
	function loadMenuTranslation($menuId){
		$db = &$this->getDBManipulator();
		$loaded = false;
		if($menu = &$this->getMenu($menuId)){
			if($res = $db->getRecord(NAMES_TABLE, $menu->getMenuNameId())){
				while($fields = $db->fetchArray($res)){
					$langId = (int)$fields['lang_id'];
					$label = $fields['value'];
					$menu->setMenuName($label, $langId);
					$loaded = true;
				}
			}
      else {
				$this->debug("MenusManager.loadMenuTranslation, error : menu '$menuId' unknown.", 2);
      }
		}
		return $loaded;
	}


 function storeMenuTranslation($menuId, $langId) {
		$db = $this->getDBManipulator();
		$menu = &$this->getMenu($menuId, false);

		if (!$menu) {
			return false;
		}
		if ($menuId == 0) {
		// create new label id's for the menu fields
			$labels = array(
				'name'        => ''
			);
			$menuValues = array();
			foreach ($labels as $key => $value) {
				$record = array();
				$record['lang_id'] = '1';
				$record['value'] = '';
				$res = $db->addRecord(NAMES_TABLE, $record);
				if ($res && $db->getLastId()) {
					$menuValues[$key.'_id'] = $db->getLastId();
				}
			}
			$menu->setMenuValues($menuValues);
		}
		$labels = array(
			 'name'        => $menu->getMenuNameId()
		);
		$menuValues = array();
		$valuesTableLang = &$menu->getMenuValuesTable();
  	foreach($valuesTableLang as $langId => $valuesTable) {
			if(!is_int($langId)) {
				continue;
			}
			foreach ($labels as $key => $labelId) {
				$record = array();
				$record['value'] = $this->html_encode($valuesTable[$key]);
				if ($labelId == 0) {
					// create new record
					$record['lang_id'] = $langId;
					$res = $db->addRecord(NAMES_TABLE, $record);
					if ($res && $db->getLastId()) {
						$menuValues[$key.'_id'] = $db->getLastId();
					}
				}
				else {
					// update record or create new record
					$res = $db->getRecord(NAMES_TABLE, $labelId, '`lang_id`='.$langId);
					if ($res && $db->getNumRows()) {
						$res = $db->setRecord(NAMES_TABLE, $labelId, $record, '`lang_id`='.$langId);
					}
					elseif ($res && !$db->getNumRows()) {
						$record['id'] = $labelId;
						$record['lang_id'] = $langId;
						$res = $db->addRecord(NAMES_TABLE, $record);
					}
				}
			}
		}
		$menu->setMenuValues($menuValues);
		return true;
  }

	function storeLanguageDependencies($menuId, $langId=LOAD_ALL_LANGUAGES) {
    $this->storeMenuTranslation($menuId, $langId);
  }

	/**
	 * Stores Language Dependencies
	 *
	 * @param  integer $menuId
	 * @return boolean
	 */
	function _storeLanguageDependencies($menuId) {
		$langId = $this->getLangId();

		$menu = $this->getMenu($menuId);

		if (is_null($menu)) {
			return false;
		}

		if ($menuId == 0) {
			$varsTable = array(
				'name' => $menu->getMenuName($langId)
			);

			$menuFieldsArray = array();

			foreach ($varsTable as $key => $value) {
				$labelFieldsArray = array(
					 'value'   => $value
					,'lang_id' => $langId
				);

	        	if (!$this->dbManipulator->queryInsert(NAMES_TABLE, $labelFieldsArray)) {
					$this->debug('MenusManager::storeLanguageDependencies, error : unable to create new label', 3);
					return false;
				}

				$menuFieldsArray[$key.'_id'] = $this->dbManipulator->getLastId();
			}

			$menu->setValues($menuFieldsArray);

			$this->debug('MenusManager::storeLanguageDependencies, success : new labels created successfully', 9);
			return true;
		}
		else {
			$varsTable = array();
			$varsTable[$menu->getMenuNameId()] = $menu->getMenuName();

			foreach ($varsTable as $key => $value) {
				$labelFieldsArray = array(
					'value' => $value
				);

				if ($this->dbManipulator->recordExists(NAMES_TABLE, $key, '`lang_id`='.$langId)) {
    	    		if (!$this->dbManipulator->queryUpdate(NAMES_TABLE, $labelFieldsArray, $key, 'id', '`lang_id`='.$langId)) {
						$this->debug('MenusManager::storeLanguageDependencies, error : unable to update label (id='.$key.' lang_id='.$langId.')', 3);
						return false;
					}
				}
				else {
					$labelFieldsArray = array(
						 'id'      => $key
						,'lang_id' => $langId
					);

	        		if(!$this->dbManipulator->queryInsert(NAMES_TABLE, $labelFieldsArray)) {
						$this->debug('MenusManager::storeLanguageDependencies, error : unable to create new label (id='.$key.' lang_id='.$langId.')', 3);
						return false;
					}
				}

				$this->debug('MenusManager::storeLanguageDependencies, success : labels updated successfully', 9);
				return true;
			}
		}
	}

	/**
	 * @return boolean
	 */
  function checkMenu($menuId) {
    return isset($this->menusTable[$menuId]);
  }

  function &getMenu($id) {
    if (!$this->checkMenu($id)){
			if ($this->loadMenu($id) < 0) {
				return null;
      }
		}		
		return $this->menusTable[$id];
  }


	function &getMenuTemplates() {
    $db = &$this->getDBManipulator();
		$menuTemplatesArray = array();
	  $result = &$db->getRecord(TEMPLATES_TABLE, -1, "type='easy_cms_page'");
	  while($row = &$db->fetchArray($result)){
       $menuTemplatesArray[$row['id']] = $row['name'];
    }
    return $menuTemplatesArray;
  }

	/**
	 * Gets New Menu
	 *
	 * @param integer $aclId
	 */
	function &getNewMenu($aclId=0) {
		$id          = 0;
		$nameId      = 0;
		$templateId  = 0;
		$rootPageId  = 0;
		$sortField   = '';
		$sortOrder   = 1;
		$sortingType = 1;

		$this->menusTable[0] = &new Menu($id, $nameId, $templateId, $rootPageId, $sortField, $sortOrder);
    $this->menusTable[0]->setMenuAclId($aclId);
    $this->menusTable[0]->setMenuSortingType($sortingType);
    $this->menusTable[0]->setMenuPublished(PUBLICATION_DEFAULT_VALUE);
		return $this->menusTable[0];
	}
	
  function setMenu(&$menu) {
    if ($this->checkMenu($menu->getId())){
			$this->debug("MenusManager.setMenu, warning : menu of id '".$menu->getId()."' already loaded in menu manager.", 3);
		}
    $this->menusTable[$menu->getId()] = &$menu;
		$this->debug("MenusManager.setMenu, status : success.", 10);		
		return 1;
	}	
	
	function menuExists($id) {
		return $this->dbManipulator->menuExists($id);	
	}	
	
	function getParentObjectValuesArray($menuId, $pageId, $frameId) {
		$result = $this->dbManipulator->queryGetPageOfMenu($pageId, $frameId, $menuId);
		
		if (!$result || !$this->dbManipulator->getNumRows()) {
			return null;
		}
		
		$row = $this->dbManipulator->fetchArray($result);
		
		return $row;
	}
	
	/**
	 * Updates Menu ACL
	 * 
	 * @param  integer $id Menu Id
	 * @param  integer $aclId ACL Id	 	 	 
	 */	 	
	function updateMenuACL($menuId, $aclId){
		$db = &$this->getDBManipulator();
		$fields = array('acl_id' => $aclId);

		if($db->setRecord(MENUS_TABLE, -1, $fields, "`id`='$menuId'")){
			return true;
		}
		return false;
	}
}
?>