<?php
/**
* This file is part of the Easy-CMS project.
* Easy-CMS is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
* 
* Easy-CMS is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License
* along with Easy-CMS; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
	
include_once('classes/core/parser/tags/Tag.class.php');
include_once('classes/core/DBManipulator.class.php');

/**
* Tag element.
*
* @access   public
* @author	Cedric Francoys <cedric.francoys@easy-cms.org>
* @version	ContainersListTag.class, Mon Jan 03 19:39:03 CET 2005
* @package	Tags
*/
class ContainersListTag extends Tag {
	
	/**
	* Constructor
	* 
	* @access   public
 	* @param    string  The complete tag syntax (i.e. : <tagname attr1="value1" attr2="value2">, <br />, </a>, ...)
 	* @param    integer The position of the tag in the xml document
 	* @return   void  
	*/	 	
	function ContainersListTag($tagString, $name, $type, $offset, $length) {
		parent::Tag($tagString, $name, $type, $offset, $length);
	}

	/**
	* Performs actions specific to the tag
	* 
	* @access   public
 	* @return   bool Returns the HTML part corresponding to the containers list.
	*/
	function evaluate(){
		$site = &Site::getInstance();
		$pageId = $this->page->getPageId();
		$frameId = $this->page->getPageFrameId();		

		$containersListsManager = &$site->getContainersListsManager();
		$dbManipulator = &$site->getDBManipulator();
				
		$drawBorder	              = $this->getAttribute('border');
		$frameContainersListName	= $this->getAttribute("id");
		$containersListSortField	= $this->getAttribute("sortfield");
		$isStatic									= $this->getAttribute("static");

		$langId = $site->getPersistentVar('lid', $site->getDefaultLangId());
		
		if ($drawBorder == null || $drawBorder == '0' || $drawBorder == 'no' || $drawBorder == 'NO') {
			$drawBorder = false;
		}
		else {
			$drawBorder = true;
		}

		if ($isStatic == null || $isStatic == "0" || $isStatic == "no" || $isStatic == "NO"){
			$isStatic = false;
		}
		else {
			$isStatic = true;
		}		

		if (($result = &$dbManipulator->getRecord(FRAME_CONTAINERS_LISTS_TABLE, $frameId, "containers_list_name = '$frameContainersListName' and page_id='".$pageId."'", "frame_id")) < 0 ){
			$this->debug("ContainersListTag.evaluate, error : unable to read DB for frame '".$frameId."'.", 2);
			return "";
		}
		
		if(!($row = &$dbManipulator->fetchArray($result))){
			// containerslist does not exist 
			// requires either a static list or a new one
			$this->debug("ContainersListTag.evaluate, notice : non-existent containersList.", 5);
			$needNewContainersList = false;
		
			if($isStatic){
				$this->debug("ContainersListTag.evaluate, notice : static container, trying to obtain reference to a previously created container.", 5);
				// search for a container id of any page of the same frame with identical name
				if(($containersListId = $dbManipulator->getStaticContainersListId($frameId, $frameContainersListName)) <= 0){
					$this->debug("ContainersListTag.evaluate, warning : unable to get any static containersList for frame '".$frameId." : requesting a new containersList'.", 3);
					$needNewContainersList = true;                    
				}
			}
			else{
				$needNewContainersList = true;
			}
		
			if($needNewContainersList){
				$this->debug("ContainersListTag.evaluate, notice : creating a new containersList.", 5);
				// create a new containersList				
				$containersListId = 0;
				$sortField = &$containersListSortField;
				$aclId = $this->page->getPageAclId();
				$containersList = &$containersListsManager->getNewContainersList($aclId);
				$containersList->setContainersListSortField($sortField);
				if ($acl = &$containersListsManager->getContainersListAcl($aclId)) {
					$containersList->setContainersListAcl($acl);
				}
				$containersListsManager->addContainersList($containersList);
				$containersListId = $containersListsManager->storeContainersList($containersListId);
				$dbManipulator->addFrameContainersList($frameId, $this->page->getPageId(), $containersListId, $frameContainersListName);
			}
		}
		else {        
			$containersListId = $row["containers_list_id"];
		}
		
		if(($containersList = &$containersListsManager->getContainersList($containersListId)) <= 0){
			$this->debug("ContainersListTag.evaluate, error : unable to get containersList '$containersListId' for frame '".$frameId."'.", 2);
			return "";
		}
			
		$this->debug("ContainersListTag.evaluate, parse 'easy-cms:containersList' tag : success.", 10);		
		
		return $containersList->toHTML($this->user, $langId, $this->mode, $drawBorder);
	}
		
}
?>