<?php
/*
 * This file is part of the easy-CMS project.
 * easy-CMS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * easy-CMS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with easy-CMS; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

/**
 * @package    Core
 * @subpackage Templates
 */

/**
 *
 */
include_once('classes/core/CoreObject.class.php');
include_once('includes/compat/php_xslt.php');

/**
 * Template Class
 *
 * Generates HTML for a given xml and its associated xsl code.
 *
 * @access     public
 * @author	   Cedric Francoys <cedric.francoys@easy-cms.org>
 * @version    Template.class,v 0.1
 * @package	   Core
 * @subpackage Templates
 */
class Template extends CoreObject {
	/**#@+
	 * @access private
	 */
	/**
	 * @var integer Template Id
	 */
  var $id;

	/**
	 * @var string Template Type Name
	 */
  var $typeName;

	/**
	 * @var string Template Name
	 */
	var $name;

	/**
	 * @var string Template Content (XSL)
	 */
  var $xsl;

	/**
	 * @var integer Is Template Deleted ?
	 */
	var $deleted;
	/**#@-*/

	/**#@+
	 * @access public
	 */
	/**
	 * Constructor
	 *
	 * @param string  $xsl
	 * @param string  $typeName Template Type
	 * @param integer $id Template Id
	 */
  function Template($id=0, $typeName='', $name='', $xsl='', $deleted=0){
    $this->setTemplateId($id);
		$this->setTemplateTypeName($typeName);
		$this->setTemplateName($name);
    $this->setTemplateXSL($xsl);
		$this->setTemplateDeleted($deleted);
	}

	/**
	 * Gets Template Id
	 *
	 * @return integer
	 */
  function getTemplateId() {
		return $this->id;
	}

	/**
	 * Sets Template Id
	 *
	 * @param integer $id Template Id
	 */
	function setTemplateId($id) {
		$this->id = $id;
	}

	/**
	 * Gets Template Type Name
	 *
	 * @return string
	 */
	function getTemplateTypeName() {
		return $this->typeName;
	}

	/**
	 * Sets Template Type Name
	 *
	 * @param string $typeName Template Type Name
	 */
	function setTemplateTypeName($typeName) {
		$this->typeName = $typeName;
	}

	/**
	 * Gets Template Name
	 *
	 * @return string
	 */
	function getTemplateName(){
		return $this->name;
	}

	/**
	 * Sets Template Name
	 *
	 * @param string $name Template Name
	 */
	function setTemplateName($name){
		$this->name = $name;
	}

	/**
	 * Gets Template XSL
	 *
	 * @return string
	 */
	function getTemplateXSL() {
		return $this->xsl;
	}

	/**
	 * Sets Template XSL
	 *
	 * @param string $xsl Template XSL
	 */
	function setTemplateXSL($xsl) {
		$this->xsl = $xsl;
	}

	/**
	 * Gets Template Deletion Flag
	 *
	 * @return integer
	 */
	function getTemplateDeleted(){
		return $this->deleted;
	}

	/**
	 * Sets Template Deletion Flag
	 *
	 * @param integer $deleted
	 */
	function setTemplateDeleted($deleted){
		$this->deleted = $deleted;
	}

	/**
	 * Exports Template Into Array
	 *
	 * @return array
	 */
	function toArray(){
		$array = array();
		//$array['id']      = $this->getTemplateId();
		$array['type']    = $this->getTemplateTypeName();
		$array['name']    = $this->getTemplateName();
		$array['xsl']     = $this->getTemplateXSL();
		$array['deleted'] = $this->getTemplateDeleted();
		return $array;
	}

	/**
	 * Process XML
	 *
	 * Computes template (XSL Transformation)
	 *
	 * @param  string $xml
	 * @param  string $mode
	 * @return string
	 */
	function processXML($xml, $mode) {
		$id       = $this->getTemplateId();
		$typeName = $this->getTemplateTypeName();
		$xsl      = $this->getTemplateXSL();
		if (!isset($xsl)) {
			$this->debug('Template::processXML, error : Template(id='.$id.' typeName="'.$typeName.'")\'s XSL is empty', 2);
			return '';
		}
		if ($mode == EDIT_MODE) {
			if($typeName == "easy_cms_page") {
				$xsl .= "<xsl:template match=\"page_controls\">\n";
				$xsl .= "			<a class=\"easy-CMS_UI_Style_propertiesIcon\" href=\"javascript:egShowContextMenu(contextMenu_menu_page_{./menu-id}_{./id});\">\n";
				$xsl .= "				<img src=\"includes/images/edit.gif\" />\n";
				$xsl .= "			</a>\n";
				$xsl .= "</xsl:template>\n";
			}
			else {
				$xsl .= "<xsl:template match=\"content_controls\">\n";
				$xsl .= "			<a class=\"easy-CMS_UI_Style_propertiesIcon\" href=\"javascript:egShowContextMenu(contextMenu_menu_content_{./container-id}_{./clone-id}_{./id});\">\n";
				$xsl .= "				<img src=\"includes/images/edit.gif\" />\n";
				$xsl .= "			</a>\n";
				$xsl .= "</xsl:template>\n";
			}
		}
		$xslSheet = "<xsl:stylesheet version=\"1.0\" xmlns:xsl=\"http://www.w3.org/1999/XSL/Transform\">";
		$xslSheet .= "<xsl:output method=\"xhtml\" encoding=\"UTF-8\" indent=\"yes\" />";
		$xslSheet .= "<xsl:output omit-xml-declaration=\"yes\" />";
		$xslSheet .= $xsl;
		$xslSheet .= "</xsl:stylesheet>\n";

		$arguments = array("/_xml" => $xml, "/_xsl" => $xslSheet);

		$xsltProcessor = xslt_create();
		if (!($html = xslt_process($xsltProcessor, "arg:/_xml", "arg:/_xsl", NULL, $arguments))) {
			$this->debug("Template(".$typeName.").processXML, error(".xslt_errno($xsltProcessor).") : ".xslt_error($xsltProcessor).".", 2);
			$this->debug($xml, 4);
			$this->debug($xsl, 4);
		}
		xslt_free($xsltProcessor);
		return $html;
	}
	/**#@-*/
}

?>