<?php
/*
 * This file is part of the Easy-CMS project.
 * Easy-CMS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * Easy-CMS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Easy-CMS; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
/**
 * @package    Core
 * @subpackage Types
 */

/**
 */
 
include_once('classes/core/DBAccessorObject.class.php');
include_once('classes/db/DBConnection.class.php');
include_once('classes/core/DBManipulator.class.php');

/**
 * Type Class
 *
 * @author	   Cedric Francoys <cedric.francoys@easy-cms.org>
 * @version	   Type.class, Sat Jan 08 20:33:55 CET 2005
 * @package    Core
 * @subpackage Types
 */
class Type extends DBAccessorObject {
	/**#@+
	 * @access private
	 */
	/**
	 * Type Name
	 *
	 * @var string
	 */
	var $name;
	
	/**
	 * Type Fields
	 *
	 * @var array
	 */
	var $fieldsArray;
	
	/**
	 * @deprecated due to naming convention
	 * @todo approve deprecation
	 */
	var $fieldsTable;
	/**#@-*/

	/**
	 * Constructor
	 *
	 * @param string  $name
	 * @param object  $dbManipulator
	 * @param integer $langId
	 */
	function Type($name, &$dbManipulator) {
		parent::DBAccessorObject($dbManipulator);        
		$this->setTypeName($name);
		$tableName   = $this->getTableName();
		$fieldsArray = $dbManipulator->getFieldsArray($tableName);
		$this->setFieldsArray($fieldsArray);
	}
	
	/**
	 * Loads Type Fields
	 *
	 * @access private
	 * @todo check for uselessness
	 */
	function _loadFieldsArray()	{
		$dbManipulator = &$this->getDBManipulator();
		$tableName     = $this->getTableName();
		$this->setFieldsArray($dbManipulator->getFieldsArray($tableName));
	}
	
	/**
	 * Gets Type Name
	 *
	 * @return string
	 */
	function getTypeName() {
		return $this->name;
	}
	
	/**
	 * Sets Type Name
	 *
	 * @param string $name
	 */
	function setTypeName($name) {
		$this->name = $name;
	}

	/**
	 * Gets Type Fields
	 *
	 * @return array
	 */
	function getFieldsArray() {
		if (!isset($this->fieldsArray))
			return null;
		return $this->fieldsArray;
	}
	
	/**
	 * Sets Type Fields
	 *
	 * @param array
	 */
	function setFieldsArray($fieldsArray) {
		$this->fieldsArray = $fieldsArray;
	}
    
	/**
	 * Gets Table Name
	 *
	 * Returns name of table that holds Type records
	 *
	 * @return string
	 */
	function getTableName() {
		return TYPE_TABLES_PREFIX.$this->getTypeName();
	}
	
	/**
	 * Checks Fields
	 *
	 * Checks if $fieldName is defined in {@link $fieldsArray}
	 *
	 * @return boolean
	 */
	function fieldExists($fieldName) {
		return isset($this->fieldsArray[$fieldName]);
	}
	
	/**
	 * Checks Record
	 *
	 * Checks if record of given $id and $langId exists in table
	 *
	 * @param  integer $id record Id
	 * @param  integer $langId language Id
	 * @return boolean
	 */
	function recordExists($id, $langId)	{
		$dbManipulator = &$this->getDBManipulator();
		$tableName     = $this->getTableName();
		
		$result = $dbManipulator->getRecord($tableName, $id, '`lang_id`='.$langId);
		
		if (!$result || !$dbManipulator->getNumRows()) {
			return false;
		}
		
		return true;
	}

	/**
	 * Gets Record
	 *
	 * Gets record of given id and language from table
	 *
	 * @param  integer $id
	 * @param  integer $langId
	 * @return array
	 * @todo approve modification
	 */
	function getRecord($id, $langId) {
		$dbManipulator = &$this->getDBManipulator();
		$tableName     = $this->getTableName();		
		
		$result = $dbManipulator->getRecord($tableName, $id, '`lang_id`='.$langId);
		
		if (!$result || !$dbManipulator->getNumRows()) {
			$this->debug('Type::getRecord, error : unable to get record(id='.$id.' lang_id='.$langId.')', 3);
			return false;
		}
		
		return $dbManipulator->fetchArray($result);
	}

	/**
	 * Sets Record
	 *
	 * Updates record of given id and language in table
	 *
	 * @param  integer $id
	 * @param  array   $fieldsArray
	 * @param  inger $langId
	 * @return boolean
	 * @todo approve modification
	 */
	function setRecord($id, $fieldsArray, $langId) {
		$dbManipulator = &$this->getDBManipulator();
		$tableName     = $this->getTableName();
		
		$result = $dbManipulator->setRecord($tableName, $id, $fieldsArray, '`lang_id`='.$langId);
		
		if (!$result || !$dbManipulator->getAffectedRows()) {
			$this->debug('Type::setRecord, warning : unable to update or no change for record(id='.$id.' lang_id='.$langId.')', 5);
			return false;
		}
		
		return true;
	}

	/**
	 * Adds Record
	 *
	 * Adds record of id and language into table
	 *
	 * @param  array   $fieldsArray
	 * @param  integer $id
	 * @param  integer $langId
	 * @return integer last id or <0 if error
	 * @todo approve modification
	 */
	function addRecord($id, $fieldsArray, $langId) {
		$dbManipulator = &$this->getDBManipulator();
		$tableName     = $this->getTableName();
		
		$fieldsArray['lang_id'] = $langId;
		
		if ($id > 0) {
			$fieldsArray['id'] = $id;
		}
		
		$result = $dbManipulator->addRecord($tableName, $fieldsArray);
		
		if (!$result || !$dbManipulator->getAffectedRows()) {
			return 0;
		}
		
		if (!$id) {
			if (!($id = $dbManipulator->getLastId())) {
				return 0;
			}
		}
		
		return $id;
	}

	/**
	 * Deletes Record
	 *
	 * Deletes record of given id and language from table
	 *
	 * @param  integer $id
	 * @param  integer $langId
	 * @return boolean
	 * @todo approve modification
	 */
	function delRecord($id, $langId) {
		$dbManipulator = &$this->getDBManipulator();
		$tableName     = $this->getTableName();
		
		$result = $dbManipulator->delRecord($tableName, $id);
		
		if (!$result || !$dbManipulator->getAffectedRows()) {
			$this->debug('Type::delRecord, error : unable to delete record(id='.$id.' lang_id='.$langId.')', 3);
			return false;
		}
		
		return true;
	}

	/**
	 * Gets Field Value
	 * 
	 * @param  string $fieldName
	 * @return mixed  null if error
	 * @todo check for uselessness
	 */
	function getField($fieldName) {
		if (!$this->fieldExists($fieldName)) {
            return null;
		}
		return $this->fieldsArray[$fieldName];
	}

	/**
	 * Puts fields' type into a string
	 *
	 * @return string
	 * @todo check for uselessness
	 */
	function toString() {
        $str = "name : ".$this->name."\nfields :\n";
        foreach ($this->getFieldsArray() as $key => $value) {
            $str .= "   $key\n";
        } 
        return $str;
	}
	
	/**
	 * Gets Type Fields
	 *
	 * @return array
	 * @deprecated use {@link getFieldsArray}
	 */
	function getSimpleTypesArray()
	{
		return $this->getFieldsArray();
	}
	
	/**
	 * @deprecated due to naming convention
	 * @todo approve deprecation
	 */
    function getFieldsTable() 
	{
    	return $this->getFieldsArray();
    }
	
	/**
	 * @deprecated due to naming convention
	 * @todo approve deprecation
	 */
    function setName($name) 
	{
        $this->setTypeName($name);
    } 

	/**
	 * @deprecated due to naming convention
	 * @todo approve deprecation
	 */
    function getName() 
	{
        return $this->getTypeName();
    }
	
	/**
	 * @deprecated due to naming convention
	 * @todo approve deprecation
	 */
	function loadFieldsTable()
	{
		$this->setFieldsArray($this->dbManipulator->getFieldsArray($this->getTableName()));
	}
	
	/**
	 * @deprecated due to naming convention
	 * @todo approve deprecation
	 */
    function checkField($fieldName) 
	{
        return $this->fieldExists($fieldName);
    }
	
	/**
	 * @deprecated
	 * @todo approve deprecation
	 */
    function getFieldsCount() 
	{
		$fieldsArray = $this->getFieldsArray();
		if (!$fieldsArray)
			return 0;
		return count($fieldsArray);
    } 
	
	/**
	 * @deprecated
	 * @todo approve deprecation
	 */
    function addField($fieldName, $cmsType) 
	{
		if($this->checkField($fieldName)){
			$this->debug("Type(".$this->getName().").addField, warning : field '$fieldName' already exists (add skipped).[DEPRECATED]");
		}
		else
			$this->fieldsTable[$fieldName] = $cmsType; //?tester $cmsType
    } 

	/**
	 * @deprecated
	 * @todo approve deprecation
	 */
    function removeField($fieldName) 
	{
		if(!$this->checkField($fieldName)){
			$this->debug("Type(".$this->getName().").removeField, warning : unknown field '$fieldName' (remove skipped).[DEPRECATED]");
		}
		else {
			unset($this->fieldsTable[$fieldName]);
		}
    } 
	
	/**
	 * @deprecated
	 * @todo approve deprecation
	 */
	function readDB()	{
        $this->fieldsTable = &$this->dbManipulator->getFieldsArray($this->getTableName());
	}

	/**
	 * @deprecated
	 * @todo approve deprecation
	 */
	function writeDB() {
        //$dbConnection = &$this->dbManipulator->getDBConnection(); deprecated
		$dbConnection = $this->dbManipulator;
		
		if($dbConnection->tableExists($this->getTableName())){
			$fieldsTable = &$this->getFieldsTable();
			$fieldsArray = &$this->dbManipulator->getFieldsArray($this->getTableName());			
			$newFieldsArray = (array) null;
			$oldFieldsArray = (array) null;
			
			foreach ($fieldsTable as $key => $value) {
				if (!isset($fieldsArray[$key]))
		   			$newFieldsArray[$key] = $this->dbManipulator->getDBMSType($value);
			}
			foreach ($fieldsArray as $key => $value) {
				if (!isset($fieldsTable[$key]))
		   			$oldFieldsArray[$key] = $this->dbManipulator->getDBMSType($value);
			}			
			$dbConnection->updateTable($this->getTableName(), $newFieldsArray, $oldFieldsArray);
		}
		else{
			foreach ($this->getFieldsTable() as $key => $value) {
				$newFieldsArray[$key] = $this->dbManipulator->getDBMSType($value);
			}		
			$dbConnection->createTable($this->getTableName(), $newFieldsArray);
		}
	}

	/**
	 * @deprecated
	 * @todo approve deprecation
	 */
	function removeDB() {
        //$dbConnection = &$this->dbManipulator->getDBConnection(); to be removed
		//$dbConnection->dropTable($this->getTableName()); to be removed
		$this->dbManipulator->dropTable($this->getTableName());
	}
} 

?>