<?php
/**
* This file is part of the Easy-CMS project.
* Easy-CMS is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
* 
* Easy-CMS is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License
* along with Easy-CMS; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
	
include_once('classes/db/DBMSData.class.php');
include_once('classes/db/DBConnection.class.php');
include_once('classes/core/CoreObject.class.php');

/**
* Manage the calls of specific MySQL functions for DBConnection functions.
*
* @access   private
* @author	Cedric Francoys <cedric.francoys@easy-cms.org>
* @version 	$Id: DBConnectionMySQL.class.php,v 1.1.1.1 2006/02/28 12:05:54 vinadelmar Exp $
* @package	DB
*/
class DBConnectionMySQL extends DBConnection {

	/**
	 * Object containing db data for SQL transactions.
	 *
	 * @var string
	 */
	var $dbData;

	/** 
	 * Variable containing the latest error id.
	 *
	 * The possible values of this var are depending on the DBMS used (here MySQL)
	 *
	 * @var		integer
	 * @access	public
	 */
	var $lastId;
	
	/** 
	 * Variable containing the latest error.
	 *
	 * The possible values of this var are depending on the DBMS used (here MySQL)
	 * The string can generally be retrieved using the $lastId var value.
	 *
	 * @var		string
	 * @access	public
	 */
	var $lastError;

	/** 
	 * Variable containing the number of affected rows.
	 *
	 * The possible values of this var are depending on the DBMS used (here MySQL)
	 * The integer can generally be retrieved using the $affectedRows var value.
	 *
	 * @var		integer
	 * @access	public
	 */
	var $affectedRows;
	
	/**
	 * Class constructor.
	 *
	 * Initialize the DBMSData object containing data for SQL transactions.
	 *
	 * @access   public
 	 * @param    string    The hostname of the DB server.
	 * @param    string    The name of the DB.
	 * @param    string    The username to use for the connection to the DB.
	 * @param    string    The password to use for the connection to the DB.
 	 * @return   void
	 */
	function DBConnectionMySQL($host, $db, $user, $pass) {
		parent::DBConnection(MYSQL);
        $this->dbData = new DBMSData($host, $db, $user, $pass);
	}
	
	/* to be removed
    function &getDBMSData() {
        return $this->dbData;
    } 
	*/

	/**
	 * Open the DBMS connection.
	 *
	 * @return   integer   The status of the connect function call.
	 * @access   public
	 */
	// ok
	function connect() {
		if(mysql_connect($this->dbData->getHostName(), $this->dbData->getUserName(), $this->dbData->getPassword())){
	        $result = mysql_select_db($this->dbData->getDBName());
		}
		else {
			die("Unable to establish DB connection : check your parameters.");
		}
		return $result;
	}

	/**
	* Close the DBMS connection.
	*
	* @return   integer   The status of the close function call.
	* @access   public
	*/
	//ok
	function disconnect() {
		$result = mysql_close();
		$this->setLastError(mysql_errno()." : ".mysql_error());
		return $result;
	}

	//ok
	function getLastId() {
		return $this->lastId;
	}

	//ok
	function getAffectedRows() {
		return $this->affectedRows;
	}
 
	//ok
	function getLastError() {
		return $this->lastError;
	}
	//ok
	function setLastId($id) {
		$this->lastId = $id;
	}

	// ok
	function setAffectedRows($affectedRows) {
		$this->affectedRows = $affectedRows;
	}

	// ok
	function setLastError($error) {
		$this->lastError = $error;
	}

	/**
	* Send a SQL query.
	*
	* @param string The query to send to the DBMS.
	* @return resource Returns a resource identifier or -1 if the query was not executed correctly.
	*/
	//ok
	function &sendQuery($query) {
		if( ($result = mysql_query($query)) <= 0){
			$this->setLastError(mysql_errno()." : ".mysql_error());
			$this->debug("DBConnectionMySQL.sendQery, status : error - ".$this->getLastError().", query : $query.", 1);
			return -1;
		}
		$this->setAffectedRows(mysql_affected_rows());
		$this->setLastId(mysql_insert_id());
		$this->debug("DBConnectionMySQL.sendQery '$query', status : success.", 10);
		return $result;
	}

	//ok
	function &fetchRow(&$array) {
		$row = &mysql_fetch_row($array);
		$this->setLastError(mysql_errno()." : ".mysql_error());
		$this->debug("DBConnectionMySQL.fetchRow ($array), status : success.", 10);		
		return $row;
	}

	//ok
	function &fetchArray(&$array) {
		$row = &mysql_fetch_array($array);
		$this->setLastError(mysql_errno()." : ".mysql_error());
		$this->debug("DBConnectionMySQL.fetchArray ($array), status : success.", 10);		
		return $row;
	}

	//ok
    function &getTables($prefix = "") {
        $query = "show tables like '" . $prefix . "%';";
        return $this->sendQuery($query);
    } 

	//ok
    function &getTable($table) {
        $query = "show tables like '$table';";
        return $this->sendQuery($query);
    } 

	//ok
    function tableExists($table) {
        $result = &$this->getTable($table);
        return ($this->fetchArray($result));
    } 

	//ok
    function recordExists($table, $id, $cond = "", $idField = "id") {
        $result = &$this->getRecord($table, $id, $cond, $idField);
		return ($this->fetchArray($result));
    } 
	
	//ok
    function &getColumns($table) {
        $query = "show full columns from `$table`;";
        return $this->sendQuery($query);
    } 

	//ok
	function &getRecord($table, $id = "", $cond = "", $idField = "id", $order = "") {
		$query = "select * from `$table`";
		$where = "";
		if ($id != "" || $cond != "") {
	        $query .= " where";
		}
		if ($id != "") {
	        $where .= " `$idField` = '$id'";
		}
		if ($cond != "") {
			if ($where != "") {
				$where .= " and";
				$where .= " $cond";
			}
		}
		$query .= "$where";
		if($order != "") {
			$query .= " order by `$order`";
		}
		$query .= ";";
		return $this->sendQuery($query);
	}

	//ok
	function &setRecord($table, $id, $fieldsArray, $cond = "", $idField = "id") {
		$query = "update `$table` set ";
		$strLen = strlen($query);
    foreach ($fieldsArray as $key => $value) {
			if (strlen($query) > $strLen) {
        	    $query .= ", ";
      }
      $query .= "`$key` = '".addslashes($value)."'";
    }
    $query .= " where `$idField` = '$id'";
		if ($cond != "") {
      $query .= " and $cond";
    }
    $query .= ";";
    return $this->sendQuery($query);
  }

	//ok
  function delRecord($table, $id, $cond = "", $idField = "id") {
    $query = "delete from `$table` where `$idField` = '$id'";
		if ($cond != "") {
      $query .= " and $cond";
    }
    $query .= ";";
    return $this->sendQuery($query);
  }

	//ok
	function addRecord($table, $fieldsArray) {
		$query  = "insert into `$table` (";
		$keys   = "";
		$values = "";		
		foreach ($fieldsArray as $key => $value) {
			if (strlen($keys)){
        	    $keys   .= ", ";
        	    $values .= ", ";				
			}			    
            $keys   .= "`$key`";
            $values .= "'".addslashes($value)."'";			
		}
		$query .= "$keys) values ($values);";
		return $this->sendQuery($query);
	}

	//ok
	function dropTable($table) {
		$query = "drop table `$table`;";
		return $this->sendQuery($query);
	}

	//ok
	function createTable($table, $columnsArray) {
		$query  = "create table `$table` (";
		$query .= "`id` int not null auto_increment ";
		foreach ($columnsArray as $key => $value) {
	    	$query .= ", `$key` $value not null ";
		}
		$query .= "primary key (`id`));";
		return $this->sendQuery($query);
	}

	//ok
	function updateTable($table, $newColumnsArray, $oldColumnsArray) {
		$query = "";
		foreach ($newColumnsArray as $key => $value) {
			if (strlen($query)) {
				$query .= ", ";
			}
			$query .= "add `$key` $value not null";
		}
		foreach ($oldColumnsArray as $key => $value) {
			if (strlen($query)) {
				$query .= ", ";
			}
			$query .= "drop `$key`";
		}
		$query = "alter table `$table` ".$query.";";
		return $this->sendQuery($query);
	}		
	
}
?>