<?php
/*
 * This file is part of the easy-CMS project.
 * easy-CMS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * easy-CMS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with easy-CMS; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/**
 * @package Debug
 */

/**
 * @author  cedseven <cedseven@users.sourceforge.net>
 * @package Debug
 */
class Debug {

    function Debug() {
		}

    function &getInstance() {
    	static $debug = null;
		
      if (is_null($debug)){
        	$debug = new Debug();
			}
      return $debug;
    } 
	
    function report($text, $level = 0) {
			if(ENABLE_LOGGING <= 0) {
				return 0;
			}
      if($level > DEBUG_LEVEL) {
				return 0;
			}
			$message = '';
			for($i = 0; $i < $level; ++$i) {
				$message .= ' ';
			}
			$message .= "(level $level) ".$text."\n";

      if(is_file(DEBUG_FILE)) {
        clearstatcache();
        $size = sprintf("%u", filesize(DEBUG_FILE));
        if($size > MAX_LOG_SIZE) {
          unlink(DEBUG_FILE);
        }
      }

			if(!($file = @fopen(DEBUG_FILE, 'a+'))) {
	      $this->debug("File.write, error : unable to open file '".DEBUG_FILE."'.", 1);
	      return -1;
	    }
	    if($file) {
	    	if (!(@fwrite($file, $message))) {
					$this->debug("File.write, error : unable to write to file '".DEBUG_FILE."'.", 1);
					return -1;
				}
				fclose($file);
			}
    }

    function &getReport($level = 0) {
			// TODO
			// return content of the log file
			//return file_get_contents(DEBUG_FILE);
			return '';
    } 
}


set_error_handler('errorHandler');
error_reporting(E_ALL);

function errorHandler($errno, $errstr, $errfile, $errline, $errcontext) {
	$debug = &Debug::getInstance();
	$errorString = '';
/*
1	 E_ERROR
2	E_WARNING
4	E_PARSE
8	E_NOTICE
16	E_CORE_ERROR
32	E_CORE_WARNING
64	E_COMPILE_ERROR
128	E_COMPILE_WARNING
256	E_USER_ERROR
512	E_USER_WARNING
1024	E_USER_NOTICE
2047	E_ALL
2048	E_STRICT
4096	E_RECOVERABLE_ERROR
*/
  switch ($errno) {

		// errno = 1
    case E_ERROR:
			$errorString = 'error';
			break;
		// errno = 2
    case E_WARNING:
			$errorString = 'warning';
			break;
		// errno = 4
    case E_PARSE:
			$errorString = 'parse';
			break;
		// errno = 8
    case E_NOTICE:
			$errorString = 'notice';
			// do not log php notices
			return 0;
			break;
		// errno = 16
    case E_CORE_ERROR:
			$errorString = 'core error';
			break;
		// errno = 32
    case E_CORE_WARNING:
			$errorString = 'core warning';
			break;
		// errno = 64
    case E_COMPILE_ERROR:
			$errorString = 'compile error';
			break;
		// errno = 128
    case E_COMPILE_WARNING:
			$errorString = 'compile warning';
			break;
		// errno = 256
    case E_USER_ERROR:
			$errorString = 'user error';
			break;
		// errno = 512
		case E_USER_WARNING:
			$errorString = 'user warning';
			break;
		// errno = 1024
    case E_USER_NOTICE:
			$errorString = 'user notice';
			// do not log php notices
			return 0;
			break;
		// errno = 2048
    case E_STRICT:
			$errorString = 'strict syntax notice';
			// do not log php notices
			return 0;
			break;
		// errno = 4096
    case E_RECOVERABLE_ERROR:
			$errorString = 'recoverable error';
			break;

	}
	$message = "php $errorString (# $errno) : $errstr, in line $errline of file '$errfile' ";
	if (isset($errcontext['this'])) {
	  if (is_object($errcontext['this'])) {
	     $classname = get_class($errcontext['this']);
	     $parentclass = get_parent_class($errcontext['this']);
	     $message .= " :: Object/Class: '$classname', Parent Class: '$parentclass'";
	  }
	}
	$debug->report($message);
}
?>