<?php
/*
 * This file is part of the easy-CMS project.
 * easy-CMS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * easy-CMS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with easy-CMS; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

include_once('classes/core/CoreObject.class.php');

/**
 * Node Class
 *
 * @author  cedseven
 * @package System
 */
class Node extends CoreObject {
	/**
	 * Node Name
	 *
	 * @access protected
	 * @var    string
	 */
	var $name;

	/**
	 * Node parent
	 *
	 * @access protected
	 * @var    object
	 */
	var $parentNode;
	
	/**
	 * Node Path
	 *
	 * @access protected
	 * @var    string
	 */
	var $path;
	
	/**
	 * Constructor
	 *
	 * @param string $name
	 * @param string $path
	 */
	function Node($name, $path) {
		if ($name == '') {
			$infos = $this->getInfosFromFullPath($path);
			$path = $infos['path'];
			$name = $infos['name'];
		}
		$this->setName($name);
		$this->setPath($path);
    $this->parentNode = null;
	}

	function read() {
	}

	function write() {
	}

	function remove() {
	}

	function rename($newName) {
		$oldName = $this->getName();
		$oldPath = $this->getNodeFullName();
		$this->setName(Node::toValidName($newName));
		$newPath = $this->getNodeFullName();

		if(is_file($newPath) || is_dir($newPath)) {
			$this->setName($oldName);
			return -1;
		}

		rename($oldPath, $newPath);
		return 1;
	}

	/**
	 * checks if a node is hidden (dot file)
	 *
	 * @static
	 * @return boolean
	 */
	function isHiddenFile($fileName) {
		return (strlen($fileName) && ($fileName{0} == '.'));
	}

	/**
	 * checks if a filename is valid
	 *
	 * @static
	 * @return boolean
	 */
	function isValidFileName($fileName) {
	  // begin with a-z or A-Z or 0-9
	  // min 4 chars (extension included)
	  // max 125 chars
	  // allowed chars : alphanum . _ -
		return ereg("(^[a-zA-Z0-9]+([a-zA-Z\_0-9\.-]*){3,124})$", $fileName);
	}

  function setPath($path) {
		$this->path = $path;
  }

  function setName($name) {
		$this->name = $name;
  }

  function setParentNode(&$parentNode) {
		$this->parentNode = &$parentNode;
  }

	function getParentNode() {
		return $this->parentNode;
	}
	
	function getNodeType() {
	
	}
	
	/**
	 * Gets Node Name
	 *
	 * @return string
	 */
	function getName() {
		return $this->name;
	}
	
	/**
	 * Gets Node Path
	 *
	 * @return string
	 */
	function getPath() {
		return $this->path;
	}
	
	/**
	 * Gets Node Size
	 *
	 * @return integer
	 */
	function getSize() {
		if (!($size = filesize($this->getNodeFullName())))
			return 0;
		return $size;
	}
	
	/**
	 * Gets Node Name
	 *
	 * Node name for display
	 *
	 * @return string
	 */
	function getDisplayName() {
		return str_replace('_', ' ', $this->getName());
	}

	function getNodeFullName() {
		$path = $this->getPath();
		if(strlen($path) > 0 && $path[strlen($path)-1] != '/') {
			$path .= '/';
		}
		$path .= $this->getName();
		return $path;
	}
	
	function getInfosFromFullPath($path) {
		$array = split("[/\]", $path);
		$name = '';
		$path = '';
		$i = 0;
		foreach ($array as $node) {
			if ($i > 1 && strlen($name) > 0) {
				$path .= '/';
	 		}
			$path .= $name;
			$name = $node;
			++$i;
		}
		$infos['name'] = $name;
		$infos['path'] = $path;		
		return $infos;
	}

	// @static
	function toValidName($fileName) {
		// replace invalid chars in filename
// todo : to improve
		$convertTable = array(
				" "		=>	"_",
				"'"		=>	"",
				"\""	=>	"",
				"!"		=>	"",
				"?"		=>	"",
				"%"		=>	"",
				"$"		=>	"",
				""		=>	"",
				""		=>	"",
				"&"		=>	"",
				"#"		=>	"",
				"@"		=>	"",
				"~"		=>	"",
				"^"		=>	"",
				""		=>	"",
				"("		=>	"",
				")"		=>	"",
				"["		=>	"",
				"]"		=>	"",
				"+"		=>	"",

				""		=>	"n",
				""		=>	"N",
				""		=>	"c",
				""		=>	"C",

				""		=>	"a",
				""		=>	"a",
				""		=>	"a",
				""		=>	"a",
				""		=>	"a",
				""		=>	"a",
				"-"		=>	"A",
				"+"		=>	"A",
				"-"		=>	"A",
				"-"		=>	"A",
				"+"		=>	"A",
				"+"		=>	"A",

				""		=>	"e",
				""		=>	"e",
				""		=>	"e",
				""		=>	"e",
				"+"		=>	"E",
				"+"		=>	"E",
				"-"		=>	"E",
				"-"		=>	"E",

				""		=>	"i",
				""		=>	"i",
				""		=>	"i",
				""		=>	"i",
				"-"		=>	"I",
				""		=>	"I",
				"+"		=>	"I",
				""		=>	"I",

				""		=>	"o",
				"="		=>	"o",
				""		=>	"o",
				""		=>	"o",
				""		=>	"O",
				""		=>	"O",
				""		=>	"O",
				""		=>	"O",

				""		=>	"u",
				""		=>	"u",
				""		=>	"u",
				""		=>	"u",
				"+"		=>	"U",
				"+"		=>	"U",
				""		=>	"U",
				"_"		=>	"U",

				""		=>	"y",
				""		=>	"y",
				""		=>	"Y",
		);

		$result = strtr($fileName, $convertTable);

		if($result[0] == '-' || $result[0] == '_' ) {
				$result[0] = '0';
		}

		return $result;
	}
}
?>