<?php
/*
 * This file is part of the Easy-CMS project.
 * Easy-CMS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * Easy-CMS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Easy-CMS; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/**
 */
 
/**
 *
 */
define('STEP1', 'init');
define('STEP2', 'process');
define('STEP3', 'end');

include_once('config.inc.php');
include_once('classes/core/Site.class.php');
include_once('classes/core/HTMLManager.class.php');

function getFormDetails()
{
	$html  = '';
	$html .= '<p>'."\n";
	$html .= '  <label for="type_name">Name : </label>'."\n";
	$html .= '  <input id="type_name" name="type_name" type="text" size="20"/><br/>'."\n";
	$html .= '  <label for="num_fields">Number of fields : </label>'."\n";
	$html .= '  <input id="num_fields" name="num_fields" type="text" size="5"/>'."\n";
	$html .= '</p>'."\n";
	return $html;
}

function getFormFields()
{
	$site = &Site::getInstance();
	
	$typeName  = strtolower(trim($site->getSubmittedVar('type_name', '')));
	$numFields = trim($site->getSubmittedVar('num_fields', ''));
	
	if (!$typeName || !$numFields) {
		return '';
	}
	
	// only letters allowed for type name
	if (!preg_match('`^[a-z]{3,}$`', $typeName)) {
		return '';
	}
	
	if (!is_numeric($numFields) || $numFields<=0) {
		return '';
	}
	
	$html  = '';
	$html .= '<table>'."\n";
	$html .= '<caption>Fields for type "'.$typeName.'"</caption>'."\n";
	$html .= '<thead>'."\n";
	$html .= '<tr>'."\n";
	$html .= '  <th>Field Name</th>'."\n";
	$html .= '  <th>Field Type</th>'."\n";
	$html .= '</tr>'."\n";
	$html .= '<tfoot>'."\n";
	$html .= '<tr>'."\n";
	$html .= '  <th>Field Name</th>'."\n";
	$html .= '  <th>Field Type</th>'."\n";
	$html .= '</tr>'."\n";
	$html .= '</tfoot>'."\n";
	$html .= '<tbody>'."\n";
	
	for ($i=0; $i<$numFields; $i++) {
		$html .= '<tr>'."\n";
		$html .= '  <td><input name="field_'.($i+1).'_name" type="text" size="20" /></td>'."\n";
		$html .= '  <td>'."\n";
		$html .= '    <select name="field_'.($i+1).'_type">'."\n";
		$html .= '    <option value="'.INTEGER.'">Integer</option>'."\n";
		$html .= '    <option value="'.FLOAT.'">Float</option>'."\n";
		$html .= '    <option value="'.BOOL.'">Bool</option>'."\n";
		$html .= '    <option value="'.STRING.'">String</option>'."\n";
		$html .= '    <option value="'.SHORTTEXT.'">Short Text</option>'."\n";
		$html .= '    <option value="'.TEXT.'">Text</option>'."\n";
		$html .= '    <option value="'.COLOR.'">Color</option>'."\n";
		$html .= '    <option value="'.LINK.'">Link</option>'."\n";
		$html .= '    <option value="'.DATE.'">Date</option>'."\n";
		$html .= '    <option value="'.TIME.'">Time</option>'."\n";
		$html .= '    <option value="'.DOCUMENT.'">Document</option>'."\n";
		$html .= '    <option value="'.IMAGE.'">Image</option>'."\n";
		$html .= '    <option value="'.REFERENCE.'">Reference</option>'."\n";
		$html .= '    </select>'."\n";
		$html .= '  </td>'."\n";
		$html .= '</tr>'."\n";
	}
	
	$html .= '</tbody>'."\n";
	$html .= '</table>'."\n";
	$html .= '<p>'."\n";
	$html .= '  <input type="hidden" name="type_name" value="'.$typeName.'" />'."\n";
	$html .= '  <input type="hidden" name="num_fields" value="'.$numFields.'" />'."\n";
	$html .= '</p>'."\n";
	
	return $html;
}

function createContentType()
{
	$site = &Site::getInstance();
	$dbManipulator = &$site->getDBManipulator();
	
	$reservedNames = array('id', 'lang_id', 'acl_id', 'deleted', 'published');
	
	foreach ($reservedNames as $name) {
		if (in_array($name, $_POST)) {
			return false;
		}
	}
	
	$typeName  = $site->getSubmittedVar('type_name', '');
	$numFields = $site->getSubmittedVar('num_fields', 0);
	
	if (!$typeName || !$numFields) {
		echo 'no typename no numfields';
		return false;
	}
	
	$fieldsArray = array();
	
	for ($i=1; $i<=$numFields; $i++) {
		$name = $_POST['field_'.$i.'_name'];
		$type = $_POST['field_'.$i.'_type'];
		$fieldsArray[$name] = $type;
	}
	
	
	$ret = $dbManipulator->queryNewContentTable($typeName, $fieldsArray);
	
	$site->siteDestructor();
	
	return $ret;
}


$site = &Site::getInstance();

$htmlManager = new HTMLManager('Create Content Type');

$user = &$site->getCurrentUser();

if ($user->getUserId() != 1) {
	exit('Access denied');
}

$step = $site->getSubmittedVar('step', '');

switch ($step) {
case STEP1:
	if (!($html = getFormFields())) {
		$html = getFormDetails();
		$step = STEP1;
	}
	else {
		$step = STEP2;
	}
	break;
	
case STEP2:
	if (!createContentType()) {
		$html  = '<p style="color:red;font-weight:bold">Error! Try again.</p>'."\n";
		$html .= getFormDetails();
		$step = STEP1;
	}
	else {
		$html = '<p style="color:green;font-weight:bold">Content type created</p>';
		$step = STEP3;
	}
	break;

// ok, exit
case STEP3:
	$html  = '';
	$html .= '<script type="text/javascript">'."\n";
	$html .= 'window.location.href="index.php";'."\n";
	$html .= '</script>';
	break;
	
default:
	$html = getFormDetails();
	$step = STEP1;
}

$htmlManager->addHTML('<form action="create_content_type.php" method="post">');
$htmlManager->addHTML($html);
$htmlManager->addHTML('<p>');
$htmlManager->addHTML('  <input type="hidden" name="step" value="'.$step.'" />');
$htmlManager->addHTML('  <input type="hidden" name="pid" value="1" />');
$htmlManager->addHTML('  <input type="submit" value="'.(($step == STEP3) ? 'Finish' : 'Ok').'" />');
$htmlManager->addHTML('</p>');
$htmlManager->addHTML('</form>');

echo $htmlManager->getHTML();

?>
