<?php
/*
 * This file is part of the Easy-CMS project.
 * Easy-CMS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Easy-CMS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Easy-CMS; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

include_once('config.inc.php');
include_once('classes/core/Site.class.php');

include_once('classes/system/Dir.class.php');
include_once('classes/system/File.class.php');


include_once('interface/egScript.class.php');
include_once('interface/egManager.class.php');
include_once('interface/egContainer.class.php');
include_once('interface/egMenuItem.class.php');
include_once('interface/egFrame.class.php');
include_once('interface/egToolTip.class.php');
include_once('interface/egRichText.class.php');
include_once('interface/egLink.class.php');
include_once('interface/egStatic.class.php');
include_once('interface/egEdit.class.php');
include_once('interface/egCheckBox.class.php');
include_once('interface/egRadioButton.class.php');
include_once('interface/egPressButton.class.php');
include_once('interface/egDropDownListBox.class.php');
include_once('interface/egPropertyList.class.php');
include_once('interface/egPropertySheet.class.php');
include_once('interface/egPropertyPage.class.php');
include_once('interface/egTreeNode.class.php');
include_once('interface/egTreeList.class.php');
include_once('interface/egSubWindow.class.php');


$site = &Site::getInstance(); // constructor checks the $_GET, $_POST and $_SESSION arrays

//security check : user must be identified to upload some file
$user = $site->getCurrentUser();
if(!$user || $user->getUserId() == USER_ID_ANONYMOUS) {
	die("access denied");
	exit();
}

function &decodeURLPath($urlPath){
	return str_replace(',', '/', urldecode($urlPath));
}


$mode 		= $site->getSubmittedVar('mode', ASK_DELETE_FILE);
$path 	 	= decodeURLPath($site->getSubmittedVar('path'));

if(!is_file($path)) {
	if(!is_dir($path)) {
		$mode = DELETE_FILE;
	}
}

switch ($mode) {
	case ASK_DELETE_FILE :
		$manager = &egManager::getInstance(LANG_FILE_REMOVE_TITLE);
		$main = &new egContainer("main_ctn", 0, 0, 0, 0);
		$manager->addContainer($main);

		$node = &new File("", $path);
		$nodeName = $node->getName();

		$txtValue = &new egStatic("txt_value_1", "You are about to delete this file:<br /><b>$nodeName</b><br /><br />Are you sure ?", 10, 15, 350, 0, false);

		$okButton = &new egPressbutton("btn_ok", LANG_OK_BUTTON, 130, 100, 80, null, "clickOKButton();");
		$cancelButton = &new egPressbutton("btn_cancel", LANG_CANCEL_BUTTON, 215, 100, 80, null, "clickCancelButton();");

		$hiddenValuesContainer = &new egContainer("ctn_hidden_values", 0, 0, 1, 1);

		$objMode = &new egEdit("hidden_control_mode", DELETE_FILE, 0, 0, 0, 0, "mode");
		$objPath = &new egEdit("hidden_control_path", $path, 0, 0, 0, 0, "path");

		$hiddenValuesContainer->addObject($objMode);
		$hiddenValuesContainer->addObject($objPath);

		$manager->addContainer($hiddenValuesContainer);

		$main->addObject($okButton);
		$main->addObject($cancelButton);

		$main->addObject($txtValue);

		$scripts = &new egScript();
		$line = "function clickOKButton() {
document.forms[0].submit();
}
function clickCancelButton() {
window.close();
}
";
		$scripts->addLine($line);
		$manager->addScripts($scripts);

		echo $manager->getHTML();
		break;
	case ASK_DELETE_DIR :
		$manager = &egManager::getInstance(LANG_DIR_REMOVE_TITLE);
		$main = &new egContainer("main_ctn", 0, 0, 0, 0);
		$manager->addContainer($main);

		$node = &new Dir("", $path);
		$nodeName = $node->getName();

		$txtValue = &new egStatic("txt_value_1", "You are about to delete this folder:<br /><b>$path</b><br /><br />Are you sure ?", 10, 15, 350, 0, false);

		$okButton = &new egPressbutton("btn_ok", LANG_OK_BUTTON, 130, 100, 80, null, "clickOKButton();");
		$cancelButton = &new egPressbutton("btn_cancel", LANG_CANCEL_BUTTON, 215, 100, 80, null, "clickCancelButton();");

		$hiddenValuesContainer = &new egContainer("ctn_hidden_values", 0, 0, 1, 1);

		$objMode = &new egEdit("hidden_control_mode", DELETE_DIR, 0, 0, 0, 0, "mode");
		$objPath = &new egEdit("hidden_control_path", $path, 0, 0, 0, 0, "path");

		$hiddenValuesContainer->addObject($objMode);
		$hiddenValuesContainer->addObject($objPath);

		$manager->addContainer($hiddenValuesContainer);

		$main->addObject($okButton);
		$main->addObject($cancelButton);

		$main->addObject($txtValue);

		$scripts = &new egScript();
		$line = "function clickOKButton() {
document.forms[0].submit();
}
function clickCancelButton() {
window.close();
}
";
		$scripts->addLine($line);
		$manager->addScripts($scripts);

		echo $manager->getHTML();
		break;
	case DELETE_FILE :
		if(is_file($path)) {
			$node = &new File("", $path);
			$node->remove();
		}

		$manager = &egManager::getInstance();
		$main = &new egContainer("main_ctn", 0, 0, 0, 0);
		$manager->addContainer($main);

		$scripts = new egScript();
		$line = "window.opener.location.reload();window.close();";
		$scripts->addLine($line);

		$manager->addScripts($scripts);
		echo $manager->getHTML();
		break;
	case DELETE_DIR :
		if(is_dir($path)) {
			$node = &new Dir("", $path);
			$node->remove();
		}

		$manager = &egManager::getInstance();
		$main = &new egContainer("main_ctn", 0, 0, 0, 0);
		$manager->addContainer($main);

		$scripts = new egScript();
		$line = "window.opener.location.reload();window.close();";
		$scripts->addLine($line);

		$manager->addScripts($scripts);
		echo $manager->getHTML();
		break;
}
?>