<?php
include_once('egConfig.inc.php');

/**
* constants for browser version syntax
*/
define('MAJOR', 0);
define('MINOR', 1);
define('BUILD', 2);
define('REVISION', 3);
define('FULL', 4);

/**
* constants for browsers identifiers
*/
define('ALL', 'default');
define('INTERNET_EXPLORER', 'Internet Explorer');
define('FIREFOX', 'Firefox');
define('OPERA', 'Opera');
define('SAFARI', 'Safari');
define('NETSCAPE', 'Netscape');
define('MOZILLA', 'Mozilla');
define('WEBTV', 'WebTV');
define('KONQUEROR', 'Konqueror');
define('GALEON', 'Galeon');
define('NETPOSITIVE', 'NetPositive');
define('IE_POCKET', 'IEPocket');
define('POCKET', 'Pocket');


/**
* Class to detect which browser is accessing the website
*
* @author Cedric Francoys
*/
class egBrowser {
    /**
    *
    * @var string $version
    */
    var $version;

    /**
    *
    * @var $userAgent
    */
    var $userAgent;

    /**
    *
    * @var string $platform
    */
    var $platform;

    /**
    *
    * @var string $locale
    */
    var $locale;

    /**
    *
    * @var string type
    */
    var $type;

    /**
    * Class constructor
    *
    * @param void $
    * @return void
    */
    function egBrowser() {
        $this->type = null;
        $this->userAgent = $_SERVER['HTTP_USER_AGENT'];
        $this->detectOperatingSystem();
        $this->detectLocale();
        $this->detectBrowser();
    }

    /**
    */
    function getPlatform() {
        return $this->platform;
    }

    /**
    */
    function getType() {
        return $this->type;
    }

    /**
    * version syntax : major.minor[.build[.revision]]
    */
    function getVersion($part = FULL) {
        $elems = explode(".", $this->version);

        switch ($part) {
            case MAJOR :
                if (isset($elems[MAJOR])) return $elems[MAJOR];
                return 0;
            case MINOR :
                if (isset($elems[MINOR])) return $elems[MINOR];
                return 0;
            case BUILD :
                if (isset($elems[BUILD])) return $elems[BUILD];
                return 0;
            case REVISION :
                if (isset($elems[REVISION])) return $elems[REVISION];
                return 0;
        }
        return $this->version;
    }

    /**
    * Method to check for current browser
    *
    * @param string $ browser to compare with
    * @return bool true if current browser matches the given browser
    */
    function isBrowser($browser) {
        if (isset($this->type) && $this->type == $browser) {
            return true;
        }
        return false;
    }

    /**
    * Method to get the browser details from the USER_AGENT string
    *
    * @param void $
    * @return string property platform
    */
    function detectOperatingSystem() {
        $signatures['Windows'] = "win";
        $signatures['Linux'] = "linux";
        $signatures['MacOS'] = "mac";
        $signatures['OS/2'] = "OS/2";
        $signatures['BeOS'] = "BeOS";

        foreach($signatures as $key => $value) {
            if (eregi($value, $this->userAgent)) {
                $this->platform = $key;
                break;
            }
        }
    }

    /**
    * Method to get the locale details from the USER_AGENT string
    *
    * @param void $
    * @return string property platform
    */
    function detectLocale() {
  		$locale["af"] = "Afrikaans";
  		$locale["sq"] = "Albanian";
  		$locale["ar-ae"] = "Arabic - United Arab Emirates";
  		$locale["ar-bh"] = "Arabic - Bahrain";
  		$locale["ar-dz"] = "Arabic - Algeria";
  		$locale["ar-eg"] = "Arabic - Egypt";
  		$locale["ar-iq"] = "Arabic - Iraq";
  		$locale["ar-jo"] = "Arabic - Jordan";
  		$locale["ar-kw"] = "Arabic - Kuwait";
  		$locale["ar-lb"] = "Arabic - Lebanon";
  		$locale["ar-ly"] = "Arabic - Libya";
  		$locale["ar-ma"] = "Arabic - Morocco";
  		$locale["ar-om"] = "Arabic - Oman";
  		$locale["ar-qa"] = "Arabic - Qatar";
  		$locale["ar-sa"] = "Arabic - Saudi Arabia";
  		$locale["ar-sy"] = "Arabic - Syria";
  		$locale["ar-tn"] = "Arabic - Tunisia";
  		$locale["ar-ye"] = "Arabic - Yemen";
  		$locale["hy"] = "Armenian";
  		$locale["az-az"] = "Azeri - Latin";
  		$locale["az-az"] = "Azeri - Cyrillic";
  		$locale["eu"] = "Basque";
  		$locale["be"] = "Belarusian";
  		$locale["bg"] = "Bulgarian";
  		$locale["ca"] = "Catalan";
  		$locale["zh-cn"] = "Chinese - China";
  		$locale["zh-hk"] = "Chinese - Hong Kong S.A.R.";
  		$locale["zh-mo"] = "Chinese - Macau S.A.R";
  		$locale["zh-sg"] = "Chinese - Singapore";
  		$locale["zh-tw"] = "Chinese - Taiwan";
  		$locale["hr"] = "Croatian";
  		$locale["cs"] = "Czech";
  		$locale["da"] = "Danish";
  		$locale["nl-nl"] = "Dutch - The Netherlands";
  		$locale["nl-be"] = "Dutch - Belgium";
  		$locale["en-au"] = "English - Australia";
  		$locale["en-bz"] = "English - Belize";
  		$locale["en-ca"] = "English - Canada";
  		$locale["en-cb"] = "English - Carribbean";
  		$locale["en-ie"] = "English - Ireland";
  		$locale["en-jm"] = "English - Jamaica";
  		$locale["en-nz"] = "English - New Zealand";
  		$locale["en-ph"] = "English - Phillippines";
  		$locale["en-za"] = "English - South Africa";
  		$locale["en-tt"] = "English - Trinidad";
  		$locale["en-gb"] = "English - United Kingdom";
  		$locale["en-us"] = "English - United States";
  		$locale["et"] = "Estonian";
  		$locale["fa"] = "Farsi";
  		$locale["fi"] = "Finnish";
  		$locale["fo"] = "Faroese";
  		$locale["fr-fr"] = "French - France";
  		$locale["fr-be"] = "French - Belgium";
  		$locale["fr-ca"] = "French - Canada";
  		$locale["fr-lu"] = "French - Luxembourg";
  		$locale["fr-ch"] = "French - Switzerland";
  		$locale["gd-ie"] = "Gaelic - Ireland";
  		$locale["gd"] = "Gaelic - Scotland";
  		$locale["de-de"] = "German - Germany";
  		$locale["de-at"] = "German - Austria";
  		$locale["de-li"] = "German - Liechtenstein";
  		$locale["de-lu"] = "German - Luxembourg";
  		$locale["de-ch"] = "German - Switzerland";
  		$locale["el"] = "Greek";
  		$locale["he"] = "Hebrew";
  		$locale["hi"] = "Hindi";
  		$locale["hu"] = "Hungarian";
  		$locale["is"] = "Icelandic";
  		$locale["id"] = "Indonesian";
  		$locale["it-it"] = "Italian - Italy";
  		$locale["it-ch"] = "Italian - Switzerland";
  		$locale["ja"] = "Japanese";
  		$locale["ko"] = "Korean";
  		$locale["lv"] = "Latvian";
  		$locale["lt"] = "Lithuanian";
  		$locale["mk"] = "FYRO Macedonian";
  		$locale["ms-my"] = "Malay - Malaysia";
  		$locale["ms-bn"] = "Malay - Brunei";
  		$locale["mt"] = "Maltese";
  		$locale["mr"] = "Marathi";
  		$locale["no-no"] = "Norwegian - Bokml";
  		$locale["no-no"] = "Norwegian - Nynorsk";
  		$locale["pl"] = "Polish";
  		$locale["pt-pt"] = "Portuguese - Portugal";
  		$locale["pt-br"] = "Portuguese - Brazil";
  		$locale["rm"] = "Raeto-Romance";
  		$locale["ro"] = "Romanian - Romania";
  		$locale["ro-mo"] = "Romanian - Moldova";
  		$locale["ru"] = "Russian";
  		$locale["ru-mo"] = "Russian - Moldova";
  		$locale["sa"] = "Sanskrit";
  		$locale["sr-sp"] = "Serbian - Cyrillic";
  		$locale["sr-sp"] = "Serbian - Latin";
  		$locale["tn"] = "Setsuana";
  		$locale["sl"] = "Slovenian";
  		$locale["sk"] = "Slovak";
  		$locale["sb"] = "Sorbian";
  		$locale["es-es"] = "Spanish - Spain";
  		$locale["es-ar"] = "Spanish - Argentina";
  		$locale["es-bo"] = "Spanish - Bolivia";
  		$locale["es-cl"] = "Spanish - Chile";
  		$locale["es-co"] = "Spanish - Colombia";
  		$locale["es-cr"] = "Spanish - Costa Rica";
  		$locale["es-do"] = "Spanish - Dominican Republic";
  		$locale["es-ec"] = "Spanish - Ecuador";
  		$locale["es-gt"] = "Spanish - Guatemala";
  		$locale["es-hn"] = "Spanish - Honduras";
  		$locale["es-mx"] = "Spanish - Mexico";
  		$locale["es-ni"] = "Spanish - Nicaragua";
  		$locale["es-pa"] = "Spanish - Panama";
  		$locale["es-pe"] = "Spanish - Peru";
  		$locale["es-pr"] = "Spanish - Puerto Rico";
  		$locale["es-py"] = "Spanish - Paraguay";
  		$locale["es-sv"] = "Spanish - El Salvador";
  		$locale["es-uy"] = "Spanish - Uruguay";
  		$locale["es-ve"] = "Spanish - Venezuela";
  		$locale["sx"] = "Sutu";
  		$locale["sw"] = "Swahili";
  		$locale["sv-se"] = "Swedish - Sweden";
  		$locale["sv-fi"] = "Swedish - Finland";
  		$locale["ta"] = "Tamil";
  		$locale["tt"] = "Tatar";
  		$locale["th"] = "Thai";
  		$locale["tr"] = "Turkish";
  		$locale["ts"] = "Tsonga";
  		$locale["uk"] = "Ukrainian";
  		$locale["ur"] = "Urdu";
  		$locale["uz-uz"] = "Uzbek - Cyrillic";
  		$locale["uz-uz"] = "Uzbek - Latin";
  		$locale["vi"] = "Vietnamese";
  		$locale["xh"] = "Xhosa";
  		$locale["yi"] = "Yiddish";
  		$locale["zu"] = "Zulu";

  		$this->locale = "unknown";

      foreach($locale as $key => $value) {
          if (eregi($key, $this->userAgent)) {
              $this->locale = $value;
              break;
          }
      }
    }

    function detectBrowser() {
        $signatures[INTERNET_EXPLORER] = "msie";
        $signatures[FIREFOX] = "Firefox";
        $signatures[OPERA] = "opera";
        $signatures[SAFARI] = "safari";
        $signatures[NETSCAPE] = "netscape";
        $signatures[MOZILLA] = "mozilla";
        $signatures[WEBTV] = "webtv";
        $signatures[KONQUEROR] = "Konqueror";
        $signatures[GALEON] = "galeon";
        $signatures[NETPOSITIVE] = "NetPositive";
        $signatures[IE_POCKET] = "mspie";
        $signatures[POCKET] = "pocket";

        foreach($signatures as $key => $value) {
            if (eregi($value, $this->userAgent)) {
                switch ($key) {
                    case INTERNET_EXPLORER:
                        $val = explode(" ", stristr($this->userAgent, "msie"));
                        $this->version = substr_replace($val[1], "", -1);
                        if (!eregi("opera", $this->userAgent)) {
                            $this->type = INTERNET_EXPLORER;
                            break;
                        }
                    case OPERA:
                        $val = stristr($this->userAgent, "opera");
                        if (eregi("/", $val)) {
                            $val = explode("/", $val);
                            $val = explode(" ", $val[1]);
                            $this->version = $val[0];
                        } else {
                            $val = explode(" ", stristr($val, "opera"));
                            $this->version = $val[1];
                        }
                        $this->type = OPERA;
                        break;
                    case FIREFOX:
                        $val = stristr($this->userAgent, "Firefox");
                        $val = explode("/", $val);
                        $this->version = $val[1];
                        $this->type = FIREFOX;
                        break;
                    case MOZILLA:
                        $val = explode(" ", stristr($this->userAgent, "rv:"));
                        eregi("rv:[0-9]\.[0-9]\.[0-9]", $this->userAgent, $val);
                        $this->version = str_replace("rv:", "", $val[0]);
                        if (!eregi("netscape", $this->userAgent)) {
                            $this->type = MOZILLA;
                            break;
                        }
                    case NETSCAPE:
                        $val = explode(" ", stristr($this->userAgent, "netscape"));
                        $val = explode("/", $val[0]);
                        $this->version = $val[1];
                        $this->type = NETSCAPE;
                        break;
                    case KONQUEROR:
                        $val = explode(" ", stristr($this->userAgent, "Konqueror"));
                        $val = explode("/", $val[0]);
                        $this->version = str_replace(")", "", $val[1]);
                        $this->type = KONQUEROR;
                        break;
                    case GALEON:
                        $val = explode(" ", stristr($this->userAgent, "galeon"));
                        $val = explode("/", $val[0]);
                        $this->version = $val[1];
                        $this->type = GALEON;
                        break;
                    case NETPOSITIVE:
                        $val = explode("/", stristr($this->userAgent, "NetPositive"));
                        $this->version = $val[1];
                        $this->type = NETPOSITIVE;
                        break;
                    case WEBTV:
                        $val = explode("/", stristr($this->userAgent, "webtv"));
                        $this->version = $val[1];
                        $this->type = WEBTV;
                        break;
                    case SAFARI:
                        $this->version = "";
                        $this->type = SAFARI;
                        break;
                    case IE_POCKET:
                    case POCKET:
                        $val = explode(" ", stristr($this->userAgent, "mspie"));
                        $this->platform = "WindowsCE";
                        if (eregi("mspie", $this->userAgent))
                            $this->version = $val[1];
                        else {
                            $val = explode("/", $this->userAgent);
                            $this->version = $val[1];
                        }
                        $this->type = IE_POCKET;
                        break;
                }
                break;
            }
        }
    }
}
?>